@@ -1,5 +1,5 @@
 var classSteinberg_1_1IPlugViewContentScaleSupport =
 [
-    [ "ScaleFactor", "classSteinberg_1_1IPlugViewContentScaleSupport.html#a75ec4b5d086d2af3733ac3775ab008d8", null ],
+    [ "ScaleFactor", "group__smtgtypedef.html#ga75ec4b5d086d2af3733ac3775ab008d8", null ],
     [ "setContentScaleFactor", "classSteinberg_1_1IPlugViewContentScaleSupport.html#af5b0fea85beba3cdcfeb8de66779f478", null ]
 ];
\ No newline at end of file
