@@ -50,36 +50,36 @@ var namespaceSteinberg =
     [ "UString", "classSteinberg_1_1UString.html", "classSteinberg_1_1UString" ],
     [ "UStringBuffer", "classSteinberg_1_1UStringBuffer.html", "classSteinberg_1_1UStringBuffer" ],
     [ "ViewRect", "structSteinberg_1_1ViewRect.html", "structSteinberg_1_1ViewRect" ],
-    [ "int8", "namespaceSteinberg.html#ae47c588f3ab8c61121c1c7ab7edc47cd", null ],
-    [ "uint8", "namespaceSteinberg.html#a33a5e996e7a90acefb8b1c0bea47e365", null ],
-    [ "uchar", "namespaceSteinberg.html#a65f85814a8290f9797005d3b28e7e5fc", null ],
-    [ "int16", "namespaceSteinberg.html#aa0d0fdc87fd135ef2bedb030901cdb9c", null ],
-    [ "uint16", "namespaceSteinberg.html#ac2a9e79eb120216f855626495b7bd18a", null ],
-    [ "int32", "namespaceSteinberg.html#ab7903878916593daecbeb95b98115ab0", null ],
-    [ "uint32", "namespaceSteinberg.html#acbd4acd0d29e2d6c43104827f77d9cd2", null ],
-    [ "int64", "namespaceSteinberg.html#a7cde0074dfd288f2d70c0e035dacb28a", null ],
-    [ "uint64", "namespaceSteinberg.html#abc0f5bc07737e498f287334775dff2b6", null ],
-    [ "TSize", "namespaceSteinberg.html#abc5a03f91bd781b5062f4fccaa7851f0", null ],
-    [ "tresult", "namespaceSteinberg.html#a902761e005a6252e538c766de48fc957", null ],
-    [ "TPtrInt", "namespaceSteinberg.html#adbdfa470c35e7bf57d7952f0767bbf57", null ],
-    [ "TBool", "namespaceSteinberg.html#a1ea8addd740f35d207a1569dd38ef895", null ],
-    [ "char8", "namespaceSteinberg.html#ac9e1c0f508ae0f5f8a2b704a91e1ae86", null ],
-    [ "char16", "namespaceSteinberg.html#a667a0a4e0cbcb3f3785984955e1fefd8", null ],
-    [ "char", "namespaceSteinberg.html#aa9eb7d301130a7771343735bef461579", null ],
-    [ "CStringA", "namespaceSteinberg.html#a435992556581fbc31a9bddb3bb2f787a", null ],
-    [ "CStringW", "namespaceSteinberg.html#a81b4df0e8189d2f135f25919a6a90be2", null ],
-    [ "CString", "namespaceSteinberg.html#a6f37e0dbf8faed21d2658800d9db4583", null ],
-    [ "FIDString", "namespaceSteinberg.html#ad4c02134d1ee42389f3d94717935a1d5", null ],
-    [ "UCoord", "namespaceSteinberg.html#abf33a8b245f4634965116e9c25eb702a", null ],
-    [ "LARGE_INT", "namespaceSteinberg.html#a9cd1730908299276af7bc0baa8c5197e", null ],
-    [ "TUID", "namespaceSteinberg.html#a6935af93744bfe4ecc455f274ef1ec36", null ],
-    [ "IAttrID", "namespaceSteinberg.html#ae6eacc17e4382538d4af0d9993bc869a", null ],
-    [ "ColorSpec", "namespaceSteinberg.html#a5b13d028fba1eee386ec9ac208c6238d", null ],
-    [ "ColorComponent", "namespaceSteinberg.html#af1189c83b63820c6ccc3167402601fea", null ],
-    [ "UColorSpec", "namespaceSteinberg.html#a87699df6cd24276f34afea51d903c6e4", null ],
-    [ "UColorComponent", "namespaceSteinberg.html#a3c4f7362f2f494a4120d7c864dd0822d", null ],
-    [ "UString128", "namespaceSteinberg.html#aa92186fdeda699e7a0cc7ac6c45d07e5", null ],
-    [ "UString256", "namespaceSteinberg.html#a71098a25fa252b10d271a11807153385", null ],
+    [ "int8", "group__smtgtypedef.html#gae47c588f3ab8c61121c1c7ab7edc47cd", null ],
+    [ "uint8", "group__smtgtypedef.html#ga33a5e996e7a90acefb8b1c0bea47e365", null ],
+    [ "uchar", "group__smtgtypedef.html#ga65f85814a8290f9797005d3b28e7e5fc", null ],
+    [ "int16", "group__smtgtypedef.html#gaa0d0fdc87fd135ef2bedb030901cdb9c", null ],
+    [ "uint16", "group__smtgtypedef.html#gac2a9e79eb120216f855626495b7bd18a", null ],
+    [ "int32", "group__smtgtypedef.html#gab7903878916593daecbeb95b98115ab0", null ],
+    [ "uint32", "group__smtgtypedef.html#gacbd4acd0d29e2d6c43104827f77d9cd2", null ],
+    [ "int64", "group__smtgtypedef.html#ga7cde0074dfd288f2d70c0e035dacb28a", null ],
+    [ "uint64", "group__smtgtypedef.html#gabc0f5bc07737e498f287334775dff2b6", null ],
+    [ "TSize", "group__smtgtypedef.html#gabc5a03f91bd781b5062f4fccaa7851f0", null ],
+    [ "tresult", "group__smtgtypedef.html#ga902761e005a6252e538c766de48fc957", null ],
+    [ "TPtrInt", "group__smtgtypedef.html#gadbdfa470c35e7bf57d7952f0767bbf57", null ],
+    [ "TBool", "group__smtgtypedef.html#ga1ea8addd740f35d207a1569dd38ef895", null ],
+    [ "char8", "group__smtgtypedef.html#gac9e1c0f508ae0f5f8a2b704a91e1ae86", null ],
+    [ "char16", "group__smtgtypedef.html#ga667a0a4e0cbcb3f3785984955e1fefd8", null ],
+    [ "char", "group__smtgtypedef.html#gaa9eb7d301130a7771343735bef461579", null ],
+    [ "CStringA", "group__smtgtypedef.html#ga435992556581fbc31a9bddb3bb2f787a", null ],
+    [ "CStringW", "group__smtgtypedef.html#ga81b4df0e8189d2f135f25919a6a90be2", null ],
+    [ "CString", "group__smtgtypedef.html#ga6f37e0dbf8faed21d2658800d9db4583", null ],
+    [ "FIDString", "group__smtgtypedef.html#gad4c02134d1ee42389f3d94717935a1d5", null ],
+    [ "UCoord", "group__smtgtypedef.html#gabf33a8b245f4634965116e9c25eb702a", null ],
+    [ "LARGE_INT", "group__smtgtypedef.html#ga9cd1730908299276af7bc0baa8c5197e", null ],
+    [ "TUID", "group__pluginBase.html#ga6935af93744bfe4ecc455f274ef1ec36", null ],
+    [ "IAttrID", "group__smtgtypedef.html#gae6eacc17e4382538d4af0d9993bc869a", null ],
+    [ "ColorSpec", "group__smtgtypedef.html#ga5b13d028fba1eee386ec9ac208c6238d", null ],
+    [ "ColorComponent", "group__smtgtypedef.html#gaf1189c83b63820c6ccc3167402601fea", null ],
+    [ "UColorSpec", "group__smtgtypedef.html#ga87699df6cd24276f34afea51d903c6e4", null ],
+    [ "UColorComponent", "group__smtgtypedef.html#ga3c4f7362f2f494a4120d7c864dd0822d", null ],
+    [ "UString128", "group__smtgtypedef.html#gaa92186fdeda699e7a0cc7ac6c45d07e5", null ],
+    [ "UString256", "group__smtgtypedef.html#ga71098a25fa252b10d271a11807153385", null ],
     [ "Direction", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aa", [
       [ "kNorth", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa89c5f7af4c1a4fe20ab7524369050200", null ],
       [ "kNorthEast", "namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa80a10c4928ef7af3ce487d381e2420d2", null ],
@@ -256,9 +256,9 @@ var namespaceSteinberg =
     [ "strcat16", "namespaceSteinberg.html#a05fbb76593f6044ac8375e1becf16d4d", null ],
     [ "str8ToStr16", "namespaceSteinberg.html#a65d41e28de7b3ce39de0f9e2e6d99926", null ],
     [ "FIDStringsEqual", "namespaceSteinberg.html#afcb1a763178c9806cc827360a02741e2", null ],
-    [ "strEmpty", "namespaceSteinberg.html#a6a838f230987e1a095b0cb75c28d4a65", null ],
-    [ "str8Empty", "namespaceSteinberg.html#a728f0ddc16a12be5fa0f950f4c8a0a8e", null ],
-    [ "str16Empty", "namespaceSteinberg.html#a81eef9745d0b6653c6a1c78bb89533d8", null ],
+    [ "strEmpty", "group__smtgtypedef.html#ga6a838f230987e1a095b0cb75c28d4a65", null ],
+    [ "str8Empty", "group__smtgtypedef.html#ga728f0ddc16a12be5fa0f950f4c8a0a8e", null ],
+    [ "str16Empty", "group__smtgtypedef.html#ga81eef9745d0b6653c6a1c78bb89533d8", null ],
     [ "getTUID", "namespaceSteinberg.html#ab5c714b140d499f304e042e746ca9b1b", null ],
     [ "Min", "namespaceSteinberg.html#a29948ccdc9190054dba415d7ac893768", null ],
     [ "Max", "namespaceSteinberg.html#ae861849d924547696801cead672d8b16", null ],
@@ -267,7 +267,7 @@ var namespaceSteinberg =
     [ "Bound", "namespaceSteinberg.html#ac5974f8c0577e9e37f9ea9d9d5a70a75", null ],
     [ "Swap", "namespaceSteinberg.html#a1bab287b1f45fc8d99493a1d142b7deb", null ],
     [ "IsApproximateEqual", "namespaceSteinberg.html#a004e46ded0d442c0c031094559ad23b6", null ],
-    [ "ToNormalized", "namespaceSteinberg.html#a31a33bd1d2143601be9244b5eb666167", null ],
+    [ "ToNormalized", "namespaceSteinberg.html#a266eafd81fd5078d6b177162227ee49a", null ],
     [ "FromNormalized", "namespaceSteinberg.html#a53b9fdb1691391567d0bd6697ddc503c", null ],
     [ "operator==", "namespaceSteinberg.html#a8a42998c5c8a3a844cdf3b21d1b9be70", null ],
     [ "operator!=", "namespaceSteinberg.html#a443dbd34922bff48d94a4060764ae9e9", null ],
@@ -295,14 +295,15 @@ var namespaceSteinberg =
     [ "BlendColor", "namespaceSteinberg.html#a82f9ae0460c5ad8b348cdfa75fec5c68", null ],
     [ "StringCopy", "namespaceSteinberg.html#a51c63740ab18a5e8a1394fb10e743917", null ],
     [ "StringLength", "namespaceSteinberg.html#ae6cdc2936b352ab9cd2fb6aed350bbaa", null ],
-    [ "kPlatformStringWin", "namespaceSteinberg.html#a2ae80314db54c6bda33e1cf922effb47", null ],
-    [ "kPlatformStringMac", "namespaceSteinberg.html#ad5ffc071fd688ac833b5283777037278", null ],
-    [ "kPlatformStringIOS", "namespaceSteinberg.html#a0e747a3b854268949a75a1c8e8fd070c", null ],
-    [ "kPlatformStringLinux", "namespaceSteinberg.html#a1c13255fbcd5845d44bd45cc27bd3586", null ],
-    [ "kPlatformString", "namespaceSteinberg.html#a45a730ec762ad31ab0e5c80e15560afc", null ],
-    [ "kPlatformTypeHWND", "namespaceSteinberg.html#aa1e68ac1f25da9c85c937d0360dbc601", null ],
-    [ "kPlatformTypeHIView", "namespaceSteinberg.html#a974cabea219cb31ad8218ba15d1f7071", null ],
-    [ "kPlatformTypeNSView", "namespaceSteinberg.html#a8ce69944b5475d65206469b9ebcbf755", null ],
-    [ "kPlatformTypeUIView", "namespaceSteinberg.html#a6362a7ca65b87d30c561dac986b757bd", null ],
-    [ "kPlatformTypeX11EmbedWindowID", "namespaceSteinberg.html#ac945decc5f26f3fdb5419e8de833a0e1", null ]
+    [ "kPlatformStringWin", "group__smtgtypedef.html#ga2ae80314db54c6bda33e1cf922effb47", null ],
+    [ "kPlatformStringMac", "group__smtgtypedef.html#gad5ffc071fd688ac833b5283777037278", null ],
+    [ "kPlatformStringIOS", "group__smtgtypedef.html#ga0e747a3b854268949a75a1c8e8fd070c", null ],
+    [ "kPlatformStringLinux", "group__smtgtypedef.html#ga1c13255fbcd5845d44bd45cc27bd3586", null ],
+    [ "kPlatformString", "group__smtgtypedef.html#ga45a730ec762ad31ab0e5c80e15560afc", null ],
+    [ "kPlatformTypeHWND", "group__platformUIType.html#gaa1e68ac1f25da9c85c937d0360dbc601", null ],
+    [ "kPlatformTypeHIView", "group__platformUIType.html#ga974cabea219cb31ad8218ba15d1f7071", null ],
+    [ "kPlatformTypeNSView", "group__platformUIType.html#ga8ce69944b5475d65206469b9ebcbf755", null ],
+    [ "kPlatformTypeUIView", "group__platformUIType.html#ga6362a7ca65b87d30c561dac986b757bd", null ],
+    [ "kPlatformTypeX11EmbedWindowID", "group__platformUIType.html#gac945decc5f26f3fdb5419e8de833a0e1", null ],
+    [ "kPlatformTypeWaylandSurfaceID", "group__platformUIType.html#ga111998b5f362f172b2c0edce7bfe3552", null ]
 ];
\ No newline at end of file
