@@ -1,16 +1,53 @@
 var NAVTREEINDEX2 =
 {
+"group__smtgtypedef.html#gae47c588f3ab8c61121c1c7ab7edc47cd":[0,0,0],
+"group__smtgtypedef.html#gae6eacc17e4382538d4af0d9993bc869a":[0,0,22],
+"group__smtgtypedef.html#gaf1189c83b63820c6ccc3167402601fea":[0,0,26],
+"hierarchy.html":[2,2],
+"ibstream_8h.html":[3,0,0,0,14],
+"icloneable_8h.html":[3,0,0,0,15],
+"ierrorcontext_8h.html":[3,0,0,0,16],
+"index.html":[],
+"ipersistent_8h.html":[3,0,0,0,17],
+"ipluginbase_8h.html":[3,0,0,0,18],
+"ipluginbase_8h.html#a15eabd5eb49e5ec7c8e2f6210f53ffdc":[3,0,0,0,18,1],
+"ipluginbase_8h.html#aa9191a0df91519481477d0ed17802104":[3,0,0,0,18,2],
+"iplugincompatibility_8h.html":[3,0,0,0,19],
+"iplugincompatibility_8h.html#a68b5dca6ae4e96f1116bd8c9729a8d57":[3,0,0,0,19,1],
+"iplugview_8h.html":[3,0,0,1,0],
+"iplugviewcontentscalesupport_8h.html":[3,0,0,1,1],
+"istringresult_8h.html":[3,0,0,0,20],
+"iupdatehandler_8h.html":[3,0,0,0,21],
+"keycodes_8h.html":[3,0,0,0,22],
+"namespaceSteinberg.html":[1,0,0],
+"namespaceSteinberg.html#a004e46ded0d442c0c031094559ad23b6":[1,0,0,118],
+"namespaceSteinberg.html#a05fbb76593f6044ac8375e1becf16d4d":[1,0,0,105],
+"namespaceSteinberg.html#a125a36f7e942e2b77d76d57d2cc6398d":[1,0,0,100],
+"namespaceSteinberg.html#a145379c6e26917acaa0bac72b8c0bc05":[1,0,0,133],
+"namespaceSteinberg.html#a154d134fd010929649c537c38e9937f8":[1,0,0,93],
+"namespaceSteinberg.html#a170abdd6288ad80f6ddca3d7e9c3fb59":[1,0,0,141],
+"namespaceSteinberg.html#a18016e0ec944a4149fab9503980332e7":[1,0,0,92],
+"namespaceSteinberg.html#a1bab287b1f45fc8d99493a1d142b7deb":[1,0,0,117],
+"namespaceSteinberg.html#a1f2971e00b71425e2035c4f946031fd9":[1,0,0,97],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aa":[1,0,0,71],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa37d01669db016bc15ed6fdab6fb6c790":[1,0,0,71,2],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa45b705ff067984bfd99c234d91386792":[1,0,0,71,6],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa515c12ec206b53ce5da86a402b3f4cf8":[1,0,0,71,4],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa6a77137c947ac754a97274617a22afb6":[1,0,0,71,5],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa80a10c4928ef7af3ce487d381e2420d2":[1,0,0,71,1],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa87e054da76bada3343762974c988e80a":[1,0,0,71,8],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaa89c5f7af4c1a4fe20ab7524369050200":[1,0,0,71,0],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaaa67fc18f8f8b0ba3b792b46a1fa0c872":[1,0,0,71,7],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaabdba6353397f1b1654328de91f17e348":[1,0,0,71,9],
+"namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aaadf50c366ce2690678d0e6290f52b4639":[1,0,0,71,3],
+"namespaceSteinberg.html#a25a9f00585fee6f2dda46514bb29b933":[1,0,0,129],
+"namespaceSteinberg.html#a266eafd81fd5078d6b177162227ee49a":[1,0,0,119],
+"namespaceSteinberg.html#a272ecb0af547f0b5e960144874fc8027":[1,0,0,139],
 "namespaceSteinberg.html#a27f6f9da6429b67343a7e36078494bd9":[1,0,0,143],
 "namespaceSteinberg.html#a290312f8c692123017dfd6ab276f7148":[1,0,0,80],
 "namespaceSteinberg.html#a29948ccdc9190054dba415d7ac893768":[1,0,0,112],
-"namespaceSteinberg.html#a2ae80314db54c6bda33e1cf922effb47":[1,0,0,147],
-"namespaceSteinberg.html#a31a33bd1d2143601be9244b5eb666167":[1,0,0,119],
-"namespaceSteinberg.html#a33a5e996e7a90acefb8b1c0bea47e365":[1,0,0,42],
 "namespaceSteinberg.html#a37115f1ed1a36ba151d84ff370aaf05f":[1,0,0,104],
-"namespaceSteinberg.html#a3c4f7362f2f494a4120d7c864dd0822d":[1,0,0,68],
-"namespaceSteinberg.html#a435992556581fbc31a9bddb3bb2f787a":[1,0,0,57],
 "namespaceSteinberg.html#a443dbd34922bff48d94a4060764ae9e9":[1,0,0,122],
-"namespaceSteinberg.html#a45a730ec762ad31ab0e5c80e15560afc":[1,0,0,151],
 "namespaceSteinberg.html#a46784fedcaf2cd10c9a0f2614ecdb832":[1,0,0,95],
 "namespaceSteinberg.html#a485a5d44628dff8b69863742f214ef8c":[1,0,0,84],
 "namespaceSteinberg.html#a51c63740ab18a5e8a1394fb10e743917":[1,0,0,145],
@@ -19,21 +56,12 @@ var NAVTREEINDEX2 =
 "namespaceSteinberg.html#a572daddd6ee8f61011dcd066eef99b0c":[1,0,0,140],
 "namespaceSteinberg.html#a58b97116e0faaf335c798a65b687e9f2":[1,0,0,127],
 "namespaceSteinberg.html#a59846763a52e0e182dcf5b1573a7e89e":[1,0,0,87],
-"namespaceSteinberg.html#a5b13d028fba1eee386ec9ac208c6238d":[1,0,0,65],
 "namespaceSteinberg.html#a603b2ada00778d1a71caef40362ae6d8":[1,0,0,125],
-"namespaceSteinberg.html#a6362a7ca65b87d30c561dac986b757bd":[1,0,0,155],
 "namespaceSteinberg.html#a65d41e28de7b3ce39de0f9e2e6d99926":[1,0,0,106],
-"namespaceSteinberg.html#a65f85814a8290f9797005d3b28e7e5fc":[1,0,0,43],
 "namespaceSteinberg.html#a6618cd408bb7e6ca706d2ede559b7883":[1,0,0,114],
 "namespaceSteinberg.html#a663277a04cd2cb23fd812715359350f5":[1,0,0,99],
-"namespaceSteinberg.html#a667a0a4e0cbcb3f3785984955e1fefd8":[1,0,0,55],
-"namespaceSteinberg.html#a6935af93744bfe4ecc455f274ef1ec36":[1,0,0,63],
 "namespaceSteinberg.html#a69a06ce98bc91e355a0b3f558344b0f2":[1,0,0,135],
-"namespaceSteinberg.html#a6a838f230987e1a095b0cb75c28d4a65":[1,0,0,108],
 "namespaceSteinberg.html#a6b08a8f4a4993d488e14cf812807675c":[1,0,0,82],
-"namespaceSteinberg.html#a6f37e0dbf8faed21d2658800d9db4583":[1,0,0,59],
-"namespaceSteinberg.html#a71098a25fa252b10d271a11807153385":[1,0,0,70],
-"namespaceSteinberg.html#a728f0ddc16a12be5fa0f950f4c8a0a8e":[1,0,0,109],
 "namespaceSteinberg.html#a743f60968fa58cdae68b31a1a3eb493d":[1,0,0,74],
 "namespaceSteinberg.html#a743f60968fa58cdae68b31a1a3eb493da111880e47a70791b129ec7a46f988078":[1,0,0,74,2],
 "namespaceSteinberg.html#a743f60968fa58cdae68b31a1a3eb493da6bd5ac36e7d960d29783e07406f3b15c":[1,0,0,74,3],
@@ -41,25 +69,19 @@ var NAVTREEINDEX2 =
 "namespaceSteinberg.html#a743f60968fa58cdae68b31a1a3eb493da8779d8eaee888493c6c5db7acc5d4a0a":[1,0,0,74,1],
 "namespaceSteinberg.html#a78350a628df86c106340f08c57f9b8b5":[1,0,0,91],
 "namespaceSteinberg.html#a79cc5b78e482b56ee792dac1fa4ddc1b":[1,0,0,96],
-"namespaceSteinberg.html#a7cde0074dfd288f2d70c0e035dacb28a":[1,0,0,48],
 "namespaceSteinberg.html#a7daea0aeaaf968f0cbc3473815ef4c4c":[1,0,0,130],
 "namespaceSteinberg.html#a7deed6801721823ffd280717b6675c48":[1,0,0,131],
 "namespaceSteinberg.html#a7ef9ebfedc0532d783ae68dbbe8f08c7":[1,0,0,132],
-"namespaceSteinberg.html#a81b4df0e8189d2f135f25919a6a90be2":[1,0,0,58],
-"namespaceSteinberg.html#a81eef9745d0b6653c6a1c78bb89533d8":[1,0,0,110],
 "namespaceSteinberg.html#a82f9ae0460c5ad8b348cdfa75fec5c68":[1,0,0,144],
 "namespaceSteinberg.html#a84be4b87ef6295be6b4ea97052b94999":[1,0,0,102],
 "namespaceSteinberg.html#a871118a09520247c78a71ecd7b0abd58":[1,0,0,72],
 "namespaceSteinberg.html#a871118a09520247c78a71ecd7b0abd58a231632c3d1e6d53428167283534f1abe":[1,0,0,72,2],
 "namespaceSteinberg.html#a871118a09520247c78a71ecd7b0abd58a4764485d9d221af213bf2b2769cdfc54":[1,0,0,72,1],
 "namespaceSteinberg.html#a871118a09520247c78a71ecd7b0abd58ad4149164ae4bf90011d92a3dbfcce742":[1,0,0,72,0],
-"namespaceSteinberg.html#a87699df6cd24276f34afea51d903c6e4":[1,0,0,67],
 "namespaceSteinberg.html#a89abcadbf71668d5248488e4b94eacc6":[1,0,0,115],
 "namespaceSteinberg.html#a8a42998c5c8a3a844cdf3b21d1b9be70":[1,0,0,121],
 "namespaceSteinberg.html#a8a76499e90e8d7f44ff14f18f129afcd":[1,0,0,78],
-"namespaceSteinberg.html#a8ce69944b5475d65206469b9ebcbf755":[1,0,0,154],
 "namespaceSteinberg.html#a901c5dcbc48f4a6f220bd7d4d5d93c66":[1,0,0,98],
-"namespaceSteinberg.html#a902761e005a6252e538c766de48fc957":[1,0,0,51],
 "namespaceSteinberg.html#a91005f5c2c5b338136cf19c7afec6064":[1,0,0,90],
 "namespaceSteinberg.html#a919216f5d1c976556c67d94c8522db43":[1,0,0,76],
 "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22b":[1,0,0,73],
@@ -144,31 +166,18 @@ var NAVTREEINDEX2 =
 "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bafce663586a7e53223158c5f4ce6033fc":[1,0,0,73,37],
 "namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22bafcf70bc39c0032de8a1c6452ac9860a5":[1,0,0,73,39],
 "namespaceSteinberg.html#a95aadb22dc3e307e7e65db901e771f60":[1,0,0,89],
-"namespaceSteinberg.html#a974cabea219cb31ad8218ba15d1f7071":[1,0,0,153],
 "namespaceSteinberg.html#a9a49a1a97b367d7069b1f6515261fe3e":[1,0,0,124],
 "namespaceSteinberg.html#a9c04924e4e7bafc6162173aa938ce7ae":[1,0,0,85],
-"namespaceSteinberg.html#a9cd1730908299276af7bc0baa8c5197e":[1,0,0,62],
 "namespaceSteinberg.html#a9d769cee1cea3e2224b7c2fb9c61e1cb":[1,0,0,83],
-"namespaceSteinberg.html#aa0d0fdc87fd135ef2bedb030901cdb9c":[1,0,0,44],
-"namespaceSteinberg.html#aa1e68ac1f25da9c85c937d0360dbc601":[1,0,0,152],
 "namespaceSteinberg.html#aa50131d71c879a95dfa3efac24b815c6":[1,0,0,137],
 "namespaceSteinberg.html#aa7cb190cb494b7f61aaacf170d322d30":[1,0,0,128],
-"namespaceSteinberg.html#aa92186fdeda699e7a0cc7ac6c45d07e5":[1,0,0,69],
-"namespaceSteinberg.html#aa9eb7d301130a7771343735bef461579":[1,0,0,56],
 "namespaceSteinberg.html#aabd2ebacd043630aac6ea6383bace10b":[1,0,0,136],
 "namespaceSteinberg.html#ab5c714b140d499f304e042e746ca9b1b":[1,0,0,111],
-"namespaceSteinberg.html#ab7903878916593daecbeb95b98115ab0":[1,0,0,46],
 "namespaceSteinberg.html#abad8045987a3d33b9421e724c06a9d6f":[1,0,0,138],
 "namespaceSteinberg.html#abb64176847a23e106203af14083e1827":[1,0,0,123],
-"namespaceSteinberg.html#abc0f5bc07737e498f287334775dff2b6":[1,0,0,49],
-"namespaceSteinberg.html#abc5a03f91bd781b5062f4fccaa7851f0":[1,0,0,50],
-"namespaceSteinberg.html#abf33a8b245f4634965116e9c25eb702a":[1,0,0,61],
 "namespaceSteinberg.html#abfe74133ed684fa31c7227a9d1a4b3ce":[1,0,0,142],
-"namespaceSteinberg.html#ac2a9e79eb120216f855626495b7bd18a":[1,0,0,45],
 "namespaceSteinberg.html#ac5974f8c0577e9e37f9ea9d9d5a70a75":[1,0,0,116],
 "namespaceSteinberg.html#ac6ae1990a6eb57a92f18013ab200fd61":[1,0,0,94],
-"namespaceSteinberg.html#ac945decc5f26f3fdb5419e8de833a0e1":[1,0,0,156],
-"namespaceSteinberg.html#ac9e1c0f508ae0f5f8a2b704a91e1ae86":[1,0,0,54],
 "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cd":[1,0,0,75],
 "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda020c41a39f7c676ecb89ee23885070b6":[1,0,0,75,33],
 "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda02a9193b86afaccf9bbf742a323100be":[1,0,0,75,2],
@@ -207,22 +216,15 @@ var NAVTREEINDEX2 =
 "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdadab15681c7200799430d2f338d0ed61e":[1,0,0,75,8],
 "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdae22e7268faee0570b14aa13c801fa3b9":[1,0,0,75,25],
 "namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdaf35707aff5cbf5d69b5f0aecd302d9b1":[1,0,0,75,28],
-"namespaceSteinberg.html#acbd4acd0d29e2d6c43104827f77d9cd2":[1,0,0,47],
 "namespaceSteinberg.html#accf894d033204ed519ac2612a46c442d":[1,0,0,88],
 "namespaceSteinberg.html#ace46dac211111d8384286b1ae2c9689e":[1,0,0,86],
 "namespaceSteinberg.html#ad1477e38cb33dbf399ba506dd9fa1ab2":[1,0,0,101],
-"namespaceSteinberg.html#ad4c02134d1ee42389f3d94717935a1d5":[1,0,0,60],
-"namespaceSteinberg.html#ad5ffc071fd688ac833b5283777037278":[1,0,0,148],
 "namespaceSteinberg.html#ad878d42e7b5a81c513f613c52a5f9f0a":[1,0,0,103],
-"namespaceSteinberg.html#adbdfa470c35e7bf57d7952f0767bbf57":[1,0,0,52],
 "namespaceSteinberg.html#adee0831ed9db758b6d119bf3c3b99e43":[1,0,0,77],
-"namespaceSteinberg.html#ae47c588f3ab8c61121c1c7ab7edc47cd":[1,0,0,41],
 "namespaceSteinberg.html#ae6cdc2936b352ab9cd2fb6aed350bbaa":[1,0,0,146],
-"namespaceSteinberg.html#ae6eacc17e4382538d4af0d9993bc869a":[1,0,0,64],
 "namespaceSteinberg.html#ae861849d924547696801cead672d8b16":[1,0,0,113],
 "namespaceSteinberg.html#ae8f11c779bd10486d527d1a7142d8e6b":[1,0,0,134],
 "namespaceSteinberg.html#aecbafba4ac9e0f4734fdc1d0aecc5f70":[1,0,0,126],
-"namespaceSteinberg.html#af1189c83b63820c6ccc3167402601fea":[1,0,0,66],
 "namespaceSteinberg.html#af722fba1489836fd17c0f50206e8e262":[1,0,0,79],
 "namespaceSteinberg.html#afcb1a763178c9806cc827360a02741e2":[1,0,0,107],
 "namespaceSteinberg_1_1FUnknownImpl.html":[1,0,0,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX2 =
 "namespaceSteinberg_1_1Linux.html":[1,0,0,4],
 "namespaceSteinberg_1_1Linux.html#a9c80aaf6d9c6451b471e97de46595753":[1,0,0,4,4],
 "namespaceSteinberg_1_1Linux.html#ad94d4fecedeef98b5d1709b61cfa0e7c":[1,0,0,4,3],
-"namespaceSteinberg_1_1U.html":[1,0,0,5],
-"namespaceSteinberg_1_1U.html#a33d524a00593b41664bf5a7be2aaf204":[1,0,0,5,6],
-"namespaceSteinberg_1_1U.html#a689771ba01c7847cc229ae30e227b638":[1,0,0,5,7]
+"namespaceSteinberg_1_1U.html":[1,0,0,5]
 };
