@@ -6,6 +6,6 @@ var searchData=
   ['endline_5fa_3',['ENDLINE_A',['../fstrdefs_8h.html#a46520f93e91d264d018120231fdd7afa',1,'fstrdefs.h']]],
   ['endline_5fw_4',['ENDLINE_W',['../fstrdefs_8h.html#a28de1ded2200fa58d2e63f3852ee7da0',1,'fstrdefs.h']]],
   ['errormessageshown_5',['errorMessageShown',['../classSteinberg_1_1IErrorContext.html#a344d0ab2c2edc4aa4f47af8617375d4f',1,'Steinberg::IErrorContext']]],
-  ['extends_6',['Extends',['../namespaceSteinberg_1_1FUnknownImpl.html#ad7c3d8fc183de6c65cb7209c4edda8a7',1,'Steinberg::FUnknownImpl']]],
+  ['extends_6',['Extends',['../namespaceSteinberg_1_1FUnknownImpl.html#ad7c3d8fc183de6c65cb7209c4edda8a7',1,'Steinberg::FUnknownImpl::Extends'],['../namespaceSteinberg_1_1U.html#ad7c3d8fc183de6c65cb7209c4edda8a7',1,'Steinberg::U::Extends']]],
   ['extern_5fuid_7',['EXTERN_UID',['../funknown_8h.html#a845c8fdb88f7f23c4060134a798a1e7d',1,'funknown.h']]]
 ];
