@@ -26,8 +26,8 @@ var searchData=
   ['settext8_23',['setText8',['../classSteinberg_1_1IString.html#ac42dc105d9a95ac233eca36746f9afb4',1,'Steinberg::IString']]],
   ['shared_24',['shared',['../namespaceSteinberg.html#aecbafba4ac9e0f4734fdc1d0aecc5f70',1,'Steinberg']]],
   ['sign_25',['Sign',['../namespaceSteinberg.html#a89abcadbf71668d5248488e4b94eacc6',1,'Steinberg']]],
-  ['str16empty_26',['str16Empty',['../namespaceSteinberg.html#a81eef9745d0b6653c6a1c78bb89533d8',1,'Steinberg']]],
-  ['str8empty_27',['str8Empty',['../namespaceSteinberg.html#a728f0ddc16a12be5fa0f950f4c8a0a8e',1,'Steinberg']]],
+  ['str16empty_26',['str16Empty',['../group__smtgtypedef.html#ga81eef9745d0b6653c6a1c78bb89533d8',1,'Steinberg']]],
+  ['str8empty_27',['str8Empty',['../group__smtgtypedef.html#ga728f0ddc16a12be5fa0f950f4c8a0a8e',1,'Steinberg']]],
   ['str8tostr16_28',['str8ToStr16',['../namespaceSteinberg.html#a65d41e28de7b3ce39de0f9e2e6d99926',1,'Steinberg']]],
   ['strcat16_29',['strcat16',['../namespaceSteinberg.html#a05fbb76593f6044ac8375e1becf16d4d',1,'Steinberg']]],
   ['strcat8_30',['strcat8',['../namespaceSteinberg.html#a37115f1ed1a36ba151d84ff370aaf05f',1,'Steinberg']]],
@@ -38,7 +38,7 @@ var searchData=
   ['strcmpt_3c_20char8_20_3e_35',['strcmpT&lt; char8 &gt;',['../namespaceSteinberg.html#a9c04924e4e7bafc6162173aa938ce7ae',1,'Steinberg']]],
   ['strcpy16_36',['strcpy16',['../namespaceSteinberg.html#a1f2971e00b71425e2035c4f946031fd9',1,'Steinberg']]],
   ['strcpy8_37',['strcpy8',['../namespaceSteinberg.html#a79cc5b78e482b56ee792dac1fa4ddc1b',1,'Steinberg']]],
-  ['strempty_38',['strEmpty',['../namespaceSteinberg.html#a6a838f230987e1a095b0cb75c28d4a65',1,'Steinberg']]],
+  ['strempty_38',['strEmpty',['../group__smtgtypedef.html#ga6a838f230987e1a095b0cb75c28d4a65',1,'Steinberg']]],
   ['stringcopy_39',['StringCopy',['../namespaceSteinberg.html#a51c63740ab18a5e8a1394fb10e743917',1,'Steinberg']]],
   ['stringlength_40',['StringLength',['../namespaceSteinberg.html#ae6cdc2936b352ab9cd2fb6aed350bbaa',1,'Steinberg']]],
   ['stripalpha_41',['StripAlpha',['../namespaceSteinberg.html#a27f6f9da6429b67343a7e36078494bd9',1,'Steinberg']]],
