@@ -1,11 +1,11 @@
 var searchData=
 [
-  ['iattrid_0',['IAttrID',['../namespaceSteinberg.html#ae6eacc17e4382538d4af0d9993bc869a',1,'Steinberg']]],
+  ['iattrid_0',['IAttrID',['../group__smtgtypedef.html#gae6eacc17e4382538d4af0d9993bc869a',1,'Steinberg']]],
   ['iid_1',['iid',['../structSteinberg_1_1FUnknownImpl_1_1HideIIDBase.html#af1c6ceaa3ae7a38295c19fd4994af35d',1,'Steinberg::FUnknownImpl::HideIIDBase']]],
   ['implements_2',['Implements',['../namespaceSteinberg_1_1FUnknownImpl.html#aa97fe0c3b9d688a3e43da776dec431c6',1,'Steinberg::FUnknownImpl::Implements'],['../namespaceSteinberg_1_1U.html#aa97fe0c3b9d688a3e43da776dec431c6',1,'Steinberg::U::Implements']]],
   ['implementsnondestroyable_3',['ImplementsNonDestroyable',['../namespaceSteinberg_1_1FUnknownImpl.html#a33d524a00593b41664bf5a7be2aaf204',1,'Steinberg::FUnknownImpl::ImplementsNonDestroyable'],['../namespaceSteinberg_1_1U.html#a33d524a00593b41664bf5a7be2aaf204',1,'Steinberg::U::ImplementsNonDestroyable']]],
-  ['int16_4',['int16',['../namespaceSteinberg.html#aa0d0fdc87fd135ef2bedb030901cdb9c',1,'Steinberg']]],
-  ['int32_5',['int32',['../namespaceSteinberg.html#ab7903878916593daecbeb95b98115ab0',1,'Steinberg']]],
-  ['int64_6',['int64',['../namespaceSteinberg.html#a7cde0074dfd288f2d70c0e035dacb28a',1,'Steinberg']]],
-  ['int8_7',['int8',['../namespaceSteinberg.html#ae47c588f3ab8c61121c1c7ab7edc47cd',1,'Steinberg']]]
+  ['int16_4',['int16',['../group__smtgtypedef.html#gaa0d0fdc87fd135ef2bedb030901cdb9c',1,'Steinberg']]],
+  ['int32_5',['int32',['../group__smtgtypedef.html#gab7903878916593daecbeb95b98115ab0',1,'Steinberg']]],
+  ['int64_6',['int64',['../group__smtgtypedef.html#ga7cde0074dfd288f2d70c0e035dacb28a',1,'Steinberg']]],
+  ['int8_7',['int8',['../group__smtgtypedef.html#gae47c588f3ab8c61121c1c7ab7edc47cd',1,'Steinberg']]]
 ];
