@@ -4,6 +4,6 @@ var ustring_8h =
     [ "UStringBuffer< maxSize >", "classSteinberg_1_1UStringBuffer.html", "classSteinberg_1_1UStringBuffer" ],
     [ "USTRING", "ustring_8h.html#ac5f8dfe73b55c4ec26f12c071d67bffb", null ],
     [ "USTRINGSIZE", "ustring_8h.html#abbca26150973e505a5e42d3854b49750", null ],
-    [ "UString128", "namespaceSteinberg.html#aa92186fdeda699e7a0cc7ac6c45d07e5", null ],
-    [ "UString256", "namespaceSteinberg.html#a71098a25fa252b10d271a11807153385", null ]
+    [ "UString128", "group__smtgtypedef.html#gaa92186fdeda699e7a0cc7ac6c45d07e5", null ],
+    [ "UString256", "group__smtgtypedef.html#ga71098a25fa252b10d271a11807153385", null ]
 ];
\ No newline at end of file
