@@ -8,5 +8,5 @@ var fcleanup_8h =
     [ "FConditionalBoolSetter", "structSteinberg_1_1FConditionalBoolSetter.html", "structSteinberg_1_1FConditionalBoolSetter" ],
     [ "FCloser< T >", "structSteinberg_1_1FCloser.html", "structSteinberg_1_1FCloser" ],
     [ "FMallocReleaser", "classSteinberg_1_1FMallocReleaser.html", "classSteinberg_1_1FMallocReleaser" ],
-    [ "FBoolSetter", "fcleanup_8h.html#aac248a0d0bf4446d45f2539bc61f6c23", null ]
+    [ "FBoolSetter", "namespaceSteinberg.html#aac248a0d0bf4446d45f2539bc61f6c23", null ]
 ];
\ No newline at end of file
