@@ -4,5 +4,5 @@ var searchData=
   ['singletonslock_1',['singletonsLock',['../namespaceSteinberg_1_1Singleton.html#ac67df8722321fe3f07d688a9710006cc',1,'Steinberg::Singleton']]],
   ['singletonsterminated_2',['singletonsTerminated',['../namespaceSteinberg_1_1Singleton.html#ae52f18a708ab305abe54c48ffc1c9840',1,'Steinberg::Singleton']]],
   ['sizepos_3',['sizePos',['../classSteinberg_1_1FStreamSizeHolder.html#a4ed2befe00e711ba9345b04f59d18a69',1,'Steinberg::FStreamSizeHolder']]],
-  ['stream_4',['stream',['../classSteinberg_1_1FStreamSizeHolder.html#a826abaebde6da276f12b3250c52ad90a',1,'Steinberg::FStreamSizeHolder::stream()'],['../classSteinberg_1_1IBStreamer.html#a78d49eed9e150f042fe1e0434fb52102',1,'Steinberg::IBStreamer::stream()']]]
+  ['stream_4',['stream',['../classSteinberg_1_1FStreamSizeHolder.html#a826abaebde6da276f12b3250c52ad90a',1,'Steinberg::FStreamSizeHolder::stream'],['../classSteinberg_1_1IBStreamer.html#a78d49eed9e150f042fe1e0434fb52102',1,'Steinberg::IBStreamer::stream']]]
 ];
