@@ -1,6 +1,6 @@
 var dir_997002628ac0d8cc9747337628191a72 =
 [
-    [ "panner/source/plugcontroller.cpp", "panner_2source_2plugcontroller_8cpp.html", null ],
+    [ "plugcontroller.cpp", "panner_2source_2plugcontroller_8cpp.html", null ],
     [ "plugfactory.cpp", "plugfactory_8cpp.html", "plugfactory_8cpp" ],
     [ "plugprocessor.cpp", "plugprocessor_8cpp.html", "plugprocessor_8cpp" ]
 ];
\ No newline at end of file
