@@ -2,7 +2,7 @@ var hostcheckercontroller_8h =
 [
     [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", "classSteinberg_1_1Vst_1_1HostCheckerController" ],
     [ "ScoreEntry", "structSteinberg_1_1Vst_1_1HostCheckerController_1_1ScoreEntry.html", "structSteinberg_1_1Vst_1_1HostCheckerController_1_1ScoreEntry" ],
-    [ "kMaxLatency", "namespaceSteinberg_1_1HostChecker.html#ae3d4ad032b2586752aaefe7d98b3b352", null ],
+    [ "kMaxLatencyInSeconds", "namespaceSteinberg_1_1HostChecker.html#a475b7b89c7a9ef6b0f0590fa64e3ec0b", null ],
     [ "kParamWarnCount", "namespaceSteinberg_1_1HostChecker.html#a82a59297717d21868266e8a4fd1da4f0", null ],
     [ "kParamWarnBitCount", "namespaceSteinberg_1_1HostChecker.html#a72e8435dc9b0315802adde434a4fcd14", null ],
     [ "kParamWarnStepCount", "namespaceSteinberg_1_1HostChecker.html#a4bc22a30a6391416bcaa23b915d31916", null ],
