@@ -3,5 +3,5 @@ var mdaBaseProcessor_8h =
     [ "Processor", "classSteinberg_1_1Vst_1_1mda_1_1Processor.html", "classSteinberg_1_1Vst_1_1mda_1_1Processor" ],
     [ "SampleAccurateBaseProcessor", "classSteinberg_1_1Vst_1_1mda_1_1SampleAccurateBaseProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1SampleAccurateBaseProcessor" ],
     [ "SynthData< VoiceT, kEventBufferSize, kNumVoices >", "structSteinberg_1_1Vst_1_1mda_1_1SynthData.html", "structSteinberg_1_1Vst_1_1mda_1_1SynthData" ],
-    [ "BaseProcessor", "mdaBaseProcessor_8h.html#aa0936cf0a422e298f98238f76edfcc44", null ]
+    [ "BaseProcessor", "namespaceSteinberg_1_1Vst_1_1mda.html#aa0936cf0a422e298f98238f76edfcc44", null ]
 ];
\ No newline at end of file
