@@ -70,31 +70,31 @@ var NAVTREEINDEX =
 "VSTInterAppAudioAppDelegate_8h.html",
 "classSteinberg_1_1Vst_1_1AGain.html#ad48c36f6210f722d195a93f68fb7dff4",
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#af161b55b382c62c4868a760fff750cd0",
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#a4c975cd547adc38bc800fddc7f8a2954a29851866e68dd8cf8111d40879ec848c",
-"classSteinberg_1_1Vst_1_1Plug.html#a4dae123b5697706651d9ff20c9614f63",
-"classSteinberg_1_1Vst_1_1VoiceBase.html#a62774a81bf875a00321b2974ee87d4f9",
-"classSteinberg_1_1Vst_1_1mda_1_1BeatBoxController.html#a0114d51b222e8663f93dc0a8f1afb095",
-"classSteinberg_1_1Vst_1_1mda_1_1ComboProcessor.html#af886660e87d29c40f1ca26f5fe065ad3",
-"classSteinberg_1_1Vst_1_1mda_1_1DegradeProcessor.html#ab756503ec7eb8340aae55ee1455b31ae",
-"classSteinberg_1_1Vst_1_1mda_1_1DubDelayController.html#a6d2a1929151bc7086c493054f3a7be85a7ca1e7303f91236e87a28d0da99ce499",
-"classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html#ac16ff5312692ef65aaadddac31421aeb",
-"classSteinberg_1_1Vst_1_1mda_1_1LeslieController.html#a6d2a1929151bc7086c493054f3a7be85a4b064a62c3d4542e876b5111292b6f2d",
-"classSteinberg_1_1Vst_1_1mda_1_1MultiBandProcessor.html#a8cb865e4b76909b24401f9f68be53839",
-"classSteinberg_1_1Vst_1_1mda_1_1Processor.html#af8b29edd2aa8b0f1efd6fe304f98c445",
-"classSteinberg_1_1Vst_1_1mda_1_1SampleAccurateBaseProcessor.html#a009053d0bf0fe9fb13b29fc3155e8b8c",
-"classSteinberg_1_1Vst_1_1mda_1_1StereoProcessor.html#a18a9ddb1c64491ea2cfbebfd2c7c01b9",
-"classSteinberg_1_1Vst_1_1mda_1_1TestToneProcessor.html#ad36303b43802391ea41993be94178770",
-"classVSTGUI_1_1NoteTouchController.html#ae184ac69ed767b0c43c94f63244a5b67",
-"group__musicalCharacter.html#gaa57323ce9c0b4d417c6b36aa76570514",
-"group__plugType.html#ga0759e804603c37125d02cbc3b091f03b",
-"group__speakerArrangements.html#ga7da30e8a25cd20fc4b44a292368092fc",
-"index.html#Panner",
-"main_8m.html",
-"namespaceSteinberg.html#a743f60968fa58cdae68b31a1a3eb493da7dee5096e7803ac26cee7abe740d777d",
-"namespaceSteinberg_1_1Vst.html#a3e856c7ffbe25183e8d732833ec765d5",
-"namespaceSteinberg_1_1Vst_1_1NoteExpressionSynth.html#a1ce3513d3c756afe6a0aecc8b8e7d45da0ac26f0bf0461b55b596412ebb5c25b5",
-"structSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1GlobalParameterState.html#a27e13d4bf656b836f731506edd58ab83",
-"structSteinberg_1_1Vst_1_1mda_1_1SynthData.html#a02e33118d5f5843bb2b6e0e5884ca8fc"
+"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1BrownNoise.html#ac52d4064d6e6e1bd930dbc2441186982",
+"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Voice.html#aa22fe57240f981f1281e79a8594ce22d",
+"classSteinberg_1_1Vst_1_1Validator.html#a5552f3d766a2708d4f59dc2ca9865dc9",
+"classSteinberg_1_1Vst_1_1mda_1_1BandistoProcessor.html#ad79aca159f5b0f497390712b7b25e612",
+"classSteinberg_1_1Vst_1_1mda_1_1ComboProcessor.html#a54bb422651082c044af95480c18560f4",
+"classSteinberg_1_1Vst_1_1mda_1_1DegradeController.html#a813cbf9dee7a64708f56160974dd37b0",
+"classSteinberg_1_1Vst_1_1mda_1_1DitherProcessor.html#a1258bcc56d4d2dcb7a975b99d0432621",
+"classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html#a4c91e0151586bd9b21bc4e486d4b44b6",
+"classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html#ac16ff5312692ef65aaadddac31421aeb",
+"classSteinberg_1_1Vst_1_1mda_1_1LoudnessProcessor.html#ad48c36f6210f722d195a93f68fb7dff4",
+"classSteinberg_1_1Vst_1_1mda_1_1Processor.html#a52e68c247fe30358749ecf046b6ec577",
+"classSteinberg_1_1Vst_1_1mda_1_1RingModProcessor.html#a80b09ba6d56f803698722f396fff6329",
+"classSteinberg_1_1Vst_1_1mda_1_1SplitterProcessor.html#a4b4c1671e848c3debb26cc1fd9c0de77",
+"classSteinberg_1_1Vst_1_1mda_1_1TestToneController.html#ab9e4a07e520c19780b66a682829c706c",
+"classVSTGUI_1_1EventLogDataBrowserSource.html#abde7a8563e0588638005573e0aace4ae",
+"globals_eval.html",
+"group__musicalStyle.html#ga817fef9aabf571d6f91e357efc677040",
+"group__speakerArrangements.html#ga55be9946868c6ffe425dbdd9abc70843",
+"group__speakerArrangements.html#gaec8cf18e8bfd88584375e66b67fde24e",
+"logevents_8h.html#afc84f29132b630b33d341d0769a66d46ab40d3f236012290e3b1572368e095bf4",
+"namespaceSteinberg.html#a0a5776df696f816f7fcc81666e242d81",
+"namespaceSteinberg_1_1KeyCodes.html#a1411be7b25f47e89beedadd3de3ade07",
+"namespaceSteinberg_1_1Vst_1_1CurveType.html",
+"prefetchablesupport_2source_2plugentry_8cpp.html#a29707ed5621830ba9ca420b63a42b48d",
+"structSteinberg_1_1Vst_1_1mda_1_1JX10Processor_1_1VOICE.html#ae9394312428df4f88947d8ab1fceac56"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronization';
