@@ -18,7 +18,7 @@ var searchData=
   ['l4_5f2_15',['l4_2',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a42262067506945b6c6b7f20499a58283',1,'Steinberg::FUnknownImpl::UID::l4_2'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a42262067506945b6c6b7f20499a58283',1,'Steinberg::U::UID::l4_2']]],
   ['l4_5f3_16',['l4_3',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585afdf8e144b07277b747cd719cd5e90fbb',1,'Steinberg::FUnknownImpl::UID::l4_3'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585afdf8e144b07277b747cd719cd5e90fbb',1,'Steinberg::U::UID::l4_3']]],
   ['l4_5f4_17',['l4_4',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a7bbddf97f369fb4059a743b4826fafa6',1,'Steinberg::FUnknownImpl::UID::l4_4'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a7bbddf97f369fb4059a743b4826fafa6',1,'Steinberg::U::UID::l4_4']]],
-  ['large_5fint_18',['LARGE_INT',['../../base/namespaceSteinberg.html#a9cd1730908299276af7bc0baa8c5197e',1,'Steinberg']]],
+  ['large_5fint_18',['LARGE_INT',['../../base/group__smtgtypedef.html#ga9cd1730908299276af7bc0baa8c5197e',1,'Steinberg']]],
   ['lastnote_19',['lastnote',['../classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html#a1218aeb20cac0f3c0a7ed459b11572c7',1,'Steinberg::Vst::mda::JX10Processor']]],
   ['lastpreset_20',['lastPreset',['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a46ad71fcafe9288a61041dd87173d9a6',1,'Steinberg::Vst::InterAppAudio::PresetManager']]],
   ['ldel_21',['ldel',['../classSteinberg_1_1Vst_1_1mda_1_1DelayProcessor.html#ade07a3997e8ab6e7f618f6e07b70853e',1,'Steinberg::Vst::mda::DelayProcessor']]],
