@@ -50,5 +50,5 @@ var searchData=
   ['twopi_47',['twopi',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#a331c522690e3ec54032538f9c9272fa1',1,'Steinberg::Vst::mda::LeslieProcessor']]],
   ['typ_48',['typ',['../classSteinberg_1_1Vst_1_1mda_1_1SubSynthProcessor.html#a79c60dc7aff717516ce6b2a252bb7f6e',1,'Steinberg::Vst::mda::SubSynthProcessor']]],
   ['type_49',['type',['../../base/classSteinberg_1_1FVariant.html#af9b2e23a8f32ca09cfeb7d828436fb01',1,'Steinberg::FVariant::type'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1DataEvent.html#af356674bbaaf9bb782af79059eef1346',1,'Steinberg::Vst::DataEvent::type'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#af9b2e23a8f32ca09cfeb7d828436fb01',1,'Steinberg::Vst::Event::type'],['../../vstsdk/classSteinberg_1_1Vst_1_1BusList.html#a9efc310404a7d775d72cc8974e5e3b58',1,'Steinberg::Vst::BusList::type'],['../classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Filter.html#ab6f4e6d3fde00ce906e46494f60dfe7a',1,'Steinberg::Vst::NoteExpressionSynth::Filter::type']]],
-  ['typeid_50',['typeId',['../../vstinterfaces/structSteinberg_1_1Vst_1_1KeyswitchInfo.html#adc03aa09c3341a6a08543d04e31897ef',1,'Steinberg::Vst::KeyswitchInfo::typeId'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionTextEvent.html#a8cecee2171d29eb98141c9364baa346e',1,'Steinberg::Vst::NoteExpressionTextEvent::typeId'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html#a8cecee2171d29eb98141c9364baa346e',1,'Steinberg::Vst::NoteExpressionTypeInfo::typeId'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionValueEvent.html#a8cecee2171d29eb98141c9364baa346e',1,'Steinberg::Vst::NoteExpressionValueEvent::typeId']]]
+  ['typeid_50',['typeId',['../../vstinterfaces/structSteinberg_1_1Vst_1_1KeyswitchInfo.html#adc03aa09c3341a6a08543d04e31897ef',1,'Steinberg::Vst::KeyswitchInfo::typeId'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionIntValueEvent.html#a8cecee2171d29eb98141c9364baa346e',1,'Steinberg::Vst::NoteExpressionIntValueEvent::typeId'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionTextEvent.html#a8cecee2171d29eb98141c9364baa346e',1,'Steinberg::Vst::NoteExpressionTextEvent::typeId'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html#a8cecee2171d29eb98141c9364baa346e',1,'Steinberg::Vst::NoteExpressionTypeInfo::typeId'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionValueEvent.html#a8cecee2171d29eb98141c9364baa346e',1,'Steinberg::Vst::NoteExpressionValueEvent::typeId']]]
 ];
