@@ -11,6 +11,7 @@ var annotated_dup =
         [ "CubicBezierTimingFunction", "class_v_s_t_g_u_i_1_1_animation_1_1_cubic_bezier_timing_function.html", "class_v_s_t_g_u_i_1_1_animation_1_1_cubic_bezier_timing_function" ],
         [ "ExchangeViewAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_exchange_view_animation.html", "class_v_s_t_g_u_i_1_1_animation_1_1_exchange_view_animation" ],
         [ "FinishedMessage", "class_v_s_t_g_u_i_1_1_animation_1_1_finished_message.html", "class_v_s_t_g_u_i_1_1_animation_1_1_finished_message" ],
+        [ "FuncAnimation", "class_v_s_t_g_u_i_1_1_animation_1_1_func_animation.html", "class_v_s_t_g_u_i_1_1_animation_1_1_func_animation" ],
         [ "IAnimationTarget", "class_v_s_t_g_u_i_1_1_animation_1_1_i_animation_target.html", "class_v_s_t_g_u_i_1_1_animation_1_1_i_animation_target" ],
         [ "InterpolationTimingFunction", "class_v_s_t_g_u_i_1_1_animation_1_1_interpolation_timing_function.html", "class_v_s_t_g_u_i_1_1_animation_1_1_interpolation_timing_function" ],
         [ "ITimingFunction", "class_v_s_t_g_u_i_1_1_animation_1_1_i_timing_function.html", "class_v_s_t_g_u_i_1_1_animation_1_1_i_timing_function" ],
@@ -83,6 +84,7 @@ var annotated_dup =
         [ "IStepValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_step_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_step_value" ],
         [ "IStringListValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_list_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_list_value" ],
         [ "IStringValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_value" ],
+        [ "IUIDescWindowController", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_u_i_desc_window_controller.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_u_i_desc_window_controller" ],
         [ "IValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value" ],
         [ "IValueConverter", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_converter.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_converter" ],
         [ "IValueListener", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_listener.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_listener" ],
@@ -99,6 +101,25 @@ var annotated_dup =
         [ "WindowListenerAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_listener_adapter.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_listener_adapter" ],
         [ "WindowStyle", "struct_v_s_t_g_u_i_1_1_standalone_1_1_window_style.html", "struct_v_s_t_g_u_i_1_1_standalone_1_1_window_style" ]
       ] ],
+      [ "TextEditor", "namespace_v_s_t_g_u_i_1_1_text_editor.html", [
+        [ "FindPanelController", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_find_panel_controller.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_find_panel_controller" ],
+        [ "Key", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_key.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_key" ],
+        [ "Line", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_line.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_line" ],
+        [ "LineNumberView", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_line_number_view.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_line_number_view" ],
+        [ "NewLineProcessor", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_new_line_processor.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_new_line_processor" ],
+        [ "Range", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_range.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_range" ],
+        [ "STB_TexteditState", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_s_t_b___textedit_state.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_s_t_b___textedit_state" ],
+        [ "StbFindState", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_find_state.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_find_state" ],
+        [ "StbTexteditRow", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_textedit_row.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_textedit_row" ],
+        [ "StbUndoRecord", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_undo_record.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_undo_record" ],
+        [ "StbUndoState", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_undo_state.html", null ],
+        [ "TextEditorView", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_editor_view.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_editor_view" ],
+        [ "TextModel", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_model.html", "struct_v_s_t_g_u_i_1_1_text_editor_1_1_text_model" ]
+      ] ],
+      [ "TextEditorColorization", "namespace_v_s_t_g_u_i_1_1_text_editor_colorization.html", [
+        [ "IEditorExt", "struct_v_s_t_g_u_i_1_1_text_editor_colorization_1_1_i_editor_ext.html", "struct_v_s_t_g_u_i_1_1_text_editor_colorization_1_1_i_editor_ext" ],
+        [ "IStyleProvider", "struct_v_s_t_g_u_i_1_1_text_editor_colorization_1_1_i_style_provider.html", "struct_v_s_t_g_u_i_1_1_text_editor_colorization_1_1_i_style_provider" ]
+      ] ],
       [ "UIDescriptionPrivate", "namespace_v_s_t_g_u_i_1_1_u_i_description_private.html", [
         [ "StringToken", "class_v_s_t_g_u_i_1_1_u_i_description_private_1_1_string_token.html", "class_v_s_t_g_u_i_1_1_u_i_description_private_1_1_string_token" ]
       ] ],
@@ -150,7 +171,10 @@ var annotated_dup =
       ] ],
       [ "AEffGUIEditor", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor.html", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor" ],
       [ "AspectRatioVST3Editor", "class_v_s_t_g_u_i_1_1_aspect_ratio_v_s_t3_editor.html", "class_v_s_t_g_u_i_1_1_aspect_ratio_v_s_t3_editor" ],
+      [ "AutoSizeViewLayouter", "struct_v_s_t_g_u_i_1_1_auto_size_view_layouter.html", "struct_v_s_t_g_u_i_1_1_auto_size_view_layouter" ],
       [ "Base64Codec", "class_v_s_t_g_u_i_1_1_base64_codec.html", "class_v_s_t_g_u_i_1_1_base64_codec" ],
+      [ "BaseViewLayouter", "class_v_s_t_g_u_i_1_1_base_view_layouter.html", "class_v_s_t_g_u_i_1_1_base_view_layouter" ],
+      [ "BaseViewLayouterEntry", "struct_v_s_t_g_u_i_1_1_base_view_layouter_entry.html", "struct_v_s_t_g_u_i_1_1_base_view_layouter_entry" ],
       [ "BitScopeToggleT", "struct_v_s_t_g_u_i_1_1_bit_scope_toggle_t.html", "struct_v_s_t_g_u_i_1_1_bit_scope_toggle_t" ],
       [ "Buffer", "class_v_s_t_g_u_i_1_1_buffer.html", "class_v_s_t_g_u_i_1_1_buffer" ],
       [ "BufferedOutputStream", "class_v_s_t_g_u_i_1_1_buffered_output_stream.html", "class_v_s_t_g_u_i_1_1_buffered_output_stream" ],
@@ -233,6 +257,7 @@ var annotated_dup =
       [ "CSpecialDigit", "class_v_s_t_g_u_i_1_1_c_special_digit.html", "class_v_s_t_g_u_i_1_1_c_special_digit" ],
       [ "CSplashScreen", "class_v_s_t_g_u_i_1_1_c_splash_screen.html", "class_v_s_t_g_u_i_1_1_c_splash_screen" ],
       [ "CSplitView", "class_v_s_t_g_u_i_1_1_c_split_view.html", "class_v_s_t_g_u_i_1_1_c_split_view" ],
+      [ "CSSNamedColor", "struct_v_s_t_g_u_i_1_1_c_s_s_named_color.html", "struct_v_s_t_g_u_i_1_1_c_s_s_named_color" ],
       [ "CSwitchBase", "class_v_s_t_g_u_i_1_1_c_switch_base.html", "class_v_s_t_g_u_i_1_1_c_switch_base" ],
       [ "CTabView", "class_v_s_t_g_u_i_1_1_c_tab_view.html", "class_v_s_t_g_u_i_1_1_c_tab_view" ],
       [ "CTextButton", "class_v_s_t_g_u_i_1_1_c_text_button.html", "class_v_s_t_g_u_i_1_1_c_text_button" ],
@@ -257,6 +282,7 @@ var annotated_dup =
       [ "DragEventData", "struct_v_s_t_g_u_i_1_1_drag_event_data.html", "struct_v_s_t_g_u_i_1_1_drag_event_data" ],
       [ "DragStartMouseObserver", "struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html", "struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer" ],
       [ "DropTargetAdapter", "class_v_s_t_g_u_i_1_1_drop_target_adapter.html", "class_v_s_t_g_u_i_1_1_drop_target_adapter" ],
+      [ "EnumBitset", "struct_v_s_t_g_u_i_1_1_enum_bitset.html", "struct_v_s_t_g_u_i_1_1_enum_bitset" ],
       [ "ERect", "struct_v_s_t_g_u_i_1_1_e_rect.html", "struct_v_s_t_g_u_i_1_1_e_rect" ],
       [ "Event", "struct_v_s_t_g_u_i_1_1_event.html", "struct_v_s_t_g_u_i_1_1_event" ],
       [ "EventConsumeState", "struct_v_s_t_g_u_i_1_1_event_consume_state.html", "struct_v_s_t_g_u_i_1_1_event_consume_state" ],
@@ -267,6 +293,8 @@ var annotated_dup =
       [ "GestureEvent", "struct_v_s_t_g_u_i_1_1_gesture_event.html", "struct_v_s_t_g_u_i_1_1_gesture_event" ],
       [ "GetViewOptions", "struct_v_s_t_g_u_i_1_1_get_view_options.html", "struct_v_s_t_g_u_i_1_1_get_view_options" ],
       [ "GlobalFonts", "struct_v_s_t_g_u_i_1_1_global_fonts.html", "struct_v_s_t_g_u_i_1_1_global_fonts" ],
+      [ "GridLayouter", "class_v_s_t_g_u_i_1_1_grid_layouter.html", "class_v_s_t_g_u_i_1_1_grid_layouter" ],
+      [ "GridLayoutProperties", "struct_v_s_t_g_u_i_1_1_grid_layout_properties.html", "struct_v_s_t_g_u_i_1_1_grid_layout_properties" ],
       [ "GroupController", "class_v_s_t_g_u_i_1_1_group_controller.html", "class_v_s_t_g_u_i_1_1_group_controller" ],
       [ "IBitmapCreator", "class_v_s_t_g_u_i_1_1_i_bitmap_creator.html", "class_v_s_t_g_u_i_1_1_i_bitmap_creator" ],
       [ "IBitmapCreator2", "class_v_s_t_g_u_i_1_1_i_bitmap_creator2.html", "class_v_s_t_g_u_i_1_1_i_bitmap_creator2" ],
@@ -301,13 +329,18 @@ var annotated_dup =
       [ "ISplitViewController", "class_v_s_t_g_u_i_1_1_i_split_view_controller.html", "class_v_s_t_g_u_i_1_1_i_split_view_controller" ],
       [ "ISplitViewSeparatorDrawer", "class_v_s_t_g_u_i_1_1_i_split_view_separator_drawer.html", "class_v_s_t_g_u_i_1_1_i_split_view_separator_drawer" ],
       [ "ITextEditListener", "class_v_s_t_g_u_i_1_1_i_text_edit_listener.html", "class_v_s_t_g_u_i_1_1_i_text_edit_listener" ],
+      [ "ITextEditor", "struct_v_s_t_g_u_i_1_1_i_text_editor.html", "struct_v_s_t_g_u_i_1_1_i_text_editor" ],
+      [ "ITextEditorController", "struct_v_s_t_g_u_i_1_1_i_text_editor_controller.html", "struct_v_s_t_g_u_i_1_1_i_text_editor_controller" ],
       [ "ITextLabelListener", "class_v_s_t_g_u_i_1_1_i_text_label_listener.html", "class_v_s_t_g_u_i_1_1_i_text_label_listener" ],
       [ "IUIDescription", "class_v_s_t_g_u_i_1_1_i_u_i_description.html", "class_v_s_t_g_u_i_1_1_i_u_i_description" ],
+      [ "IUIDescriptionAddOn", "struct_v_s_t_g_u_i_1_1_i_u_i_description_add_on.html", "struct_v_s_t_g_u_i_1_1_i_u_i_description_add_on" ],
       [ "IViewAddedRemovedObserver", "class_v_s_t_g_u_i_1_1_i_view_added_removed_observer.html", "class_v_s_t_g_u_i_1_1_i_view_added_removed_observer" ],
       [ "IViewContainerListener", "class_v_s_t_g_u_i_1_1_i_view_container_listener.html", "class_v_s_t_g_u_i_1_1_i_view_container_listener" ],
       [ "IViewCreator", "class_v_s_t_g_u_i_1_1_i_view_creator.html", "class_v_s_t_g_u_i_1_1_i_view_creator" ],
       [ "IViewEventListener", "class_v_s_t_g_u_i_1_1_i_view_event_listener.html", "class_v_s_t_g_u_i_1_1_i_view_event_listener" ],
       [ "IViewFactory", "class_v_s_t_g_u_i_1_1_i_view_factory.html", "class_v_s_t_g_u_i_1_1_i_view_factory" ],
+      [ "IViewFactoryEditingSupport", "class_v_s_t_g_u_i_1_1_i_view_factory_editing_support.html", "class_v_s_t_g_u_i_1_1_i_view_factory_editing_support" ],
+      [ "IViewLayouter", "class_v_s_t_g_u_i_1_1_i_view_layouter.html", "class_v_s_t_g_u_i_1_1_i_view_layouter" ],
       [ "IViewListener", "class_v_s_t_g_u_i_1_1_i_view_listener.html", "class_v_s_t_g_u_i_1_1_i_view_listener" ],
       [ "IViewMouseListener", "class_v_s_t_g_u_i_1_1_i_view_mouse_listener.html", "class_v_s_t_g_u_i_1_1_i_view_mouse_listener" ],
       [ "IViewSwitchController", "class_v_s_t_g_u_i_1_1_i_view_switch_controller.html", "class_v_s_t_g_u_i_1_1_i_view_switch_controller" ],
@@ -331,6 +364,7 @@ var annotated_dup =
       [ "MouseUpEvent", "struct_v_s_t_g_u_i_1_1_mouse_up_event.html", "struct_v_s_t_g_u_i_1_1_mouse_up_event" ],
       [ "MouseWheelEvent", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event" ],
       [ "MultiFrameBitmapView", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view" ],
+      [ "NoViewLayouter", "struct_v_s_t_g_u_i_1_1_no_view_layouter.html", "struct_v_s_t_g_u_i_1_1_no_view_layouter" ],
       [ "OldKeyboardHookAdapter", "class_v_s_t_g_u_i_1_1_old_keyboard_hook_adapter.html", "class_v_s_t_g_u_i_1_1_old_keyboard_hook_adapter" ],
       [ "OldMouseObserverAdapter", "class_v_s_t_g_u_i_1_1_old_mouse_observer_adapter.html", "class_v_s_t_g_u_i_1_1_old_mouse_observer_adapter" ],
       [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html", "struct_v_s_t_g_u_i_1_1_optional" ],
@@ -347,10 +381,13 @@ var annotated_dup =
       [ "StdOutStream", "class_v_s_t_g_u_i_1_1_std_out_stream.html", "class_v_s_t_g_u_i_1_1_std_out_stream" ],
       [ "StringListControlDrawer", "class_v_s_t_g_u_i_1_1_string_list_control_drawer.html", "class_v_s_t_g_u_i_1_1_string_list_control_drawer" ],
       [ "TextEditListenerAdapter", "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter.html", "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter" ],
+      [ "TextEditorControllerAdapter", "struct_v_s_t_g_u_i_1_1_text_editor_controller_adapter.html", "struct_v_s_t_g_u_i_1_1_text_editor_controller_adapter" ],
       [ "TextLabelListenerAdapter", "class_v_s_t_g_u_i_1_1_text_label_listener_adapter.html", "class_v_s_t_g_u_i_1_1_text_label_listener_adapter" ],
       [ "TrimOptions", "struct_v_s_t_g_u_i_1_1_trim_options.html", "struct_v_s_t_g_u_i_1_1_trim_options" ],
       [ "UIAttributes", "class_v_s_t_g_u_i_1_1_u_i_attributes.html", "class_v_s_t_g_u_i_1_1_u_i_attributes" ],
       [ "UIDescription", "class_v_s_t_g_u_i_1_1_u_i_description.html", "class_v_s_t_g_u_i_1_1_u_i_description" ],
+      [ "UIDescriptionAddOnAdapter", "struct_v_s_t_g_u_i_1_1_u_i_description_add_on_adapter.html", "struct_v_s_t_g_u_i_1_1_u_i_description_add_on_adapter" ],
+      [ "UIDescriptionAddOnRegistry", "class_v_s_t_g_u_i_1_1_u_i_description_add_on_registry.html", "class_v_s_t_g_u_i_1_1_u_i_description_add_on_registry" ],
       [ "UIDescriptionListener", "class_v_s_t_g_u_i_1_1_u_i_description_listener.html", "class_v_s_t_g_u_i_1_1_u_i_description_listener" ],
       [ "UIDescriptionListenerAdapter", "class_v_s_t_g_u_i_1_1_u_i_description_listener_adapter.html", "class_v_s_t_g_u_i_1_1_u_i_description_listener_adapter" ],
       [ "UIDescriptionListenerOff", "struct_v_s_t_g_u_i_1_1_u_i_description_listener_off.html", "struct_v_s_t_g_u_i_1_1_u_i_description_listener_off" ],
@@ -365,6 +402,8 @@ var annotated_dup =
       [ "ViewCreatorAdapter", "class_v_s_t_g_u_i_1_1_view_creator_adapter.html", "class_v_s_t_g_u_i_1_1_view_creator_adapter" ],
       [ "ViewCreatorRegistry", "class_v_s_t_g_u_i_1_1_view_creator_registry.html", "class_v_s_t_g_u_i_1_1_view_creator_registry" ],
       [ "ViewEventListenerAdapter", "class_v_s_t_g_u_i_1_1_view_event_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_event_listener_adapter" ],
+      [ "ViewFactoryDelegate", "class_v_s_t_g_u_i_1_1_view_factory_delegate.html", "class_v_s_t_g_u_i_1_1_view_factory_delegate" ],
+      [ "ViewLayout", "struct_v_s_t_g_u_i_1_1_view_layout.html", "struct_v_s_t_g_u_i_1_1_view_layout" ],
       [ "ViewListenerAdapter", "class_v_s_t_g_u_i_1_1_view_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_listener_adapter" ],
       [ "ViewMouseListenerAdapter", "class_v_s_t_g_u_i_1_1_view_mouse_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_mouse_listener_adapter" ],
       [ "VST3Editor", "class_v_s_t_g_u_i_1_1_v_s_t3_editor.html", "class_v_s_t_g_u_i_1_1_v_s_t3_editor" ],
