@@ -25,6 +25,7 @@ var group__containerviews =
         [ "focusViewObservers", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a3b07e17f5a81a5c5ae52068b87704a53", null ],
         [ "inEventHandling", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#af0f1c42638a3e4adb3a8b8607c6c24a6", null ],
         [ "keyboardHooks", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#aab454e846ff98f312a168529bef56559", null ],
+        [ "lastCheckSizeConstraintLayout", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a0384febec4674eef67dc56d4d22118a9", null ],
         [ "legacyModalViewSessionID", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#ae3e4b8c00985c2b3d8ab9da711d6f542", null ],
         [ "modalViewSessionIDCounter", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a190ea2debf9e9b8f762f20615fb71bf9", null ],
         [ "modalViewSessionStack", "struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#afc68799e7aad13c2788ea971e1e1e215", null ],
@@ -53,6 +54,7 @@ var group__containerviews =
       [ "callMouseObserverMouseExited", "class_v_s_t_g_u_i_1_1_c_frame.html#a8f97b9b5fe74666c47d1c374f265e60d", null ],
       [ "callMouseObserverOtherMouseEvent", "class_v_s_t_g_u_i_1_1_c_frame.html#a3402a32a2fd0efbfb2c3023bb151c025", null ],
       [ "checkMouseViews", "class_v_s_t_g_u_i_1_1_c_frame.html#aa2412cc4f1e5a8fe430d2bb00c6f0b7d", null ],
+      [ "checkSizeConstraint", "class_v_s_t_g_u_i_1_1_c_frame.html#a9ea5d0cad85b53c51e7c9ffa620eb26a", null ],
       [ "clearMouseViews", "class_v_s_t_g_u_i_1_1_c_frame.html#a701c02ab4b91b1f30de6e7a7579854ca", null ],
       [ "close", "class_v_s_t_g_u_i_1_1_c_frame.html#a5ae591df94fc66ccb85cbb6565368bca", null ],
       [ "dispatchEvent", "class_v_s_t_g_u_i_1_1_c_frame.html#a685a52cd57a119d965aa3c6d2989dd94", null ],
@@ -214,6 +216,7 @@ var group__containerviews =
       [ "margin", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#ac75fc835ed41509adc9eee92b2ae3fe5", null ],
       [ "spacing", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a3e972ac45d440d7fa0c279f69b4a4f43", null ],
       [ "style", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a4b798253dd80ae013643a26e88e2bf6a", null ],
+      [ "ViewAnimatesResizingAttr", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a5babd43e686665dce926b73fcb9f7ba6", null ],
       [ "viewResizeAnimationTime", "class_v_s_t_g_u_i_1_1_c_row_column_view.html#a2cdfd0f81c97aaded87f0754b9ec162d", null ]
     ] ],
     [ "CScrollView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html", [
@@ -226,48 +229,55 @@ var group__containerviews =
         [ "kFollowFocusView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a57b3c017a8c8a22997c3b3234eba4db3ac49fe0a8e337925478fbd39226340ccd", null ],
         [ "kAutoHideScrollbars", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a57b3c017a8c8a22997c3b3234eba4db3a8b76060aaf221b15dbb15f493505e0ea", null ]
       ] ],
+      [ "Edge", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a5be7c8fa582f7b873d1c6caacb633073", [
+        [ "Top", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a5be7c8fa582f7b873d1c6caacb633073aa4ffdcf0dc1f31b9acaf295d75b51d00", null ],
+        [ "Left", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a5be7c8fa582f7b873d1c6caacb633073a945d5e233cf7d6240f6b783b36a374ff", null ]
+      ] ],
       [ "CScrollView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a2e773cded4e1194fde35e491a22d1c44", null ],
-      [ "CScrollView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ad44035bb69143789ccd43a631ce59bf2", null ],
-      [ "~CScrollView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ab8661c0fab125ec65fbda6e58cd8c8b1", null ],
+      [ "~CScrollView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a36a6c605fecaf8277232b1305b2a390e", null ],
       [ "addView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a64b49e8983843bfa97812b18041024ec", null ],
+      [ "attached", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a522467127f90bd5e2a6856e09b1b7bf2", null ],
       [ "calculateOptimalContainerSize", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ae7bdd205a8ff506b59682006afc398bf", null ],
       [ "changeViewZOrder", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a832e856a48c4411bad7023d4bb8a9b7f", null ],
       [ "drawBackgroundRect", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a712bcd14cfc09e409577317765f7b9e7", null ],
       [ "getActiveScrollbars", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#aff41b5b4d511dd326b0c1c668cc368c7", null ],
       [ "getContainerSize", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a0db22771c6b68b323ecf55261fbdd428", null ],
+      [ "getEdgeView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ae8ef7f315540810f06ffea98f324c46a", null ],
       [ "getHorizontalScrollbar", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a76e22b8c6753ee395e403e94159ae1da", null ],
       [ "getNbViews", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a4dba129ad0db7f96dd138a8a2e4e78a4", null ],
       [ "getScrollbarWidth", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a4d2ba8d328e25d87b943d70d31b9dd20", null ],
+      [ "getScrollContainer", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a714d644421067c583a4273eb95add674", null ],
       [ "getScrollOffset", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a025926f929ed154d264de3b4513d3843", null ],
       [ "getStyle", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#aa34e83aef3d87498e3151c01fc0e3ba8", null ],
       [ "getVerticalScrollbar", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ade3be7d8919678d3599e2ef8ab1159a9", null ],
       [ "getView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a39137ecba38cde42c946637352e73876", null ],
+      [ "getVisibleClientRect", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a0a6f0098bab5b2a30dac59d58eba1d66", null ],
       [ "makeRectVisible", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ad69f12c2e8328208ba0f58b845a04ecf", null ],
       [ "newCopy", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a5b303fef30c4644882aaa04f5ad669ca", null ],
       [ "notify", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a4b7d3ab731844a367db3a0d77af8e9ac", null ],
       [ "onMouseWheelEvent", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a0ec2a093619cd74f07d551b18679833f", null ],
-      [ "recalculateSubViews", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a0c6d1dd9bc1cbe653d7eacaf4362e06e", null ],
+      [ "preLayouting", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ab7c361dc40c6ab4cda35751a2245a995", null ],
+      [ "recalculateLayout", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a6f24abbf75b1d1b517f97509e0a455e3", null ],
       [ "removeAll", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#aabd341267925286a64dd52c16072e0cd", null ],
       [ "removeView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a628758060bb2b806776d7654c53768ca", null ],
       [ "resetScrollOffset", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a9080c8b02304886c8dbd9ccd4216a347", null ],
       [ "setAutosizeFlags", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ae636961f473c40033bf1edc1468f237f", null ],
       [ "setBackgroundColor", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a7ba955980a40362b194fd630f46a70e8", null ],
       [ "setContainerSize", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a76a87a4f5faa6bd93a3503c31225d654", null ],
+      [ "setEdgeView", "group__new__in__4__15.html#gaa6fa1c8e609e7d1bec365c1fcbce3015", null ],
       [ "setScrollbarWidth", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#acbd5b76dbb00098b28f173f7f0276312", null ],
+      [ "setScrollOffset", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a5ff1f32db0753a63e7cd8f1da5520183", null ],
       [ "setStyle", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a921dad1b65204e0e6c501e64b83dcc02", null ],
       [ "setTransparency", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ac15cca530e344ce60376a876493d3ef0", null ],
       [ "setViewSize", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#afa3d86320cb051cecb3c687a523ba787", null ],
+      [ "syncHScrollbar", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#af218ec435ca47d0ae1582bd6e5dea3aa", null ],
+      [ "syncScrollbars", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ad5e6e2faf4ba8ac94e940d18ade65494", null ],
+      [ "syncVScrollbar", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a54d98a74c672071677ad68d2e3e5d5d0", null ],
       [ "valueChanged", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a94d64f149dbf98863f121a3f6ce588ac", null ],
       [ "viewSizeChanged", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a9252b89cc57e621b0e60a981c6a455f4", null ],
       [ "viewWillDelete", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a81909ad6d160cf26b7ca118b97537528", null ],
-      [ "activeScrollbarStyle", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a6e7d66c797bece478be8cf6e6578bf8c", null ],
-      [ "containerSize", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#acc639bfdaf5f4b9cde46e48d6e47943c", null ],
-      [ "hsb", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a3cdbe0efdfc817c89d455706101cb693", null ],
-      [ "recalculateSubViewsRecursionGard", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ad3625bac224b08d967f9cb12c10057d7", null ],
-      [ "sc", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#aff567c827a45b152eadcb8bde332c019", null ],
-      [ "scrollbarWidth", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a89669bcb8bf5e3f126e38cb1ea39556c", null ],
-      [ "style", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#ac2aa43786a8b7cbdcfb76f31c05f9068", null ],
-      [ "vsb", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a67125beb4025180c08a82e885d4a5a26", null ]
+      [ "kHSBTag", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a0ed5ed872c27979082ef53c743ac23cf", null ],
+      [ "kVSBTag", "class_v_s_t_g_u_i_1_1_c_scroll_view.html#a802d0c8b5a1304745f1a8c8aab78a61a", null ]
     ] ],
     [ "CShadowViewContainer", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html", [
       [ "CShadowViewContainer", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html#af20982221f241e08beb9f136edf7cafe", null ],
@@ -321,11 +331,7 @@ var group__containerviews =
       [ "removeAll", "class_v_s_t_g_u_i_1_1_c_split_view.html#aabd341267925286a64dd52c16072e0cd", null ],
       [ "removed", "class_v_s_t_g_u_i_1_1_c_split_view.html#a157ad241be4354121739aac80cf3cd3d", null ],
       [ "removeView", "class_v_s_t_g_u_i_1_1_c_split_view.html#a628758060bb2b806776d7654c53768ca", null ],
-      [ "requestNewSeparatorSize", "class_v_s_t_g_u_i_1_1_c_split_view.html#a129ba2469954235dd9ad1eb7f9c5ca4c", null ],
-      [ "resizeFirstView", "class_v_s_t_g_u_i_1_1_c_split_view.html#ad6ece4580634fc04e425a521c327125d", null ],
-      [ "resizeLastView", "class_v_s_t_g_u_i_1_1_c_split_view.html#a54f2ef725a3284c7cadc1cc0c7dcc527", null ],
-      [ "resizeSecondView", "class_v_s_t_g_u_i_1_1_c_split_view.html#a7d515066dd3e7c3d0960c3da1502f64c", null ],
-      [ "resizeViewsEqual", "class_v_s_t_g_u_i_1_1_c_split_view.html#ac98cefe207ff01ac2532c39dd3a85619", null ],
+      [ "requestNewSeparatorSize", "class_v_s_t_g_u_i_1_1_c_split_view.html#afbfeb203210b85fbb6839ecf96ee0364", null ],
       [ "setResizeMethod", "class_v_s_t_g_u_i_1_1_c_split_view.html#a3e054909d56d2693a28f490aad1ae585", null ],
       [ "setSeparatorWidth", "class_v_s_t_g_u_i_1_1_c_split_view.html#a9fb9f90a3230b7fe496791ea67986e2d", null ],
       [ "setStyle", "class_v_s_t_g_u_i_1_1_c_split_view.html#aa053942a502bdcf882888ab77b7a3b45", null ],
@@ -387,6 +393,7 @@ var group__containerviews =
         [ "backgroundColor", "struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a1e5cbf2f65427aafbd2afef9d8570405", null ],
         [ "backgroundColorDrawStyle", "struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a7d82e50d9ee3c1b4c8521c83d0534b3d", null ],
         [ "children", "struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a0a10a5d6efc9ffc1e4745a0092c9b42e", null ],
+        [ "layouter", "struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a36f6551dcf420384b58ca37367fa340e", null ],
         [ "transform", "struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a122e5b2a4ab8dbf238d0cba30a061abf", null ],
         [ "viewContainerListeners", "struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a6113acd9a502ebc89120091d82fbe317", null ]
       ] ],
@@ -411,15 +418,18 @@ var group__containerviews =
       [ "addView", "class_v_s_t_g_u_i_1_1_c_view_container.html#aed7070f25de97fc661a06bdb43613f08", null ],
       [ "addView", "class_v_s_t_g_u_i_1_1_c_view_container.html#a3540fa93c2bf13a4f82db50613ba0603", null ],
       [ "advanceNextFocusView", "class_v_s_t_g_u_i_1_1_c_view_container.html#a073394468f30821dc263cd47a845adce", null ],
+      [ "applyViewLayout", "class_v_s_t_g_u_i_1_1_c_view_container.html#aef2dc9b7428e4591cb968b705cb424bb", null ],
       [ "asViewContainer", "class_v_s_t_g_u_i_1_1_c_view_container.html#a76f492587d04b7310c7ad64a614adbbe", null ],
       [ "asViewContainer", "class_v_s_t_g_u_i_1_1_c_view_container.html#abe3a1618995fc7c9186d992a4c7385ea", null ],
       [ "attached", "class_v_s_t_g_u_i_1_1_c_view_container.html#a522467127f90bd5e2a6856e09b1b7bf2", null ],
       [ "beforeDelete", "class_v_s_t_g_u_i_1_1_c_view_container.html#adc36f3faf62b04701b310c82c0b605a5", null ],
+      [ "calculateViewLayout", "class_v_s_t_g_u_i_1_1_c_view_container.html#a30315f927fc76fa394ac611334ccd10d", null ],
       [ "changeViewZOrder", "class_v_s_t_g_u_i_1_1_c_view_container.html#a5921267a54329874cba0b7547b7618e6", null ],
       [ "checkUpdateRect", "class_v_s_t_g_u_i_1_1_c_view_container.html#a2688055dabaf83e0d7956357cfb57629", null ],
       [ "draw", "class_v_s_t_g_u_i_1_1_c_view_container.html#a2223292a91c85ab8ff9d156763543bf2", null ],
       [ "drawBackgroundRect", "class_v_s_t_g_u_i_1_1_c_view_container.html#a73195afa396240ad593e6a07dc412528", null ],
       [ "drawRect", "class_v_s_t_g_u_i_1_1_c_view_container.html#ac3627a2e2abcfe4e6df2a77e4829446a", null ],
+      [ "findFirstViewIf", "class_v_s_t_g_u_i_1_1_c_view_container.html#a1a877d92e188e3a6b0891f0f6ce93dad", null ],
       [ "forEachChild", "class_v_s_t_g_u_i_1_1_c_view_container.html#a31f2c5aab6893a97dce69575422409cf", null ],
       [ "frameToLocal", "class_v_s_t_g_u_i_1_1_c_view_container.html#a48a051ae6394c5d724dd9bc50028c976", null ],
       [ "getAutosizingEnabled", "class_v_s_t_g_u_i_1_1_c_view_container.html#a0b73e5a49cc0b85711ad89582c39e680", null ],
@@ -430,15 +440,18 @@ var group__containerviews =
       [ "getChildViewsOfType", "class_v_s_t_g_u_i_1_1_c_view_container.html#a7b08928abb1f7ad795faf1e6c9e6897d", null ],
       [ "getContainerAt", "class_v_s_t_g_u_i_1_1_c_view_container.html#a54f20ec2ea6bb75ddc956c1b589213c7", null ],
       [ "getDropTarget", "class_v_s_t_g_u_i_1_1_c_view_container.html#a4954a63cca56c9fdcd3671187dab914f", null ],
+      [ "getInitialFocusView", "class_v_s_t_g_u_i_1_1_c_view_container.html#a9d0bd9f450509853f597a04394bf7d19", null ],
       [ "getMouseDownView", "class_v_s_t_g_u_i_1_1_c_view_container.html#a13468e7a127a2c9acc1d1bed2d4a19ac", null ],
       [ "getNbViews", "class_v_s_t_g_u_i_1_1_c_view_container.html#a06bfd3090cb9d96f3e4974aa090cc639", null ],
       [ "getTransform", "class_v_s_t_g_u_i_1_1_c_view_container.html#afd973675a1459432ab10c56cd192cc6d", null ],
       [ "getView", "class_v_s_t_g_u_i_1_1_c_view_container.html#aa0b72a8af8b9d0bda8be44d668828e9b", null ],
       [ "getViewAt", "class_v_s_t_g_u_i_1_1_c_view_container.html#a7c17efd881f52f95c5d22a5c35a0cb80", null ],
+      [ "getViewLayouter", "class_v_s_t_g_u_i_1_1_c_view_container.html#a47784fc62004c1f0fe24dcc73336f8ba", null ],
       [ "getViewsAt", "class_v_s_t_g_u_i_1_1_c_view_container.html#a66cb943b8912543b2f7cbf75a88b3768", null ],
       [ "getVisibleSize", "class_v_s_t_g_u_i_1_1_c_view_container.html#a95fdf9ad1e54a68fdbe680310ae3df56", null ],
       [ "hasChildren", "class_v_s_t_g_u_i_1_1_c_view_container.html#abae2ef4777ea28fa9acc234111dc84eb", null ],
       [ "hitTestSubViews", "class_v_s_t_g_u_i_1_1_c_view_container.html#a5de12aa6c135e4739adfc23d15c0a506", null ],
+      [ "inApplyViewLayout", "class_v_s_t_g_u_i_1_1_c_view_container.html#a76b5b2dd95d5a671ddb51038391c5bc9", null ],
       [ "invalid", "class_v_s_t_g_u_i_1_1_c_view_container.html#a0a838991166299c2318eaf3fc6085005", null ],
       [ "invalidateDirtyViews", "class_v_s_t_g_u_i_1_1_c_view_container.html#a0e04ec0a26733c9f8ebc816aaa25b6b5", null ],
       [ "invalidRect", "class_v_s_t_g_u_i_1_1_c_view_container.html#a5803a16bd396a0d032c08c29a60e4f78", null ],
@@ -465,8 +478,10 @@ var group__containerviews =
       [ "setBackgroundColor", "class_v_s_t_g_u_i_1_1_c_view_container.html#ab9480aa685c8a3f5f4800dad999efb75", null ],
       [ "setBackgroundColorDrawStyle", "class_v_s_t_g_u_i_1_1_c_view_container.html#af301508d4a35e86f8f798efb3b333c88", null ],
       [ "setBackgroundOffset", "class_v_s_t_g_u_i_1_1_c_view_container.html#a7177d866464e199ad0fd194f739d3929", null ],
+      [ "setInitialFocusView", "class_v_s_t_g_u_i_1_1_c_view_container.html#a9aeb7d27e26ea1a4e51e5cce3270be0e", null ],
       [ "setMouseDownView", "class_v_s_t_g_u_i_1_1_c_view_container.html#a7c0478917fe62f7920673bdd80b06e2f", null ],
       [ "setTransform", "class_v_s_t_g_u_i_1_1_c_view_container.html#ae33f973fde8bcc68ca7649b6fcef91d3", null ],
+      [ "setViewLayouter", "class_v_s_t_g_u_i_1_1_c_view_container.html#a065ecc5c2f6508c39371a18613d0a7a7", null ],
       [ "setViewSize", "class_v_s_t_g_u_i_1_1_c_view_container.html#afa3d86320cb051cecb3c687a523ba787", null ],
       [ "sizeToFit", "class_v_s_t_g_u_i_1_1_c_view_container.html#a64c95c189130160521d50820d9982242", null ],
       [ "takeFocus", "class_v_s_t_g_u_i_1_1_c_view_container.html#ad61c7e26801ed8a83174b554e75e5010", null ],
