@@ -163,8 +163,10 @@ var group__views =
         [ "ViewMouseListenerDispatcher", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#a875e0ddc4e05071b2cf60094b735d8c7", null ],
         [ "attributes", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#ae2690840d7883759ccd354025e071ecf", null ],
         [ "autosizeFlags", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#a97563af929607aba16c32432cf36fe9a", null ],
+        [ "gRuntimeID", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#a513e60e7c375f27d32b5f272c0b31bbd", null ],
         [ "parentFrame", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#a9957c398783c2d0026d5571347145772", null ],
         [ "parentView", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#a71c97f41876543c1b50f7d822c62580a", null ],
+        [ "runtimeID", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#a8e190ab307120aad246fb39a4f2b8b61", null ],
         [ "size", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#ab138ba4dfd17c13dac1cda0bae08749d", null ],
         [ "viewEventListeners", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#a1ed6be7dfdda307ff9186ec120adde94", null ],
         [ "viewFlags", "struct_v_s_t_g_u_i_1_1_c_view_1_1_impl.html#a80f4222baaab34d5065bf7263818a398", null ],
@@ -213,6 +215,7 @@ var group__views =
       [ "getMouseableArea", "class_v_s_t_g_u_i_1_1_c_view.html#a5121504050e29e9758c7d452d7e8dc3f", null ],
       [ "getMouseEnabled", "class_v_s_t_g_u_i_1_1_c_view.html#aac003ad010797e5b85321b1cf105f655", null ],
       [ "getParentView", "class_v_s_t_g_u_i_1_1_c_view.html#a838bbf95fe22cf6ab9cfdd7e86dee474", null ],
+      [ "getRuntimeID", "class_v_s_t_g_u_i_1_1_c_view.html#ac193f62cd9b8406c8619b08c01178a9e", null ],
       [ "getTransparency", "class_v_s_t_g_u_i_1_1_c_view.html#acd651f4659936e2f70f1d0e3605053d3", null ],
       [ "getViewSize", "class_v_s_t_g_u_i_1_1_c_view.html#a6cb1bdadd05b33ec42c14a139dbbfcb3", null ],
       [ "getVisibleViewSize", "class_v_s_t_g_u_i_1_1_c_view.html#a5eb5f422b9b85d9e897f05c960795e02", null ],
