@@ -46,6 +46,16 @@ var namespace_v_s_t_g_u_i =
       [ "free", "namespace_v_s_t_g_u_i_1_1_string.html#af30ee7f201c1f86d9aceb849d6d08fbf", null ],
       [ "newWithString", "namespace_v_s_t_g_u_i_1_1_string.html#a83745b23a3d48e4f1e69950977918803", null ]
     ] ],
+    [ "Tasks", "namespace_v_s_t_g_u_i_1_1_tasks.html", [
+      [ "backgroundQueue", "namespace_v_s_t_g_u_i_1_1_tasks.html#a3028f5015a4f88ea96b4929f433b3bb9", null ],
+      [ "mainQueue", "namespace_v_s_t_g_u_i_1_1_tasks.html#aaab16d3dd49f1809932964d991a689b2", null ],
+      [ "makeSerialQueue", "namespace_v_s_t_g_u_i_1_1_tasks.html#a6a3ec05d60d4d89b25a1bf1b4a13cdb5", null ],
+      [ "releaseSerialQueue", "namespace_v_s_t_g_u_i_1_1_tasks.html#a51646e59ea7f12381ca6287531e8f4e9", null ],
+      [ "schedule", "namespace_v_s_t_g_u_i_1_1_tasks.html#a9949a6389e7b361e1e1b04388059d052", null ],
+      [ "waitAllTasksExecuted", "namespace_v_s_t_g_u_i_1_1_tasks.html#aeb211e900947e4aaedc4753b6ddff662", null ]
+    ] ],
+    [ "TextEditor", "namespace_v_s_t_g_u_i_1_1_text_editor.html", "namespace_v_s_t_g_u_i_1_1_text_editor" ],
+    [ "TextEditorColorization", "namespace_v_s_t_g_u_i_1_1_text_editor_colorization.html", "namespace_v_s_t_g_u_i_1_1_text_editor_colorization" ],
     [ "UIDescriptionPrivate", "namespace_v_s_t_g_u_i_1_1_u_i_description_private.html", "namespace_v_s_t_g_u_i_1_1_u_i_description_private" ],
     [ "UIViewCreator", "namespace_v_s_t_g_u_i_1_1_u_i_view_creator.html", "namespace_v_s_t_g_u_i_1_1_u_i_view_creator" ],
     [ "VST3EditorInternal", "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html", [
@@ -55,7 +65,10 @@ var namespace_v_s_t_g_u_i =
     [ "Xml", "namespace_v_s_t_g_u_i_1_1_xml.html", "namespace_v_s_t_g_u_i_1_1_xml" ],
     [ "AEffGUIEditor", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor.html", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor" ],
     [ "AspectRatioVST3Editor", "class_v_s_t_g_u_i_1_1_aspect_ratio_v_s_t3_editor.html", "class_v_s_t_g_u_i_1_1_aspect_ratio_v_s_t3_editor" ],
+    [ "AutoSizeViewLayouter", "struct_v_s_t_g_u_i_1_1_auto_size_view_layouter.html", "struct_v_s_t_g_u_i_1_1_auto_size_view_layouter" ],
     [ "Base64Codec", "class_v_s_t_g_u_i_1_1_base64_codec.html", "class_v_s_t_g_u_i_1_1_base64_codec" ],
+    [ "BaseViewLayouter", "class_v_s_t_g_u_i_1_1_base_view_layouter.html", "class_v_s_t_g_u_i_1_1_base_view_layouter" ],
+    [ "BaseViewLayouterEntry", "struct_v_s_t_g_u_i_1_1_base_view_layouter_entry.html", "struct_v_s_t_g_u_i_1_1_base_view_layouter_entry" ],
     [ "BitScopeToggleT", "struct_v_s_t_g_u_i_1_1_bit_scope_toggle_t.html", "struct_v_s_t_g_u_i_1_1_bit_scope_toggle_t" ],
     [ "Buffer", "class_v_s_t_g_u_i_1_1_buffer.html", "class_v_s_t_g_u_i_1_1_buffer" ],
     [ "BufferedOutputStream", "class_v_s_t_g_u_i_1_1_buffered_output_stream.html", "class_v_s_t_g_u_i_1_1_buffered_output_stream" ],
@@ -138,6 +151,7 @@ var namespace_v_s_t_g_u_i =
     [ "CSpecialDigit", "class_v_s_t_g_u_i_1_1_c_special_digit.html", "class_v_s_t_g_u_i_1_1_c_special_digit" ],
     [ "CSplashScreen", "class_v_s_t_g_u_i_1_1_c_splash_screen.html", "class_v_s_t_g_u_i_1_1_c_splash_screen" ],
     [ "CSplitView", "class_v_s_t_g_u_i_1_1_c_split_view.html", "class_v_s_t_g_u_i_1_1_c_split_view" ],
+    [ "CSSNamedColor", "struct_v_s_t_g_u_i_1_1_c_s_s_named_color.html", "struct_v_s_t_g_u_i_1_1_c_s_s_named_color" ],
     [ "CSwitchBase", "class_v_s_t_g_u_i_1_1_c_switch_base.html", "class_v_s_t_g_u_i_1_1_c_switch_base" ],
     [ "CTabView", "class_v_s_t_g_u_i_1_1_c_tab_view.html", "class_v_s_t_g_u_i_1_1_c_tab_view" ],
     [ "CTextButton", "class_v_s_t_g_u_i_1_1_c_text_button.html", "class_v_s_t_g_u_i_1_1_c_text_button" ],
@@ -162,6 +176,7 @@ var namespace_v_s_t_g_u_i =
     [ "DragEventData", "struct_v_s_t_g_u_i_1_1_drag_event_data.html", "struct_v_s_t_g_u_i_1_1_drag_event_data" ],
     [ "DragStartMouseObserver", "struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html", "struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer" ],
     [ "DropTargetAdapter", "class_v_s_t_g_u_i_1_1_drop_target_adapter.html", "class_v_s_t_g_u_i_1_1_drop_target_adapter" ],
+    [ "EnumBitset", "struct_v_s_t_g_u_i_1_1_enum_bitset.html", "struct_v_s_t_g_u_i_1_1_enum_bitset" ],
     [ "ERect", "struct_v_s_t_g_u_i_1_1_e_rect.html", "struct_v_s_t_g_u_i_1_1_e_rect" ],
     [ "Event", "struct_v_s_t_g_u_i_1_1_event.html", "struct_v_s_t_g_u_i_1_1_event" ],
     [ "EventConsumeState", "struct_v_s_t_g_u_i_1_1_event_consume_state.html", "struct_v_s_t_g_u_i_1_1_event_consume_state" ],
@@ -172,6 +187,8 @@ var namespace_v_s_t_g_u_i =
     [ "GestureEvent", "struct_v_s_t_g_u_i_1_1_gesture_event.html", "struct_v_s_t_g_u_i_1_1_gesture_event" ],
     [ "GetViewOptions", "struct_v_s_t_g_u_i_1_1_get_view_options.html", "struct_v_s_t_g_u_i_1_1_get_view_options" ],
     [ "GlobalFonts", "struct_v_s_t_g_u_i_1_1_global_fonts.html", "struct_v_s_t_g_u_i_1_1_global_fonts" ],
+    [ "GridLayouter", "class_v_s_t_g_u_i_1_1_grid_layouter.html", "class_v_s_t_g_u_i_1_1_grid_layouter" ],
+    [ "GridLayoutProperties", "struct_v_s_t_g_u_i_1_1_grid_layout_properties.html", "struct_v_s_t_g_u_i_1_1_grid_layout_properties" ],
     [ "GroupController", "class_v_s_t_g_u_i_1_1_group_controller.html", "class_v_s_t_g_u_i_1_1_group_controller" ],
     [ "IBitmapCreator", "class_v_s_t_g_u_i_1_1_i_bitmap_creator.html", "class_v_s_t_g_u_i_1_1_i_bitmap_creator" ],
     [ "IBitmapCreator2", "class_v_s_t_g_u_i_1_1_i_bitmap_creator2.html", "class_v_s_t_g_u_i_1_1_i_bitmap_creator2" ],
@@ -206,13 +223,18 @@ var namespace_v_s_t_g_u_i =
     [ "ISplitViewController", "class_v_s_t_g_u_i_1_1_i_split_view_controller.html", "class_v_s_t_g_u_i_1_1_i_split_view_controller" ],
     [ "ISplitViewSeparatorDrawer", "class_v_s_t_g_u_i_1_1_i_split_view_separator_drawer.html", "class_v_s_t_g_u_i_1_1_i_split_view_separator_drawer" ],
     [ "ITextEditListener", "class_v_s_t_g_u_i_1_1_i_text_edit_listener.html", "class_v_s_t_g_u_i_1_1_i_text_edit_listener" ],
+    [ "ITextEditor", "struct_v_s_t_g_u_i_1_1_i_text_editor.html", "struct_v_s_t_g_u_i_1_1_i_text_editor" ],
+    [ "ITextEditorController", "struct_v_s_t_g_u_i_1_1_i_text_editor_controller.html", "struct_v_s_t_g_u_i_1_1_i_text_editor_controller" ],
     [ "ITextLabelListener", "class_v_s_t_g_u_i_1_1_i_text_label_listener.html", "class_v_s_t_g_u_i_1_1_i_text_label_listener" ],
     [ "IUIDescription", "class_v_s_t_g_u_i_1_1_i_u_i_description.html", "class_v_s_t_g_u_i_1_1_i_u_i_description" ],
+    [ "IUIDescriptionAddOn", "struct_v_s_t_g_u_i_1_1_i_u_i_description_add_on.html", "struct_v_s_t_g_u_i_1_1_i_u_i_description_add_on" ],
     [ "IViewAddedRemovedObserver", "class_v_s_t_g_u_i_1_1_i_view_added_removed_observer.html", "class_v_s_t_g_u_i_1_1_i_view_added_removed_observer" ],
     [ "IViewContainerListener", "class_v_s_t_g_u_i_1_1_i_view_container_listener.html", "class_v_s_t_g_u_i_1_1_i_view_container_listener" ],
     [ "IViewCreator", "class_v_s_t_g_u_i_1_1_i_view_creator.html", "class_v_s_t_g_u_i_1_1_i_view_creator" ],
     [ "IViewEventListener", "class_v_s_t_g_u_i_1_1_i_view_event_listener.html", "class_v_s_t_g_u_i_1_1_i_view_event_listener" ],
     [ "IViewFactory", "class_v_s_t_g_u_i_1_1_i_view_factory.html", "class_v_s_t_g_u_i_1_1_i_view_factory" ],
+    [ "IViewFactoryEditingSupport", "class_v_s_t_g_u_i_1_1_i_view_factory_editing_support.html", "class_v_s_t_g_u_i_1_1_i_view_factory_editing_support" ],
+    [ "IViewLayouter", "class_v_s_t_g_u_i_1_1_i_view_layouter.html", "class_v_s_t_g_u_i_1_1_i_view_layouter" ],
     [ "IViewListener", "class_v_s_t_g_u_i_1_1_i_view_listener.html", "class_v_s_t_g_u_i_1_1_i_view_listener" ],
     [ "IViewMouseListener", "class_v_s_t_g_u_i_1_1_i_view_mouse_listener.html", "class_v_s_t_g_u_i_1_1_i_view_mouse_listener" ],
     [ "IViewSwitchController", "class_v_s_t_g_u_i_1_1_i_view_switch_controller.html", "class_v_s_t_g_u_i_1_1_i_view_switch_controller" ],
@@ -236,6 +258,7 @@ var namespace_v_s_t_g_u_i =
     [ "MouseUpEvent", "struct_v_s_t_g_u_i_1_1_mouse_up_event.html", "struct_v_s_t_g_u_i_1_1_mouse_up_event" ],
     [ "MouseWheelEvent", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event" ],
     [ "MultiFrameBitmapView", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view" ],
+    [ "NoViewLayouter", "struct_v_s_t_g_u_i_1_1_no_view_layouter.html", "struct_v_s_t_g_u_i_1_1_no_view_layouter" ],
     [ "OldKeyboardHookAdapter", "class_v_s_t_g_u_i_1_1_old_keyboard_hook_adapter.html", "class_v_s_t_g_u_i_1_1_old_keyboard_hook_adapter" ],
     [ "OldMouseObserverAdapter", "class_v_s_t_g_u_i_1_1_old_mouse_observer_adapter.html", "class_v_s_t_g_u_i_1_1_old_mouse_observer_adapter" ],
     [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html", "struct_v_s_t_g_u_i_1_1_optional" ],
@@ -252,10 +275,13 @@ var namespace_v_s_t_g_u_i =
     [ "StdOutStream", "class_v_s_t_g_u_i_1_1_std_out_stream.html", "class_v_s_t_g_u_i_1_1_std_out_stream" ],
     [ "StringListControlDrawer", "class_v_s_t_g_u_i_1_1_string_list_control_drawer.html", "class_v_s_t_g_u_i_1_1_string_list_control_drawer" ],
     [ "TextEditListenerAdapter", "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter.html", "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter" ],
+    [ "TextEditorControllerAdapter", "struct_v_s_t_g_u_i_1_1_text_editor_controller_adapter.html", "struct_v_s_t_g_u_i_1_1_text_editor_controller_adapter" ],
     [ "TextLabelListenerAdapter", "class_v_s_t_g_u_i_1_1_text_label_listener_adapter.html", "class_v_s_t_g_u_i_1_1_text_label_listener_adapter" ],
     [ "TrimOptions", "struct_v_s_t_g_u_i_1_1_trim_options.html", "struct_v_s_t_g_u_i_1_1_trim_options" ],
     [ "UIAttributes", "class_v_s_t_g_u_i_1_1_u_i_attributes.html", "class_v_s_t_g_u_i_1_1_u_i_attributes" ],
     [ "UIDescription", "class_v_s_t_g_u_i_1_1_u_i_description.html", "class_v_s_t_g_u_i_1_1_u_i_description" ],
+    [ "UIDescriptionAddOnAdapter", "struct_v_s_t_g_u_i_1_1_u_i_description_add_on_adapter.html", "struct_v_s_t_g_u_i_1_1_u_i_description_add_on_adapter" ],
+    [ "UIDescriptionAddOnRegistry", "class_v_s_t_g_u_i_1_1_u_i_description_add_on_registry.html", "class_v_s_t_g_u_i_1_1_u_i_description_add_on_registry" ],
     [ "UIDescriptionListener", "class_v_s_t_g_u_i_1_1_u_i_description_listener.html", "class_v_s_t_g_u_i_1_1_u_i_description_listener" ],
     [ "UIDescriptionListenerAdapter", "class_v_s_t_g_u_i_1_1_u_i_description_listener_adapter.html", "class_v_s_t_g_u_i_1_1_u_i_description_listener_adapter" ],
     [ "UIDescriptionListenerOff", "struct_v_s_t_g_u_i_1_1_u_i_description_listener_off.html", "struct_v_s_t_g_u_i_1_1_u_i_description_listener_off" ],
@@ -270,6 +296,8 @@ var namespace_v_s_t_g_u_i =
     [ "ViewCreatorAdapter", "class_v_s_t_g_u_i_1_1_view_creator_adapter.html", "class_v_s_t_g_u_i_1_1_view_creator_adapter" ],
     [ "ViewCreatorRegistry", "class_v_s_t_g_u_i_1_1_view_creator_registry.html", "class_v_s_t_g_u_i_1_1_view_creator_registry" ],
     [ "ViewEventListenerAdapter", "class_v_s_t_g_u_i_1_1_view_event_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_event_listener_adapter" ],
+    [ "ViewFactoryDelegate", "class_v_s_t_g_u_i_1_1_view_factory_delegate.html", "class_v_s_t_g_u_i_1_1_view_factory_delegate" ],
+    [ "ViewLayout", "struct_v_s_t_g_u_i_1_1_view_layout.html", "struct_v_s_t_g_u_i_1_1_view_layout" ],
     [ "ViewListenerAdapter", "class_v_s_t_g_u_i_1_1_view_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_listener_adapter" ],
     [ "ViewMouseListenerAdapter", "class_v_s_t_g_u_i_1_1_view_mouse_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_mouse_listener_adapter" ],
     [ "VST3Editor", "class_v_s_t_g_u_i_1_1_v_s_t3_editor.html", "class_v_s_t_g_u_i_1_1_v_s_t3_editor" ],
@@ -287,6 +315,7 @@ var namespace_v_s_t_g_u_i =
     [ "CMenuItemIterator", "namespace_v_s_t_g_u_i.html#ac5d2d5ae2f6fa970821129ccaa21d2a8", null ],
     [ "CMenuItemList", "namespace_v_s_t_g_u_i.html#ae866b004d82d1e368dd3f5bc8386b2e1", null ],
     [ "CParamDisplayValueToStringProc", "namespace_v_s_t_g_u_i.html#a01e4013e5947137c376d11ba08e65e97", null ],
+    [ "CSSNamedColorArray", "namespace_v_s_t_g_u_i.html#aba35ca800afce1f5dd1fd1243e598181", null ],
     [ "CTextEditStringToValueProc", "namespace_v_s_t_g_u_i.html#aeb8a18f8dd4b9f3824fff995ced2ecaf", null ],
     [ "CViewAttributeID", "namespace_v_s_t_g_u_i.html#ab344f8ed42cf4fb22917bae466fa6897", null ],
     [ "GradientColorStop", "namespace_v_s_t_g_u_i.html#afcc200df0a75d784f2b35340aae8e428", null ],
@@ -309,6 +338,7 @@ var namespace_v_s_t_g_u_i =
     [ "PlatformGraphicsPathPtr", "namespace_v_s_t_g_u_i.html#a4933a6a3e88daad1eb3223a128bc5b57", null ],
     [ "PlatformResourceInputStreamPtr", "namespace_v_s_t_g_u_i.html#a975ab25ec941cb6345d5612800e0f3ea", null ],
     [ "PlatformStringPtr", "namespace_v_s_t_g_u_i.html#a2f58f3095b6d0389db494ea401afef22", null ],
+    [ "PlatformTaskExecutorPtr", "namespace_v_s_t_g_u_i.html#afb969248762a16156b798675e323c28a", null ],
     [ "PlatformTimerPtr", "namespace_v_s_t_g_u_i.html#a24528a069c61df796b973b9f9149fbca", null ],
     [ "PointList", "namespace_v_s_t_g_u_i.html#ad2fc415eb172cbcccde2459300aae5af", null ],
     [ "ReverseViewIterator", "namespace_v_s_t_g_u_i.html#a0d390ba7909d00d28aeebca3da0e5086", null ],
@@ -531,22 +561,23 @@ var namespace_v_s_t_g_u_i =
     [ "boxesForGauss", "namespace_v_s_t_g_u_i.html#abcf6a3f540d01f3a4df8db781b6f08cb", null ],
     [ "buttonStateFromEventModifiers", "group__new__in__4__11.html#gacc93a453b03a037ebec4987bc8f30a90", null ],
     [ "buttonStateFromMouseEvent", "group__new__in__4__11.html#ga9e7a18104859beae1f325157d78ea771", null ],
-    [ "castKeyboardEvent", "group__new__in__4__11.html#ga72eaa4704e183d6233c4c9cf42df973e", null ],
-    [ "castMouseCancelEvent", "group__new__in__4__11.html#gaea47e439b5007888b22a6611e0a34372", null ],
-    [ "castMouseDownEvent", "group__new__in__4__11.html#ga0c6b61604f95593156cb21423f653785", null ],
-    [ "castMouseEnterEvent", "group__new__in__4__11.html#ga0da14dc430887ec6c938dfbc72a494e3", null ],
-    [ "castMouseEvent", "group__new__in__4__11.html#gac58eda1c0fcfecc48bbcd4db4180f01e", null ],
-    [ "castMouseExitEvent", "group__new__in__4__11.html#ga3fea1c77f2004d3641a3f1078fef40f7", null ],
-    [ "castMouseMoveEvent", "group__new__in__4__11.html#gaeb713ab6ba4e2b6945fdefefb9592e00", null ],
-    [ "castMousePositionEvent", "group__new__in__4__11.html#gac7862a08e9b7c64482b9d55e72b09a10", null ],
-    [ "castMouseUpEvent", "group__new__in__4__11.html#gae3dfdd4a2dedd1c555cf4646bddc8a28", null ],
-    [ "castMouseWheelEvent", "group__new__in__4__11.html#ga5043a8eedce294c63e575beda7bc1adf", null ],
-    [ "castZoomGestureEvent", "group__new__in__4__11.html#ga7996f43f0a6f0a855f75e46bc6bd74e9", null ],
+    [ "castKeyboardEvent", "group__new__in__4__11.html#ga0f07cf46ef8c28fc15a17fe5df3a01a3", null ],
+    [ "castMouseCancelEvent", "group__new__in__4__11.html#ga708ade33cbffc045ee5273070403308b", null ],
+    [ "castMouseDownEvent", "group__new__in__4__11.html#gad47f01b18ba906a8c502fe8e6c1721e3", null ],
+    [ "castMouseEnterEvent", "group__new__in__4__11.html#ga22174fd34490d4d377fc078ae0940fd8", null ],
+    [ "castMouseEvent", "group__new__in__4__11.html#ga01f4a4a1c1dfc7c8666b92feb8cac80b", null ],
+    [ "castMouseExitEvent", "group__new__in__4__11.html#ga0c687f85cf356897bf3d2f93cb3bb91d", null ],
+    [ "castMouseMoveEvent", "group__new__in__4__11.html#gad900d256c235d7692f68d6501ac08393", null ],
+    [ "castMousePositionEvent", "group__new__in__4__11.html#ga4af351881d1c50760932e82a13cecd8b", null ],
+    [ "castMouseUpEvent", "group__new__in__4__11.html#ga40422bf8349a0c9fc4152d3cedbae20e", null ],
+    [ "castMouseWheelEvent", "group__new__in__4__11.html#ga06fd075ad1a20afd1a8d57e38c50a1da", null ],
+    [ "castZoomGestureEvent", "group__new__in__4__11.html#gae973cc0f159b56c26cfafad1f75f62a5", null ],
     [ "clamp", "namespace_v_s_t_g_u_i.html#afd4c86ba716fdf40d84831822843016a", null ],
     [ "clampNorm", "namespace_v_s_t_g_u_i.html#a97a959bfc6f6e0b27e925f30e3779225", null ],
     [ "convert", "namespace_v_s_t_g_u_i.html#ae4e09ac9b31e63015a2529bb3b001954", null ],
     [ "convert", "namespace_v_s_t_g_u_i.html#a72554073a9cef6518ba0ab5e90f42b09", null ],
     [ "convert", "namespace_v_s_t_g_u_i.html#ada653f3803f48e88c81f1bb8e2fc6aa5", null ],
+    [ "createNewTextEditor", "group__new__in__4__15.html#ga6cefbd50056bee34f474afdde92f3ebc", null ],
     [ "doAssert", "namespace_v_s_t_g_u_i.html#a61f906552ad31a1b0edc6d12218fa83d", null ],
     [ "drawClipped", "namespace_v_s_t_g_u_i.html#a61ce8e0954f743f4396fe84df08f0efa", null ],
     [ "dynamicPtrCast", "namespace_v_s_t_g_u_i.html#a2a8b0c5618f1860cc17a9bc00b6c5112", null ],
@@ -560,8 +591,8 @@ var namespace_v_s_t_g_u_i =
     [ "FreeNodePlatformResources", "namespace_v_s_t_g_u_i.html#ac071928df01744b9ab2f020131232c91", null ],
     [ "fromVstVirtualKey", "namespace_v_s_t_g_u_i.html#ad7b564797515bf4a690993a851e8c200", null ],
     [ "getCreatorRegistry", "namespace_v_s_t_g_u_i.html#a3ea024da68ef884d603e29900152fd36", null ],
+    [ "getCSSNamedColors", "group__new__in__4__15.html#gaa67569967ce8495520076a01d7137888", null ],
     [ "getGenericViewFactory", "namespace_v_s_t_g_u_i.html#a10480eb9d1ff4a0aeb886f9186066331", null ],
-    [ "getSplitViewController", "namespace_v_s_t_g_u_i.html#ab25dd81cb13ee92511b6bbf80e53397a", null ],
     [ "getTooltipFromView", "namespace_v_s_t_g_u_i.html#a9e2946e83b4d39ca26a82fc37c0b9659", null ],
     [ "getViewController", "namespace_v_s_t_g_u_i.html#a4fe5229a1073206ee8671ea2a88a6408", null ],
     [ "hasAssertionHandler", "namespace_v_s_t_g_u_i.html#ab0411f6642b03599f6d293af2c17079c", null ],
@@ -661,6 +692,7 @@ var namespace_v_s_t_g_u_i =
     [ "kViewNameAttribute", "namespace_v_s_t_g_u_i.html#a293b05bd232342337b39195cbb1ed6a4", null ],
     [ "kWhiteCColor", "namespace_v_s_t_g_u_i.html#a21e9da5a787be82b5c87dd9c2e909c9b", null ],
     [ "kYellowCColor", "namespace_v_s_t_g_u_i.html#a4112c2c08f0b5901bfca25a2fc58d6d4", null ],
+    [ "namedColors", "namespace_v_s_t_g_u_i.html#ac83dfc79c104486758f3ea2c22acbcce", null ],
     [ "unixPathSeparator", "namespace_v_s_t_g_u_i.html#a1dd448de94cb8e699d0280716db018c8", null ],
     [ "windowsPathSeparator", "namespace_v_s_t_g_u_i.html#a6ebc5182919a5dd7d3f30fd59eb23df3", null ]
 ];
\ No newline at end of file
