@@ -15,6 +15,8 @@ var namespace_v_s_t_g_u_i_1_1_standalone =
       [ "Copy", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a090badc6f06112d958c3e9543fdcd8fb", null ],
       [ "Cut", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a285c438e7aaa3eea4da618e49ecd235b", null ],
       [ "Delete", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#aeec45f7e4c1b9cfd7df8aae27d23aa29", null ],
+      [ "FindNext", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#adbcf8817b4827f98d018a74ac657ac69", null ],
+      [ "FindPrevious", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#aa37300678f4e547bf98ce3b1dbdbe801", null ],
       [ "Help", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a86dea344e9429aa10bd79fe8faf7d6c1", null ],
       [ "MenuSeparator", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a4862aa9abe601fcab28aafa661efaeaf", null ],
       [ "New", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#ac8e97ffc79a9b7f51ddb6f9001d44eb6", null ],
@@ -22,6 +24,7 @@ var namespace_v_s_t_g_u_i_1_1_standalone =
       [ "Paste", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a7a3c9b00144ef8e4163f9738ecdaaffd", null ],
       [ "Preferences", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a9247f47b642b9f7a737a6a56d25228fa", null ],
       [ "Quit", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#aaebedacd311787d028489d8feac24c71", null ],
+      [ "RecreateView", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a0e02ec3e4445c30e4b76ba0dceee6529", null ],
       [ "Redo", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#adc40ead4f2201564cc3eeeb1f2905640", null ],
       [ "ResaveSharedResources", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#abf8380ec42326587b3029af2175b1d6c", null ],
       [ "Revert", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a7be1047d27e4db13b3b2066f76a93c72", null ],
@@ -48,6 +51,7 @@ var namespace_v_s_t_g_u_i_1_1_standalone =
     [ "IStepValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_step_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_step_value" ],
     [ "IStringListValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_list_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_list_value" ],
     [ "IStringValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_value" ],
+    [ "IUIDescWindowController", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_u_i_desc_window_controller.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_u_i_desc_window_controller" ],
     [ "IValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value" ],
     [ "IValueConverter", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_converter.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_converter" ],
     [ "IValueListener", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_listener.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_listener" ],
