@@ -8,6 +8,8 @@ var searchData=
   ['animator_5',['Animator',['../class_v_s_t_g_u_i_1_1_animation_1_1_animator.html',1,'VSTGUI::Animation']]],
   ['animknobcreator_6',['AnimKnobCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_anim_knob_creator.html',1,'VSTGUI::UIViewCreator']]],
   ['aspectratiovst3editor_7',['AspectRatioVST3Editor',['../class_v_s_t_g_u_i_1_1_aspect_ratio_v_s_t3_editor.html',1,'VSTGUI']]],
-  ['autoanimationcreator_8',['AutoAnimationCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_auto_animation_creator.html',1,'VSTGUI::UIViewCreator']]],
-  ['autolayout_9',['AutoLayout',['../class_v_s_t_g_u_i_1_1_layouting_1_1_auto_layout.html',1,'VSTGUI::Layouting']]]
+  ['auto_8',['Auto',['../struct_v_s_t_g_u_i_1_1_grid_layout_properties_1_1_auto.html',1,'VSTGUI::GridLayoutProperties']]],
+  ['autoanimationcreator_9',['AutoAnimationCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_auto_animation_creator.html',1,'VSTGUI::UIViewCreator']]],
+  ['autolayout_10',['AutoLayout',['../class_v_s_t_g_u_i_1_1_layouting_1_1_auto_layout.html',1,'VSTGUI::Layouting']]],
+  ['autosizeviewlayouter_11',['AutoSizeViewLayouter',['../struct_v_s_t_g_u_i_1_1_auto_size_view_layouter.html',1,'VSTGUI']]]
 ];
