@@ -34,16 +34,24 @@ var searchData=
   ['sharedpointer_3c_20vstgui_3a_3aidroptarget_20_3e_31',['SharedPointer&lt; VSTGUI::IDropTarget &gt;',['../class_v_s_t_g_u_i_1_1_shared_pointer.html',1,'VSTGUI']]],
   ['sharedpointer_3c_20vstgui_3a_3ailistcontrolconfigurator_20_3e_32',['SharedPointer&lt; VSTGUI::IListControlConfigurator &gt;',['../class_v_s_t_g_u_i_1_1_shared_pointer.html',1,'VSTGUI']]],
   ['sharedpointer_3c_20vstgui_3a_3ailistcontroldrawer_20_3e_33',['SharedPointer&lt; VSTGUI::IListControlDrawer &gt;',['../class_v_s_t_g_u_i_1_1_shared_pointer.html',1,'VSTGUI']]],
-  ['sharedpointer_3c_20vstgui_3a_3auidescription_20_3e_34',['SharedPointer&lt; VSTGUI::UIDescription &gt;',['../class_v_s_t_g_u_i_1_1_shared_pointer.html',1,'VSTGUI']]],
-  ['sliderbasecreator_35',['SliderBaseCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_slider_base_creator.html',1,'VSTGUI::UIViewCreator']]],
-  ['slidercreator_36',['SliderCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_slider_creator.html',1,'VSTGUI::UIViewCreator']]],
-  ['splitviewcreator_37',['SplitViewCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_split_view_creator.html',1,'VSTGUI::UIViewCreator']]],
-  ['state_38',['State',['../struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_impl_1_1_state.html',1,'VSTGUI::CDrawContext::Impl']]],
-  ['staticlistcontrolconfigurator_39',['StaticListControlConfigurator',['../class_v_s_t_g_u_i_1_1_static_list_control_configurator.html',1,'VSTGUI']]],
-  ['stdoutstream_40',['StdOutStream',['../class_v_s_t_g_u_i_1_1_std_out_stream.html',1,'VSTGUI']]],
-  ['stringdatapackage_41',['StringDataPackage',['../struct_v_s_t_g_u_i_1_1_c_clipboard_detail_1_1_string_data_package.html',1,'VSTGUI::CClipboardDetail']]],
-  ['stringlistcontrolcreator_42',['StringListControlCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_string_list_control_creator.html',1,'VSTGUI::UIViewCreator']]],
-  ['stringlistcontroldrawer_43',['StringListControlDrawer',['../class_v_s_t_g_u_i_1_1_string_list_control_drawer.html',1,'VSTGUI']]],
-  ['stringtoken_44',['StringToken',['../class_v_s_t_g_u_i_1_1_u_i_description_private_1_1_string_token.html',1,'VSTGUI::UIDescriptionPrivate']]],
-  ['switchbasecreator_45',['SwitchBaseCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_switch_base_creator.html',1,'VSTGUI::UIViewCreator']]]
+  ['sharedpointer_3c_20vstgui_3a_3aiviewlayouter_20_3e_34',['SharedPointer&lt; VSTGUI::IViewLayouter &gt;',['../class_v_s_t_g_u_i_1_1_shared_pointer.html',1,'VSTGUI']]],
+  ['sharedpointer_3c_20vstgui_3a_3atexteditor_3a_3alinenumberview_20_3e_35',['SharedPointer&lt; VSTGUI::TextEditor::LineNumberView &gt;',['../class_v_s_t_g_u_i_1_1_shared_pointer.html',1,'VSTGUI']]],
+  ['sharedpointer_3c_20vstgui_3a_3auidescription_20_3e_36',['SharedPointer&lt; VSTGUI::UIDescription &gt;',['../class_v_s_t_g_u_i_1_1_shared_pointer.html',1,'VSTGUI']]],
+  ['sliderbasecreator_37',['SliderBaseCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_slider_base_creator.html',1,'VSTGUI::UIViewCreator']]],
+  ['slidercreator_38',['SliderCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_slider_creator.html',1,'VSTGUI::UIViewCreator']]],
+  ['splitviewcreator_39',['SplitViewCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_split_view_creator.html',1,'VSTGUI::UIViewCreator']]],
+  ['state_40',['State',['../struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_impl_1_1_state.html',1,'VSTGUI::CDrawContext::Impl']]],
+  ['staticlistcontrolconfigurator_41',['StaticListControlConfigurator',['../class_v_s_t_g_u_i_1_1_static_list_control_configurator.html',1,'VSTGUI']]],
+  ['stb_5ftexteditstate_42',['STB_TexteditState',['../struct_v_s_t_g_u_i_1_1_text_editor_1_1_s_t_b___textedit_state.html',1,'VSTGUI::TextEditor']]],
+  ['stbfindstate_43',['StbFindState',['../struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_find_state.html',1,'VSTGUI::TextEditor']]],
+  ['stbtexteditrow_44',['StbTexteditRow',['../struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_textedit_row.html',1,'VSTGUI::TextEditor']]],
+  ['stbundorecord_45',['StbUndoRecord',['../struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_undo_record.html',1,'VSTGUI::TextEditor']]],
+  ['stbundostate_46',['StbUndoState',['../struct_v_s_t_g_u_i_1_1_text_editor_1_1_stb_undo_state.html',1,'VSTGUI::TextEditor']]],
+  ['stdoutstream_47',['StdOutStream',['../class_v_s_t_g_u_i_1_1_std_out_stream.html',1,'VSTGUI']]],
+  ['stringdatapackage_48',['StringDataPackage',['../struct_v_s_t_g_u_i_1_1_c_clipboard_detail_1_1_string_data_package.html',1,'VSTGUI::CClipboardDetail']]],
+  ['stringlistcontrolcreator_49',['StringListControlCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_string_list_control_creator.html',1,'VSTGUI::UIViewCreator']]],
+  ['stringlistcontroldrawer_50',['StringListControlDrawer',['../class_v_s_t_g_u_i_1_1_string_list_control_drawer.html',1,'VSTGUI']]],
+  ['stringtoken_51',['StringToken',['../class_v_s_t_g_u_i_1_1_u_i_description_private_1_1_string_token.html',1,'VSTGUI::UIDescriptionPrivate']]],
+  ['style_52',['Style',['../struct_v_s_t_g_u_i_1_1_i_text_editor_1_1_style.html',1,'ITextEditor::Style'],['../struct_v_s_t_g_u_i_1_1_text_editor_colorization_1_1_i_style_provider_1_1_style.html',1,'IStyleProvider::Style']]],
+  ['switchbasecreator_53',['SwitchBaseCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_switch_base_creator.html',1,'VSTGUI::UIViewCreator']]]
 ];
