@@ -4,5 +4,5 @@ var searchData=
   ['zindex_1',['zIndex',['../class_v_s_t_g_u_i_1_1_c_layered_view_container.html#a7b9421795ea7c21408e6523b8f8ee9f2',1,'VSTGUI::CLayeredViewContainer']]],
   ['zoom_2',['zoom',['../struct_v_s_t_g_u_i_1_1_zoom_gesture_event.html#a9c59ed4a7b6bdc2b1207e39fabf379a4',1,'VSTGUI::ZoomGestureEvent']]],
   ['zoomfactor_3',['zoomFactor',['../class_v_s_t_g_u_i_1_1_c_knob_base.html#a4c0115542d198c9c7539a3c4eb45f3d7',1,'VSTGUI::CKnobBase::zoomFactor'],['../struct_v_s_t_g_u_i_1_1_c_slider_base_1_1_impl.html#a4c0115542d198c9c7539a3c4eb45f3d7',1,'VSTGUI::CSliderBase::Impl::zoomFactor'],['../class_v_s_t_g_u_i_1_1_v_s_t3_editor.html#a5e4d574ec42a94d6f9ed08529eebe1ac',1,'VSTGUI::VST3Editor::zoomFactor']]],
-  ['zstream_4',['zstream',['../class_v_s_t_g_u_i_1_1_z_lib_input_stream.html#af749739afdc9986577c77ff2f3652f93',1,'VSTGUI::ZLibInputStream::zstream'],['../class_v_s_t_g_u_i_1_1_z_lib_output_stream.html#af749739afdc9986577c77ff2f3652f93',1,'VSTGUI::ZLibOutputStream::zstream']]]
+  ['zstream_4',['zstream',['../struct_v_s_t_g_u_i_1_1_z_lib_input_stream_1_1_impl.html#a35603a1e3ac6826d7a5c125660acf809',1,'VSTGUI::ZLibInputStream::Impl::zstream'],['../struct_v_s_t_g_u_i_1_1_z_lib_output_stream_1_1_impl.html#a35603a1e3ac6826d7a5c125660acf809',1,'VSTGUI::ZLibOutputStream::Impl::zstream']]]
 ];
