@@ -17,36 +17,49 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1IPlugView.html#ae4f7f751a5b75837f47ba19b29c53917":[0,10,3,6],
 "classSteinberg_1_1IPlugView.html#ae726f4b3471ee2485a0bbb651cd35ff2":[0,10,3,5],
 "classSteinberg_1_1IPlugViewContentScaleSupport.html":[0,10,8],
-"classSteinberg_1_1IPlugViewContentScaleSupport.html#a75ec4b5d086d2af3733ac3775ab008d8":[0,10,8,0],
-"classSteinberg_1_1IPlugViewContentScaleSupport.html#af5b0fea85beba3cdcfeb8de66779f478":[0,10,8,1],
-"classSteinberg_1_1ITest.html":[1,0,0,8],
+"classSteinberg_1_1IPlugViewContentScaleSupport.html#af5b0fea85beba3cdcfeb8de66779f478":[0,10,8,2],
+"classSteinberg_1_1ITest.html":[1,0,0,13],
 "classSteinberg_1_1ITest.html":[2,0,0,1],
-"classSteinberg_1_1ITest.html#a1976089a2200980e907b3b3532a11f48":[1,0,0,8,3],
+"classSteinberg_1_1ITest.html#a1976089a2200980e907b3b3532a11f48":[1,0,0,13,3],
 "classSteinberg_1_1ITest.html#a1976089a2200980e907b3b3532a11f48":[2,0,0,1,3],
-"classSteinberg_1_1ITest.html#a4400a8b9f2e353b65a2fba78883ca820":[1,0,0,8,1],
+"classSteinberg_1_1ITest.html#a4400a8b9f2e353b65a2fba78883ca820":[1,0,0,13,1],
 "classSteinberg_1_1ITest.html#a4400a8b9f2e353b65a2fba78883ca820":[2,0,0,1,1],
-"classSteinberg_1_1ITest.html#a47a53344d6db1006db6f4008102ae437":[1,0,0,8,2],
+"classSteinberg_1_1ITest.html#a47a53344d6db1006db6f4008102ae437":[1,0,0,13,2],
 "classSteinberg_1_1ITest.html#a47a53344d6db1006db6f4008102ae437":[2,0,0,1,2],
-"classSteinberg_1_1ITest.html#af060cf05dd752b63abfc8a0cb51205c0":[1,0,0,8,0],
+"classSteinberg_1_1ITest.html#af060cf05dd752b63abfc8a0cb51205c0":[1,0,0,13,0],
 "classSteinberg_1_1ITest.html#af060cf05dd752b63abfc8a0cb51205c0":[2,0,0,1,0],
-"classSteinberg_1_1ITestFactory.html":[1,0,0,9],
+"classSteinberg_1_1ITestFactory.html":[1,0,0,14],
 "classSteinberg_1_1ITestFactory.html":[2,0,0,2],
-"classSteinberg_1_1ITestFactory.html#ab9a27b3c53748ad9c1175e862acdc8f4":[1,0,0,9,0],
+"classSteinberg_1_1ITestFactory.html#ab9a27b3c53748ad9c1175e862acdc8f4":[1,0,0,14,0],
 "classSteinberg_1_1ITestFactory.html#ab9a27b3c53748ad9c1175e862acdc8f4":[2,0,0,2,0],
-"classSteinberg_1_1ITestResult.html":[1,0,0,10],
+"classSteinberg_1_1ITestResult.html":[1,0,0,15],
 "classSteinberg_1_1ITestResult.html":[2,0,0,3],
-"classSteinberg_1_1ITestResult.html#ad65829b0d34b7e08770e7c51e2f00f57":[1,0,0,10,1],
+"classSteinberg_1_1ITestResult.html#ad65829b0d34b7e08770e7c51e2f00f57":[1,0,0,15,1],
 "classSteinberg_1_1ITestResult.html#ad65829b0d34b7e08770e7c51e2f00f57":[2,0,0,3,1],
-"classSteinberg_1_1ITestResult.html#aed6eebaa827b0aec9dc5b5e127fa7a66":[1,0,0,10,0],
+"classSteinberg_1_1ITestResult.html#aed6eebaa827b0aec9dc5b5e127fa7a66":[1,0,0,15,0],
 "classSteinberg_1_1ITestResult.html#aed6eebaa827b0aec9dc5b5e127fa7a66":[2,0,0,3,0],
-"classSteinberg_1_1ITestSuite.html":[1,0,0,11],
+"classSteinberg_1_1ITestSuite.html":[1,0,0,16],
 "classSteinberg_1_1ITestSuite.html":[2,0,0,4],
-"classSteinberg_1_1ITestSuite.html#a378a54c5bcba1f3c9e879273c0075bc6":[1,0,0,11,2],
+"classSteinberg_1_1ITestSuite.html#a378a54c5bcba1f3c9e879273c0075bc6":[1,0,0,16,2],
 "classSteinberg_1_1ITestSuite.html#a378a54c5bcba1f3c9e879273c0075bc6":[2,0,0,4,2],
-"classSteinberg_1_1ITestSuite.html#a3a31a9ffef8734f24e4b06ab5c9f4c50":[1,0,0,11,1],
+"classSteinberg_1_1ITestSuite.html#a3a31a9ffef8734f24e4b06ab5c9f4c50":[1,0,0,16,1],
 "classSteinberg_1_1ITestSuite.html#a3a31a9ffef8734f24e4b06ab5c9f4c50":[2,0,0,4,1],
-"classSteinberg_1_1ITestSuite.html#a6538d0c316069abeeae72d2ca4c8f4eb":[1,0,0,11,0],
+"classSteinberg_1_1ITestSuite.html#a6538d0c316069abeeae72d2ca4c8f4eb":[1,0,0,16,0],
 "classSteinberg_1_1ITestSuite.html#a6538d0c316069abeeae72d2ca4c8f4eb":[2,0,0,4,0],
+"classSteinberg_1_1IWaylandFrame.html":[0,10,10],
+"classSteinberg_1_1IWaylandFrame.html":[0,11,1],
+"classSteinberg_1_1IWaylandFrame.html#a055c5ea82125e5669e662779a0b0c0ba":[0,10,10,1],
+"classSteinberg_1_1IWaylandFrame.html#a055c5ea82125e5669e662779a0b0c0ba":[0,11,1,1],
+"classSteinberg_1_1IWaylandFrame.html#a7f589ebeefa8cfdf33f5f2899a20c105":[0,10,10,2],
+"classSteinberg_1_1IWaylandFrame.html#a7f589ebeefa8cfdf33f5f2899a20c105":[0,11,1,2],
+"classSteinberg_1_1IWaylandFrame.html#aa1e0f816ce1621721544a73463590f91":[0,10,10,0],
+"classSteinberg_1_1IWaylandFrame.html#aa1e0f816ce1621721544a73463590f91":[0,11,1,0],
+"classSteinberg_1_1IWaylandHost.html":[0,10,9],
+"classSteinberg_1_1IWaylandHost.html":[0,11,0],
+"classSteinberg_1_1IWaylandHost.html#a75e7b832363bd3f9c9027b5f6aae2d6a":[0,10,9,1],
+"classSteinberg_1_1IWaylandHost.html#a75e7b832363bd3f9c9027b5f6aae2d6a":[0,11,0,1],
+"classSteinberg_1_1IWaylandHost.html#aac1c5eb544d1edda1f83947f67f05648":[0,10,9,0],
+"classSteinberg_1_1IWaylandHost.html#aac1c5eb544d1edda1f83947f67f05648":[0,11,0,0],
 "classSteinberg_1_1Linux_1_1IEventHandler.html":[0,10,5],
 "classSteinberg_1_1Linux_1_1IEventHandler.html#ac953714233e0c3af5f14e7ab8dfc68f5":[0,10,5,0],
 "classSteinberg_1_1Linux_1_1IRunLoop.html":[0,10,7],
@@ -56,198 +69,185 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1Linux_1_1IRunLoop.html#ae84103b4ac33ddbe1fec57d28e917618":[0,10,7,3],
 "classSteinberg_1_1Linux_1_1ITimerHandler.html":[0,10,6],
 "classSteinberg_1_1Linux_1_1ITimerHandler.html#a90a0d24275b47109b29b50f80d95c8d5":[0,10,6,0],
-"classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html":[1,0,0,7,5,0],
+"classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html":[1,0,0,12,5,0],
 "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html":[2,0,0,0,0,0],
-"classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html#a976da6f002de26e9431f1189f7d75b00":[1,0,0,7,5,0,0],
+"classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html#a976da6f002de26e9431f1189f7d75b00":[1,0,0,12,5,0,0],
 "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html#a976da6f002de26e9431f1189f7d75b00":[2,0,0,0,0,0,0],
-"classSteinberg_1_1Vst_1_1IAttributeList.html":[1,0,0,7,36],
+"classSteinberg_1_1Vst_1_1IAttributeList.html":[1,0,0,12,36],
 "classSteinberg_1_1Vst_1_1IAttributeList.html":[2,0,0,0,9],
-"classSteinberg_1_1Vst_1_1IAttributeList.html#a14f06557ea3cda96658afe6896fb34c5":[1,0,0,7,36,7],
+"classSteinberg_1_1Vst_1_1IAttributeList.html#a14f06557ea3cda96658afe6896fb34c5":[1,0,0,12,36,7],
 "classSteinberg_1_1Vst_1_1IAttributeList.html#a14f06557ea3cda96658afe6896fb34c5":[2,0,0,0,9,7],
-"classSteinberg_1_1Vst_1_1IAttributeList.html#a1e207585ce257192e8746924baaa9a7c":[1,0,0,7,36,5],
+"classSteinberg_1_1Vst_1_1IAttributeList.html#a1e207585ce257192e8746924baaa9a7c":[1,0,0,12,36,5],
 "classSteinberg_1_1Vst_1_1IAttributeList.html#a1e207585ce257192e8746924baaa9a7c":[2,0,0,0,9,5],
-"classSteinberg_1_1Vst_1_1IAttributeList.html#a25f64b8d44505736988478be3c3ea3db":[1,0,0,7,36,1],
+"classSteinberg_1_1Vst_1_1IAttributeList.html#a25f64b8d44505736988478be3c3ea3db":[1,0,0,12,36,1],
 "classSteinberg_1_1Vst_1_1IAttributeList.html#a25f64b8d44505736988478be3c3ea3db":[2,0,0,0,9,1],
-"classSteinberg_1_1Vst_1_1IAttributeList.html#a55f4e61bbda9656f83cddff7ff64f15f":[1,0,0,7,36,6],
+"classSteinberg_1_1Vst_1_1IAttributeList.html#a55f4e61bbda9656f83cddff7ff64f15f":[1,0,0,12,36,6],
 "classSteinberg_1_1Vst_1_1IAttributeList.html#a55f4e61bbda9656f83cddff7ff64f15f":[2,0,0,0,9,6],
-"classSteinberg_1_1Vst_1_1IAttributeList.html#a5fcd359925f64b686e4e7e08113aae97":[1,0,0,7,36,3],
+"classSteinberg_1_1Vst_1_1IAttributeList.html#a5fcd359925f64b686e4e7e08113aae97":[1,0,0,12,36,3],
 "classSteinberg_1_1Vst_1_1IAttributeList.html#a5fcd359925f64b686e4e7e08113aae97":[2,0,0,0,9,3],
-"classSteinberg_1_1Vst_1_1IAttributeList.html#a9b9d196fc07b7c2c141f16acb5d0fd57":[1,0,0,7,36,8],
+"classSteinberg_1_1Vst_1_1IAttributeList.html#a9b9d196fc07b7c2c141f16acb5d0fd57":[1,0,0,12,36,8],
 "classSteinberg_1_1Vst_1_1IAttributeList.html#a9b9d196fc07b7c2c141f16acb5d0fd57":[2,0,0,0,9,8],
-"classSteinberg_1_1Vst_1_1IAttributeList.html#aa17533c77e99f8fc18c7fb0dac5b1810":[1,0,0,7,36,2],
+"classSteinberg_1_1Vst_1_1IAttributeList.html#aa17533c77e99f8fc18c7fb0dac5b1810":[1,0,0,12,36,2],
 "classSteinberg_1_1Vst_1_1IAttributeList.html#aa17533c77e99f8fc18c7fb0dac5b1810":[2,0,0,0,9,2],
-"classSteinberg_1_1Vst_1_1IAttributeList.html#ab6b5900e7149bdf8a032ed98397f9cec":[1,0,0,7,36,4],
+"classSteinberg_1_1Vst_1_1IAttributeList.html#ab6b5900e7149bdf8a032ed98397f9cec":[1,0,0,12,36,4],
 "classSteinberg_1_1Vst_1_1IAttributeList.html#ab6b5900e7149bdf8a032ed98397f9cec":[2,0,0,0,9,4],
-"classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html":[1,0,0,7,37],
+"classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html":[1,0,0,12,37],
 "classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html":[2,0,0,0,10],
-"classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html#a835590540d23f3bdc831cfdad872196e":[1,0,0,7,37,0],
+"classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html#a835590540d23f3bdc831cfdad872196e":[1,0,0,12,37,0],
 "classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html#a835590540d23f3bdc831cfdad872196e":[2,0,0,0,10,0],
-"classSteinberg_1_1Vst_1_1IAudioProcessor.html":[1,0,0,7,38],
+"classSteinberg_1_1Vst_1_1IAudioProcessor.html":[1,0,0,12,38],
 "classSteinberg_1_1Vst_1_1IAudioProcessor.html":[2,0,0,0,11],
-"classSteinberg_1_1Vst_1_1IAudioProcessor.html#a6b98eb31cf38ba96a28b303c13c64e13":[1,0,0,7,38,6],
+"classSteinberg_1_1Vst_1_1IAudioProcessor.html#a6b98eb31cf38ba96a28b303c13c64e13":[1,0,0,12,38,6],
 "classSteinberg_1_1Vst_1_1IAudioProcessor.html#a6b98eb31cf38ba96a28b303c13c64e13":[2,0,0,0,11,6],
-"classSteinberg_1_1Vst_1_1IAudioProcessor.html#aa1a6f9c030b9b2f5c0602dca309bb23b":[1,0,0,7,38,2],
+"classSteinberg_1_1Vst_1_1IAudioProcessor.html#aa1a6f9c030b9b2f5c0602dca309bb23b":[1,0,0,12,38,2],
 "classSteinberg_1_1Vst_1_1IAudioProcessor.html#aa1a6f9c030b9b2f5c0602dca309bb23b":[2,0,0,0,11,2],
-"classSteinberg_1_1Vst_1_1IAudioProcessor.html#abb6b16a66b2356a4038a778b815dbbf3":[1,0,0,7,38,7],
+"classSteinberg_1_1Vst_1_1IAudioProcessor.html#abb6b16a66b2356a4038a778b815dbbf3":[1,0,0,12,38,7],
 "classSteinberg_1_1Vst_1_1IAudioProcessor.html#abb6b16a66b2356a4038a778b815dbbf3":[2,0,0,0,11,7],
-"classSteinberg_1_1Vst_1_1IAudioProcessor.html#ad3bc7bac3fd3b194122669be2a1ecc42":[1,0,0,7,38,0],
+"classSteinberg_1_1Vst_1_1IAudioProcessor.html#ad3bc7bac3fd3b194122669be2a1ecc42":[1,0,0,12,38,0],
 "classSteinberg_1_1Vst_1_1IAudioProcessor.html#ad3bc7bac3fd3b194122669be2a1ecc42":[2,0,0,0,11,0],
-"classSteinberg_1_1Vst_1_1IAudioProcessor.html#adac76e90d4a18622d818c8204f937f94":[1,0,0,7,38,1],
+"classSteinberg_1_1Vst_1_1IAudioProcessor.html#adac76e90d4a18622d818c8204f937f94":[1,0,0,12,38,1],
 "classSteinberg_1_1Vst_1_1IAudioProcessor.html#adac76e90d4a18622d818c8204f937f94":[2,0,0,0,11,1],
-"classSteinberg_1_1Vst_1_1IAudioProcessor.html#aefb5731b94dbc899a4a7e9cd1c96e6a2":[1,0,0,7,38,4],
+"classSteinberg_1_1Vst_1_1IAudioProcessor.html#aefb5731b94dbc899a4a7e9cd1c96e6a2":[1,0,0,12,38,4],
 "classSteinberg_1_1Vst_1_1IAudioProcessor.html#aefb5731b94dbc899a4a7e9cd1c96e6a2":[2,0,0,0,11,4],
-"classSteinberg_1_1Vst_1_1IAudioProcessor.html#af252fd721b195b793f3a5dfffc069401":[1,0,0,7,38,5],
+"classSteinberg_1_1Vst_1_1IAudioProcessor.html#af252fd721b195b793f3a5dfffc069401":[1,0,0,12,38,5],
 "classSteinberg_1_1Vst_1_1IAudioProcessor.html#af252fd721b195b793f3a5dfffc069401":[2,0,0,0,11,5],
-"classSteinberg_1_1Vst_1_1IAudioProcessor.html#af8884671ccefe68e0a86e72413a0fcf8":[1,0,0,7,38,3],
+"classSteinberg_1_1Vst_1_1IAudioProcessor.html#af8884671ccefe68e0a86e72413a0fcf8":[1,0,0,12,38,3],
 "classSteinberg_1_1Vst_1_1IAudioProcessor.html#af8884671ccefe68e0a86e72413a0fcf8":[2,0,0,0,11,3],
-"classSteinberg_1_1Vst_1_1IAutomationState.html":[1,0,0,7,39],
+"classSteinberg_1_1Vst_1_1IAutomationState.html":[1,0,0,12,39],
 "classSteinberg_1_1Vst_1_1IAutomationState.html":[2,0,0,0,12],
-"classSteinberg_1_1Vst_1_1IAutomationState.html#a94a3fc5cff03de098873a4495a4d4c07":[1,0,0,7,39,1],
+"classSteinberg_1_1Vst_1_1IAutomationState.html#a94a3fc5cff03de098873a4495a4d4c07":[1,0,0,12,39,1],
 "classSteinberg_1_1Vst_1_1IAutomationState.html#a94a3fc5cff03de098873a4495a4d4c07":[2,0,0,0,12,1],
-"classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719":[1,0,0,7,39,0],
+"classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719":[1,0,0,12,39,0],
 "classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719":[2,0,0,0,12,0],
-"classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719a27168d4bbe8c328ccc1c61c18e5e86cf":[1,0,0,7,39,0,1],
+"classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719a27168d4bbe8c328ccc1c61c18e5e86cf":[1,0,0,12,39,0,1],
 "classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719a27168d4bbe8c328ccc1c61c18e5e86cf":[2,0,0,0,12,0,1],
-"classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719a50593589ab3b2b6bc94d914caf926e8a":[1,0,0,7,39,0,0],
+"classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719a50593589ab3b2b6bc94d914caf926e8a":[1,0,0,12,39,0,0],
 "classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719a50593589ab3b2b6bc94d914caf926e8a":[2,0,0,0,12,0,0],
-"classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719a91c9e6284228f8fed9c09539698ff6c1":[1,0,0,7,39,0,3],
+"classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719a91c9e6284228f8fed9c09539698ff6c1":[1,0,0,12,39,0,3],
 "classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719a91c9e6284228f8fed9c09539698ff6c1":[2,0,0,0,12,0,3],
-"classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719ad3b29f3c6c1d4b45e32c9782ac13b4ad":[1,0,0,7,39,0,2],
+"classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719ad3b29f3c6c1d4b45e32c9782ac13b4ad":[1,0,0,12,39,0,2],
 "classSteinberg_1_1Vst_1_1IAutomationState.html#ab92119cb4745f1106c18a44f6d7d7719ad3b29f3c6c1d4b45e32c9782ac13b4ad":[2,0,0,0,12,0,2],
-"classSteinberg_1_1Vst_1_1IComponent.html":[1,0,0,7,40],
+"classSteinberg_1_1Vst_1_1IComponent.html":[1,0,0,12,40],
 "classSteinberg_1_1Vst_1_1IComponent.html":[2,0,0,0,13],
-"classSteinberg_1_1Vst_1_1IComponent.html#a0a840e8077eb74ec429b8007c7b83517":[1,0,0,7,40,6],
+"classSteinberg_1_1Vst_1_1IComponent.html#a0a840e8077eb74ec429b8007c7b83517":[1,0,0,12,40,6],
 "classSteinberg_1_1Vst_1_1IComponent.html#a0a840e8077eb74ec429b8007c7b83517":[2,0,0,0,13,6],
-"classSteinberg_1_1Vst_1_1IComponent.html#a10db03106be8ba89d23859fa6be5d9f6":[1,0,0,7,40,8],
+"classSteinberg_1_1Vst_1_1IComponent.html#a10db03106be8ba89d23859fa6be5d9f6":[1,0,0,12,40,8],
 "classSteinberg_1_1Vst_1_1IComponent.html#a10db03106be8ba89d23859fa6be5d9f6":[2,0,0,0,13,8],
-"classSteinberg_1_1Vst_1_1IComponent.html#a3ab7d06aaefe03da1fcd1819f1261050":[1,0,0,7,40,5],
+"classSteinberg_1_1Vst_1_1IComponent.html#a3ab7d06aaefe03da1fcd1819f1261050":[1,0,0,12,40,5],
 "classSteinberg_1_1Vst_1_1IComponent.html#a3ab7d06aaefe03da1fcd1819f1261050":[2,0,0,0,13,5],
-"classSteinberg_1_1Vst_1_1IComponent.html#a41b0e971a0ff153a4eb34274750b0c91":[1,0,0,7,40,3],
+"classSteinberg_1_1Vst_1_1IComponent.html#a41b0e971a0ff153a4eb34274750b0c91":[1,0,0,12,40,3],
 "classSteinberg_1_1Vst_1_1IComponent.html#a41b0e971a0ff153a4eb34274750b0c91":[2,0,0,0,13,3],
-"classSteinberg_1_1Vst_1_1IComponent.html#a4618e7358890d549f990010bea4a4137":[1,0,0,7,40,1],
+"classSteinberg_1_1Vst_1_1IComponent.html#a4618e7358890d549f990010bea4a4137":[1,0,0,12,40,1],
 "classSteinberg_1_1Vst_1_1IComponent.html#a4618e7358890d549f990010bea4a4137":[2,0,0,0,13,1],
-"classSteinberg_1_1Vst_1_1IComponent.html#a5a0edc226a66259a6b8fe6f693101d77":[1,0,0,7,40,2],
+"classSteinberg_1_1Vst_1_1IComponent.html#a5a0edc226a66259a6b8fe6f693101d77":[1,0,0,12,40,2],
 "classSteinberg_1_1Vst_1_1IComponent.html#a5a0edc226a66259a6b8fe6f693101d77":[2,0,0,0,13,2],
-"classSteinberg_1_1Vst_1_1IComponent.html#a77ac39bcc5c4b15818b1a87de2573805":[1,0,0,7,40,7],
+"classSteinberg_1_1Vst_1_1IComponent.html#a77ac39bcc5c4b15818b1a87de2573805":[1,0,0,12,40,7],
 "classSteinberg_1_1Vst_1_1IComponent.html#a77ac39bcc5c4b15818b1a87de2573805":[2,0,0,0,13,7],
-"classSteinberg_1_1Vst_1_1IComponent.html#a8aa65685068ad033af57b1497926b689":[1,0,0,7,40,0],
+"classSteinberg_1_1Vst_1_1IComponent.html#a8aa65685068ad033af57b1497926b689":[1,0,0,12,40,0],
 "classSteinberg_1_1Vst_1_1IComponent.html#a8aa65685068ad033af57b1497926b689":[2,0,0,0,13,0],
-"classSteinberg_1_1Vst_1_1IComponent.html#aa0ffeccad3c44364a199ce56365a4c12":[1,0,0,7,40,4],
+"classSteinberg_1_1Vst_1_1IComponent.html#aa0ffeccad3c44364a199ce56365a4c12":[1,0,0,12,40,4],
 "classSteinberg_1_1Vst_1_1IComponent.html#aa0ffeccad3c44364a199ce56365a4c12":[2,0,0,0,13,4],
-"classSteinberg_1_1Vst_1_1IComponentHandler.html":[1,0,0,7,41],
+"classSteinberg_1_1Vst_1_1IComponentHandler.html":[1,0,0,12,41],
 "classSteinberg_1_1Vst_1_1IComponentHandler.html":[2,0,0,0,14],
-"classSteinberg_1_1Vst_1_1IComponentHandler.html#a135d4e76355ef0ba0a4162a0546d5f93":[1,0,0,7,41,1],
+"classSteinberg_1_1Vst_1_1IComponentHandler.html#a135d4e76355ef0ba0a4162a0546d5f93":[1,0,0,12,41,1],
 "classSteinberg_1_1Vst_1_1IComponentHandler.html#a135d4e76355ef0ba0a4162a0546d5f93":[2,0,0,0,14,1],
-"classSteinberg_1_1Vst_1_1IComponentHandler.html#a1f283573728cf0807224c5ebdf3ec3a6":[1,0,0,7,41,3],
+"classSteinberg_1_1Vst_1_1IComponentHandler.html#a1f283573728cf0807224c5ebdf3ec3a6":[1,0,0,12,41,3],
 "classSteinberg_1_1Vst_1_1IComponentHandler.html#a1f283573728cf0807224c5ebdf3ec3a6":[2,0,0,0,14,3],
-"classSteinberg_1_1Vst_1_1IComponentHandler.html#a8456ad739430267a12dda11a53fe9223":[1,0,0,7,41,0],
+"classSteinberg_1_1Vst_1_1IComponentHandler.html#a8456ad739430267a12dda11a53fe9223":[1,0,0,12,41,0],
 "classSteinberg_1_1Vst_1_1IComponentHandler.html#a8456ad739430267a12dda11a53fe9223":[2,0,0,0,14,0],
-"classSteinberg_1_1Vst_1_1IComponentHandler.html#ae380206486b11f000cad7c0d9b6e877c":[1,0,0,7,41,2],
+"classSteinberg_1_1Vst_1_1IComponentHandler.html#ae380206486b11f000cad7c0d9b6e877c":[1,0,0,12,41,2],
 "classSteinberg_1_1Vst_1_1IComponentHandler.html#ae380206486b11f000cad7c0d9b6e877c":[2,0,0,0,14,2],
-"classSteinberg_1_1Vst_1_1IComponentHandler2.html":[1,0,0,7,42],
+"classSteinberg_1_1Vst_1_1IComponentHandler2.html":[1,0,0,12,42],
 "classSteinberg_1_1Vst_1_1IComponentHandler2.html":[2,0,0,0,15],
-"classSteinberg_1_1Vst_1_1IComponentHandler2.html#aa457d0550984879c4094c578b914fb6d":[1,0,0,7,42,0],
+"classSteinberg_1_1Vst_1_1IComponentHandler2.html#aa457d0550984879c4094c578b914fb6d":[1,0,0,12,42,0],
 "classSteinberg_1_1Vst_1_1IComponentHandler2.html#aa457d0550984879c4094c578b914fb6d":[2,0,0,0,15,0],
-"classSteinberg_1_1Vst_1_1IComponentHandler2.html#aba339113df404a6b3c557774d4aa9102":[1,0,0,7,42,2],
+"classSteinberg_1_1Vst_1_1IComponentHandler2.html#aba339113df404a6b3c557774d4aa9102":[1,0,0,12,42,2],
 "classSteinberg_1_1Vst_1_1IComponentHandler2.html#aba339113df404a6b3c557774d4aa9102":[2,0,0,0,15,2],
-"classSteinberg_1_1Vst_1_1IComponentHandler2.html#ac7d37d88b53e9517e1b696bef2d47fa5":[1,0,0,7,42,1],
+"classSteinberg_1_1Vst_1_1IComponentHandler2.html#ac7d37d88b53e9517e1b696bef2d47fa5":[1,0,0,12,42,1],
 "classSteinberg_1_1Vst_1_1IComponentHandler2.html#ac7d37d88b53e9517e1b696bef2d47fa5":[2,0,0,0,15,1],
-"classSteinberg_1_1Vst_1_1IComponentHandler2.html#adbdc10ff7ecd96fa365ad4f98d57b55e":[1,0,0,7,42,3],
+"classSteinberg_1_1Vst_1_1IComponentHandler2.html#adbdc10ff7ecd96fa365ad4f98d57b55e":[1,0,0,12,42,3],
 "classSteinberg_1_1Vst_1_1IComponentHandler2.html#adbdc10ff7ecd96fa365ad4f98d57b55e":[2,0,0,0,15,3],
-"classSteinberg_1_1Vst_1_1IComponentHandler3.html":[1,0,0,7,43],
+"classSteinberg_1_1Vst_1_1IComponentHandler3.html":[1,0,0,12,43],
 "classSteinberg_1_1Vst_1_1IComponentHandler3.html":[2,0,0,0,16],
-"classSteinberg_1_1Vst_1_1IComponentHandler3.html#abf7aec615dce3825ab63e47c946ef6a8":[1,0,0,7,43,0],
+"classSteinberg_1_1Vst_1_1IComponentHandler3.html#abf7aec615dce3825ab63e47c946ef6a8":[1,0,0,12,43,0],
 "classSteinberg_1_1Vst_1_1IComponentHandler3.html#abf7aec615dce3825ab63e47c946ef6a8":[2,0,0,0,16,0],
-"classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html":[1,0,0,7,44],
+"classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html":[1,0,0,12,44],
 "classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html":[2,0,0,0,17],
-"classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html#a9a2bf35a7e6bc9dede587900312137fc":[1,0,0,7,44,0],
+"classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html#a9a2bf35a7e6bc9dede587900312137fc":[1,0,0,12,44,0],
 "classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html#a9a2bf35a7e6bc9dede587900312137fc":[2,0,0,0,17,0],
-"classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html":[1,0,0,7,45],
+"classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html":[1,0,0,12,45],
 "classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html":[2,0,0,0,18],
-"classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html#acdbd89d88d7123f96e2920c2715749fb":[1,0,0,7,45,0],
+"classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html#acdbd89d88d7123f96e2920c2715749fb":[1,0,0,12,45,0],
 "classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html#acdbd89d88d7123f96e2920c2715749fb":[2,0,0,0,18,0],
-"classSteinberg_1_1Vst_1_1IConnectionPoint.html":[1,0,0,7,46],
+"classSteinberg_1_1Vst_1_1IConnectionPoint.html":[1,0,0,12,46],
 "classSteinberg_1_1Vst_1_1IConnectionPoint.html":[2,0,0,0,19],
-"classSteinberg_1_1Vst_1_1IConnectionPoint.html#a870cdbe19a2c9798e1e68fab65e72a77":[1,0,0,7,46,2],
+"classSteinberg_1_1Vst_1_1IConnectionPoint.html#a870cdbe19a2c9798e1e68fab65e72a77":[1,0,0,12,46,2],
 "classSteinberg_1_1Vst_1_1IConnectionPoint.html#a870cdbe19a2c9798e1e68fab65e72a77":[2,0,0,0,19,2],
-"classSteinberg_1_1Vst_1_1IConnectionPoint.html#aa65d68182357737c7a1f7736400565c2":[1,0,0,7,46,0],
+"classSteinberg_1_1Vst_1_1IConnectionPoint.html#aa65d68182357737c7a1f7736400565c2":[1,0,0,12,46,0],
 "classSteinberg_1_1Vst_1_1IConnectionPoint.html#aa65d68182357737c7a1f7736400565c2":[2,0,0,0,19,0],
-"classSteinberg_1_1Vst_1_1IConnectionPoint.html#ad85bd437968bec6e403fb3cba699b01e":[1,0,0,7,46,1],
+"classSteinberg_1_1Vst_1_1IConnectionPoint.html#ad85bd437968bec6e403fb3cba699b01e":[1,0,0,12,46,1],
 "classSteinberg_1_1Vst_1_1IConnectionPoint.html#ad85bd437968bec6e403fb3cba699b01e":[2,0,0,0,19,1],
-"classSteinberg_1_1Vst_1_1IContextMenu.html":[1,0,0,7,47],
+"classSteinberg_1_1Vst_1_1IContextMenu.html":[1,0,0,12,47],
 "classSteinberg_1_1Vst_1_1IContextMenu.html":[2,0,0,0,20],
-"classSteinberg_1_1Vst_1_1IContextMenu.html#a241e6e88af766e7075c675215a62c82d":[1,0,0,7,47,2],
+"classSteinberg_1_1Vst_1_1IContextMenu.html#a241e6e88af766e7075c675215a62c82d":[1,0,0,12,47,2],
 "classSteinberg_1_1Vst_1_1IContextMenu.html#a241e6e88af766e7075c675215a62c82d":[2,0,0,0,20,2],
-"classSteinberg_1_1Vst_1_1IContextMenu.html#a8d6e113be32dfccabcacca0c81ee6f10":[1,0,0,7,47,5],
+"classSteinberg_1_1Vst_1_1IContextMenu.html#a8d6e113be32dfccabcacca0c81ee6f10":[1,0,0,12,47,5],
 "classSteinberg_1_1Vst_1_1IContextMenu.html#a8d6e113be32dfccabcacca0c81ee6f10":[2,0,0,0,20,5],
-"classSteinberg_1_1Vst_1_1IContextMenu.html#aa52f902d26c33aebde2ee96beb9fae28":[1,0,0,7,47,4],
+"classSteinberg_1_1Vst_1_1IContextMenu.html#aa52f902d26c33aebde2ee96beb9fae28":[1,0,0,12,47,4],
 "classSteinberg_1_1Vst_1_1IContextMenu.html#aa52f902d26c33aebde2ee96beb9fae28":[2,0,0,0,20,4],
-"classSteinberg_1_1Vst_1_1IContextMenu.html#aaabd9d08e6c2ff48c35ca2d1f664e124":[1,0,0,7,47,0],
+"classSteinberg_1_1Vst_1_1IContextMenu.html#aaabd9d08e6c2ff48c35ca2d1f664e124":[1,0,0,12,47,0],
 "classSteinberg_1_1Vst_1_1IContextMenu.html#aaabd9d08e6c2ff48c35ca2d1f664e124":[2,0,0,0,20,0],
-"classSteinberg_1_1Vst_1_1IContextMenu.html#ac0c7c1da210637ba2bb458b21580272f":[1,0,0,7,47,1],
+"classSteinberg_1_1Vst_1_1IContextMenu.html#ac0c7c1da210637ba2bb458b21580272f":[1,0,0,12,47,1],
 "classSteinberg_1_1Vst_1_1IContextMenu.html#ac0c7c1da210637ba2bb458b21580272f":[2,0,0,0,20,1],
-"classSteinberg_1_1Vst_1_1IContextMenu.html#ac172d5fa00b2028a352c704dd906f236":[1,0,0,7,47,3],
+"classSteinberg_1_1Vst_1_1IContextMenu.html#ac172d5fa00b2028a352c704dd906f236":[1,0,0,12,47,3],
 "classSteinberg_1_1Vst_1_1IContextMenu.html#ac172d5fa00b2028a352c704dd906f236":[2,0,0,0,20,3],
-"classSteinberg_1_1Vst_1_1IContextMenuTarget.html":[1,0,0,7,49],
+"classSteinberg_1_1Vst_1_1IContextMenuTarget.html":[1,0,0,12,49],
 "classSteinberg_1_1Vst_1_1IContextMenuTarget.html":[2,0,0,0,22],
-"classSteinberg_1_1Vst_1_1IContextMenuTarget.html#a4a1e98d2d18ded53b636b7f36cb9f83f":[1,0,0,7,49,0],
+"classSteinberg_1_1Vst_1_1IContextMenuTarget.html#a4a1e98d2d18ded53b636b7f36cb9f83f":[1,0,0,12,49,0],
 "classSteinberg_1_1Vst_1_1IContextMenuTarget.html#a4a1e98d2d18ded53b636b7f36cb9f83f":[2,0,0,0,22,0],
-"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html":[1,0,0,7,50],
+"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html":[1,0,0,12,50],
 "classSteinberg_1_1Vst_1_1IDataExchangeHandler.html":[2,0,0,0,23],
-"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a025c90a7215ee8e868dee3fac262c204":[1,0,0,7,50,3],
+"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a025c90a7215ee8e868dee3fac262c204":[1,0,0,12,50,3],
 "classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a025c90a7215ee8e868dee3fac262c204":[2,0,0,0,23,3],
-"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a364dfe59ecafb51bd6520fa5ce527540":[1,0,0,7,50,2],
+"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a364dfe59ecafb51bd6520fa5ce527540":[1,0,0,12,50,2],
 "classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a364dfe59ecafb51bd6520fa5ce527540":[2,0,0,0,23,2],
-"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a9901db75c791ff2879a906b19ed388d9":[1,0,0,7,50,0],
+"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a9901db75c791ff2879a906b19ed388d9":[1,0,0,12,50,0],
 "classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a9901db75c791ff2879a906b19ed388d9":[2,0,0,0,23,0],
-"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#ac0c45b4a114f40b229820fcd8121d4c8":[1,0,0,7,50,1],
+"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#ac0c45b4a114f40b229820fcd8121d4c8":[1,0,0,12,50,1],
 "classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#ac0c45b4a114f40b229820fcd8121d4c8":[2,0,0,0,23,1],
-"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html":[1,0,0,7,51],
+"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html":[1,0,0,12,51],
 "classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html":[2,0,0,0,24],
-"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#a0145a4f12f524bb3f9bfe42cb66ad27c":[1,0,0,7,51,0],
+"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#a0145a4f12f524bb3f9bfe42cb66ad27c":[1,0,0,12,51,0],
 "classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#a0145a4f12f524bb3f9bfe42cb66ad27c":[2,0,0,0,24,0],
-"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#a37b2181ff0ae9bdc0a6feee03b65df42":[1,0,0,7,51,1],
+"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#a37b2181ff0ae9bdc0a6feee03b65df42":[1,0,0,12,51,1],
 "classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#a37b2181ff0ae9bdc0a6feee03b65df42":[2,0,0,0,24,1],
-"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#ae443e9ae05f5504aadff05412c8195e6":[1,0,0,7,51,2],
+"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#ae443e9ae05f5504aadff05412c8195e6":[1,0,0,12,51,2],
 "classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#ae443e9ae05f5504aadff05412c8195e6":[2,0,0,0,24,2],
-"classSteinberg_1_1Vst_1_1IEditController.html":[1,0,0,7,52],
+"classSteinberg_1_1Vst_1_1IEditController.html":[1,0,0,12,52],
 "classSteinberg_1_1Vst_1_1IEditController.html":[2,0,0,0,25],
-"classSteinberg_1_1Vst_1_1IEditController.html#a0ba78602ecf2f5e8d747d8b01d4cfb6c":[1,0,0,7,52,4],
+"classSteinberg_1_1Vst_1_1IEditController.html#a0ba78602ecf2f5e8d747d8b01d4cfb6c":[1,0,0,12,52,4],
 "classSteinberg_1_1Vst_1_1IEditController.html#a0ba78602ecf2f5e8d747d8b01d4cfb6c":[2,0,0,0,25,4],
-"classSteinberg_1_1Vst_1_1IEditController.html#a10db03106be8ba89d23859fa6be5d9f6":[1,0,0,7,52,2],
+"classSteinberg_1_1Vst_1_1IEditController.html#a10db03106be8ba89d23859fa6be5d9f6":[1,0,0,12,52,2],
 "classSteinberg_1_1Vst_1_1IEditController.html#a10db03106be8ba89d23859fa6be5d9f6":[2,0,0,0,25,2],
-"classSteinberg_1_1Vst_1_1IEditController.html#a2fe381a8fb8412e6854c941dbb085fec":[1,0,0,7,52,12],
+"classSteinberg_1_1Vst_1_1IEditController.html#a2fe381a8fb8412e6854c941dbb085fec":[1,0,0,12,52,12],
 "classSteinberg_1_1Vst_1_1IEditController.html#a2fe381a8fb8412e6854c941dbb085fec":[2,0,0,0,25,12],
-"classSteinberg_1_1Vst_1_1IEditController.html#a4c2e1cafd88143fda2767a9c7ba5d48f":[1,0,0,7,52,0],
+"classSteinberg_1_1Vst_1_1IEditController.html#a4c2e1cafd88143fda2767a9c7ba5d48f":[1,0,0,12,52,0],
 "classSteinberg_1_1Vst_1_1IEditController.html#a4c2e1cafd88143fda2767a9c7ba5d48f":[2,0,0,0,25,0],
-"classSteinberg_1_1Vst_1_1IEditController.html#a77ac39bcc5c4b15818b1a87de2573805":[1,0,0,7,52,1],
+"classSteinberg_1_1Vst_1_1IEditController.html#a77ac39bcc5c4b15818b1a87de2573805":[1,0,0,12,52,1],
 "classSteinberg_1_1Vst_1_1IEditController.html#a77ac39bcc5c4b15818b1a87de2573805":[2,0,0,0,25,1],
-"classSteinberg_1_1Vst_1_1IEditController.html#a849747dc98909312b4cdbdeea82dbae0":[1,0,0,7,52,7],
+"classSteinberg_1_1Vst_1_1IEditController.html#a849747dc98909312b4cdbdeea82dbae0":[1,0,0,12,52,7],
 "classSteinberg_1_1Vst_1_1IEditController.html#a849747dc98909312b4cdbdeea82dbae0":[2,0,0,0,25,7],
-"classSteinberg_1_1Vst_1_1IEditController.html#aab2f0b853e75361d331b667e7893962e":[1,0,0,7,52,5],
+"classSteinberg_1_1Vst_1_1IEditController.html#aab2f0b853e75361d331b667e7893962e":[1,0,0,12,52,5],
 "classSteinberg_1_1Vst_1_1IEditController.html#aab2f0b853e75361d331b667e7893962e":[2,0,0,0,25,5],
-"classSteinberg_1_1Vst_1_1IEditController.html#aab5ccab5fd1cc1cd0a59afd90279dd81":[1,0,0,7,52,11],
+"classSteinberg_1_1Vst_1_1IEditController.html#aab5ccab5fd1cc1cd0a59afd90279dd81":[1,0,0,12,52,11],
 "classSteinberg_1_1Vst_1_1IEditController.html#aab5ccab5fd1cc1cd0a59afd90279dd81":[2,0,0,0,25,11],
-"classSteinberg_1_1Vst_1_1IEditController.html#ab6ffbb8e3bf6f4829ab1c9c23fe935a1":[1,0,0,7,52,3],
+"classSteinberg_1_1Vst_1_1IEditController.html#ab6ffbb8e3bf6f4829ab1c9c23fe935a1":[1,0,0,12,52,3],
 "classSteinberg_1_1Vst_1_1IEditController.html#ab6ffbb8e3bf6f4829ab1c9c23fe935a1":[2,0,0,0,25,3],
-"classSteinberg_1_1Vst_1_1IEditController.html#ac5abbadd4c8326fae66fd1e63bdc15b3":[1,0,0,7,52,9],
+"classSteinberg_1_1Vst_1_1IEditController.html#ac5abbadd4c8326fae66fd1e63bdc15b3":[1,0,0,12,52,9],
 "classSteinberg_1_1Vst_1_1IEditController.html#ac5abbadd4c8326fae66fd1e63bdc15b3":[2,0,0,0,25,9],
-"classSteinberg_1_1Vst_1_1IEditController.html#aded549c5b0f342a23dee18cc41ece6b8":[1,0,0,7,52,10],
+"classSteinberg_1_1Vst_1_1IEditController.html#aded549c5b0f342a23dee18cc41ece6b8":[1,0,0,12,52,10],
 "classSteinberg_1_1Vst_1_1IEditController.html#aded549c5b0f342a23dee18cc41ece6b8":[2,0,0,0,25,10],
-"classSteinberg_1_1Vst_1_1IEditController.html#ae9706616ae6d938bbf102954f8f2f110":[1,0,0,7,52,8],
+"classSteinberg_1_1Vst_1_1IEditController.html#ae9706616ae6d938bbf102954f8f2f110":[1,0,0,12,52,8],
 "classSteinberg_1_1Vst_1_1IEditController.html#ae9706616ae6d938bbf102954f8f2f110":[2,0,0,0,25,8],
-"classSteinberg_1_1Vst_1_1IEditController.html#af4254a0360b21f8871a61c62fb317058":[1,0,0,7,52,6],
-"classSteinberg_1_1Vst_1_1IEditController.html#af4254a0360b21f8871a61c62fb317058":[2,0,0,0,25,6],
-"classSteinberg_1_1Vst_1_1IEditController2.html":[1,0,0,7,53],
-"classSteinberg_1_1Vst_1_1IEditController2.html":[2,0,0,0,26],
-"classSteinberg_1_1Vst_1_1IEditController2.html#a749ceb08d2f33b5b12cdc59172d8a7c3":[1,0,0,7,53,1],
-"classSteinberg_1_1Vst_1_1IEditController2.html#a749ceb08d2f33b5b12cdc59172d8a7c3":[2,0,0,0,26,1],
-"classSteinberg_1_1Vst_1_1IEditController2.html#aa52846d39014c3ca95224fa98930e7a8":[1,0,0,7,53,2],
-"classSteinberg_1_1Vst_1_1IEditController2.html#aa52846d39014c3ca95224fa98930e7a8":[2,0,0,0,26,2],
-"classSteinberg_1_1Vst_1_1IEditController2.html#ad38ac70a9efcc0cfee8ac0cc2b80e648":[1,0,0,7,53,0],
-"classSteinberg_1_1Vst_1_1IEditController2.html#ad38ac70a9efcc0cfee8ac0cc2b80e648":[2,0,0,0,26,0],
-"classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html":[1,0,0,7,54],
-"classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html":[2,0,0,0,27],
-"classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html#a589c94be69d4ee5ed29cf62e437fecbb":[1,0,0,7,54,1],
-"classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html#a589c94be69d4ee5ed29cf62e437fecbb":[2,0,0,0,27,1]
+"classSteinberg_1_1Vst_1_1IEditController.html#af4254a0360b21f8871a61c62fb317058":[1,0,0,12,52,6]
 };
