@@ -1,5 +1,34 @@
 var NAVTREEINDEX2 =
 {
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a6f1b43425ba894764f35b7d492e81c53":[2,0,0,0,57,8],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a718fa905d04d7d559bc89c7ca761413b":[1,0,0,12,84,10],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a718fa905d04d7d559bc89c7ca761413b":[2,0,0,0,57,10],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a7cbc86917a614918938277be9bb52e6f":[1,0,0,12,84,11],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a7cbc86917a614918938277be9bb52e6f":[2,0,0,0,57,11],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#ac40c799f1f52837c311ac153d7a8ead7":[1,0,0,12,84,5],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#ac40c799f1f52837c311ac153d7a8ead7":[2,0,0,0,57,5],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#ad32cdcda859f588c84e76133f2d62923":[1,0,0,12,84,1],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#ad32cdcda859f588c84e76133f2d62923":[2,0,0,0,57,1],
+"classSteinberg_1_1Vst_1_1IVst3ToAAXWrapper.html":[1,0,0,12,85],
+"classSteinberg_1_1Vst_1_1IVst3ToAAXWrapper.html":[2,0,0,0,58],
+"classSteinberg_1_1Vst_1_1IVst3ToAUWrapper.html":[1,0,0,12,86],
+"classSteinberg_1_1Vst_1_1IVst3ToAUWrapper.html":[2,0,0,0,59],
+"classSteinberg_1_1Vst_1_1IVst3ToVst2Wrapper.html":[1,0,0,12,87],
+"classSteinberg_1_1Vst_1_1IVst3ToVst2Wrapper.html":[2,0,0,0,60],
+"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html":[1,0,0,12,88],
+"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html":[2,0,0,0,61],
+"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#a322e79e7c76c3e2b5f717e9666870c58":[1,0,0,12,88,0],
+"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#a322e79e7c76c3e2b5f717e9666870c58":[2,0,0,0,61,0],
+"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#ae3cece9ab989e0769cb14377e2f719b1":[1,0,0,12,88,1],
+"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#ae3cece9ab989e0769cb14377e2f719b1":[2,0,0,0,61,1],
+"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html":[1,0,0,12,89],
+"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html":[2,0,0,0,62],
+"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html#a12aaff5f46c6f620fb724e9c9763ac21":[1,0,0,12,89,0],
+"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html#a12aaff5f46c6f620fb724e9c9763ac21":[2,0,0,0,62,0],
+"classes.html":[2,1],
+"dir_2b55989507b85f9714d7502e3b031586.html":[3,0,0,0],
+"dir_2fcc4ce6f11e0f407f9d20609d32c488.html":[3,0,0,2],
+"dir_a16602e771dbe98bb8f2594e31082617.html":[3,0,0],
 "dir_d97542da2fcf294e7d73be8ba6c1a565.html":[3,0,0,1],
 "files.html":[3,0],
 "functions.html":[2,3,0],
@@ -220,34 +249,5 @@ var NAVTREEINDEX2 =
 "group__musicalInstrument.html#gaf85c8e569ae8d22ab2c233006a99f82e":[0,4,30],
 "group__musicalInstrument.html#gaf8cf7e44674db2aca92f56fd73f92006":[0,4,76],
 "group__musicalInstrument.html#gaf907f1b0c6b112a7a7ef2c26d181345b":[0,4,45],
-"group__musicalInstrument.html#gafd8251cd1e2beb471fb880eff54122a2":[0,4,90],
-"group__musicalStyle.html":[0,5],
-"group__musicalStyle.html#ga00100f8944908f3f674b077b8e7bf5ae":[0,5,18],
-"group__musicalStyle.html#ga03a11de347ee7fbfa80f6040e5838c06":[0,5,91],
-"group__musicalStyle.html#ga04e06e3becb8bca4036fd5856682a393":[0,5,50],
-"group__musicalStyle.html#ga04fc9ede978682cf37a56876ba9dba9d":[0,5,59],
-"group__musicalStyle.html#ga070e85734aa0ebd786f2c8ff8dca8301":[0,5,13],
-"group__musicalStyle.html#ga080e7eebf7cfeef648604aab356d9249":[0,5,7],
-"group__musicalStyle.html#ga09caf2a39534495b771aa65a0d969ad1":[0,5,99],
-"group__musicalStyle.html#ga0ade597c6d17afc9e6cf4a7bdf34de9b":[0,5,57],
-"group__musicalStyle.html#ga0d9c9e5d1d7762b13270a0cd388b2d7e":[0,5,3],
-"group__musicalStyle.html#ga0ee890f05a7479865af9eda6d34bc857":[0,5,62],
-"group__musicalStyle.html#ga13e10384c541982e7ebea23ae4cc0057":[0,5,51],
-"group__musicalStyle.html#ga1578d35d598b30c1a8aca33c94e33213":[0,5,36],
-"group__musicalStyle.html#ga17f0e511cbcdedf14156ba499a54d615":[0,5,100],
-"group__musicalStyle.html#ga1a1b8c73dee78995dfc73a9cbe1855fa":[0,5,26],
-"group__musicalStyle.html#ga1abdca80184a162d425c61f053530dea":[0,5,12],
-"group__musicalStyle.html#ga1b66689bf69717c4af8ad85835737acf":[0,5,79],
-"group__musicalStyle.html#ga1e43c81772b3227d2239c4c869194733":[0,5,81],
-"group__musicalStyle.html#ga2283c2c777c7cbb21710e11ef2ceb6af":[0,5,0],
-"group__musicalStyle.html#ga24447081033911845dd5279102bf075b":[0,5,98],
-"group__musicalStyle.html#ga27a783d5bce0708e88414cd4de0ffc3b":[0,5,44],
-"group__musicalStyle.html#ga2acd1ccf8c493d7055288674c243e7f0":[0,5,38],
-"group__musicalStyle.html#ga2b8b2179cf8d2b74f6c0eb2abb563a80":[0,5,4],
-"group__musicalStyle.html#ga3089241b92ddf52d670f6339c57ff321":[0,5,90],
-"group__musicalStyle.html#ga31d1f86b5f8a0281d2a85f7ae6e40d10":[0,5,92],
-"group__musicalStyle.html#ga33320722a4e37a0dbe61f8957a77fcb8":[0,5,10],
-"group__musicalStyle.html#ga33a8a991563a9d73923525ddd29e79a0":[0,5,105],
-"group__musicalStyle.html#ga370c692d8ab858d11bff12c0ea4c779c":[0,5,80],
-"group__musicalStyle.html#ga3ae32b316261fa76c8d7ca0e9790871f":[0,5,103]
+"group__musicalInstrument.html#gafd8251cd1e2beb471fb880eff54122a2":[0,4,90]
 };
