@@ -1,5 +1,34 @@
 var NAVTREEINDEX3 =
 {
+"group__musicalStyle.html":[0,5],
+"group__musicalStyle.html#ga00100f8944908f3f674b077b8e7bf5ae":[0,5,18],
+"group__musicalStyle.html#ga03a11de347ee7fbfa80f6040e5838c06":[0,5,91],
+"group__musicalStyle.html#ga04e06e3becb8bca4036fd5856682a393":[0,5,50],
+"group__musicalStyle.html#ga04fc9ede978682cf37a56876ba9dba9d":[0,5,59],
+"group__musicalStyle.html#ga070e85734aa0ebd786f2c8ff8dca8301":[0,5,13],
+"group__musicalStyle.html#ga080e7eebf7cfeef648604aab356d9249":[0,5,7],
+"group__musicalStyle.html#ga09caf2a39534495b771aa65a0d969ad1":[0,5,99],
+"group__musicalStyle.html#ga0ade597c6d17afc9e6cf4a7bdf34de9b":[0,5,57],
+"group__musicalStyle.html#ga0d9c9e5d1d7762b13270a0cd388b2d7e":[0,5,3],
+"group__musicalStyle.html#ga0ee890f05a7479865af9eda6d34bc857":[0,5,62],
+"group__musicalStyle.html#ga13e10384c541982e7ebea23ae4cc0057":[0,5,51],
+"group__musicalStyle.html#ga1578d35d598b30c1a8aca33c94e33213":[0,5,36],
+"group__musicalStyle.html#ga17f0e511cbcdedf14156ba499a54d615":[0,5,100],
+"group__musicalStyle.html#ga1a1b8c73dee78995dfc73a9cbe1855fa":[0,5,26],
+"group__musicalStyle.html#ga1abdca80184a162d425c61f053530dea":[0,5,12],
+"group__musicalStyle.html#ga1b66689bf69717c4af8ad85835737acf":[0,5,79],
+"group__musicalStyle.html#ga1e43c81772b3227d2239c4c869194733":[0,5,81],
+"group__musicalStyle.html#ga2283c2c777c7cbb21710e11ef2ceb6af":[0,5,0],
+"group__musicalStyle.html#ga24447081033911845dd5279102bf075b":[0,5,98],
+"group__musicalStyle.html#ga27a783d5bce0708e88414cd4de0ffc3b":[0,5,44],
+"group__musicalStyle.html#ga2acd1ccf8c493d7055288674c243e7f0":[0,5,38],
+"group__musicalStyle.html#ga2b8b2179cf8d2b74f6c0eb2abb563a80":[0,5,4],
+"group__musicalStyle.html#ga3089241b92ddf52d670f6339c57ff321":[0,5,90],
+"group__musicalStyle.html#ga31d1f86b5f8a0281d2a85f7ae6e40d10":[0,5,92],
+"group__musicalStyle.html#ga33320722a4e37a0dbe61f8957a77fcb8":[0,5,10],
+"group__musicalStyle.html#ga33a8a991563a9d73923525ddd29e79a0":[0,5,105],
+"group__musicalStyle.html#ga370c692d8ab858d11bff12c0ea4c779c":[0,5,80],
+"group__musicalStyle.html#ga3ae32b316261fa76c8d7ca0e9790871f":[0,5,103],
 "group__musicalStyle.html#ga3ccf2f159b7b1becbe0d64f4688f7f4e":[0,5,15],
 "group__musicalStyle.html#ga3d85eb586a37b5a6082a6d1708d91592":[0,5,106],
 "group__musicalStyle.html#ga3dd2ebf4652bdc7f67e804099495ad1b":[0,5,94],
@@ -82,6 +111,24 @@ var NAVTREEINDEX3 =
 "group__musicalStyle.html#gafdb7e50d604be148bcab627102c66a3b":[0,5,71],
 "group__musicalStyle.html#gaff54f68acdbdbbbed6054f5c9b17ba8a":[0,5,104],
 "group__platformUIType.html":[0,10,0],
+"group__platformUIType.html#ga111998b5f362f172b2c0edce7bfe3552":[0,10,0,5],
+"group__platformUIType.html#ga111998b5f362f172b2c0edce7bfe3552":[0,10,0,11],
+"group__platformUIType.html#ga111998b5f362f172b2c0edce7bfe3552":[1,0,0,290],
+"group__platformUIType.html#ga6362a7ca65b87d30c561dac986b757bd":[0,10,0,3],
+"group__platformUIType.html#ga6362a7ca65b87d30c561dac986b757bd":[0,10,0,9],
+"group__platformUIType.html#ga6362a7ca65b87d30c561dac986b757bd":[1,0,0,288],
+"group__platformUIType.html#ga8ce69944b5475d65206469b9ebcbf755":[0,10,0,2],
+"group__platformUIType.html#ga8ce69944b5475d65206469b9ebcbf755":[0,10,0,8],
+"group__platformUIType.html#ga8ce69944b5475d65206469b9ebcbf755":[1,0,0,287],
+"group__platformUIType.html#ga974cabea219cb31ad8218ba15d1f7071":[0,10,0,1],
+"group__platformUIType.html#ga974cabea219cb31ad8218ba15d1f7071":[0,10,0,7],
+"group__platformUIType.html#ga974cabea219cb31ad8218ba15d1f7071":[1,0,0,286],
+"group__platformUIType.html#gaa1e68ac1f25da9c85c937d0360dbc601":[0,10,0,0],
+"group__platformUIType.html#gaa1e68ac1f25da9c85c937d0360dbc601":[0,10,0,6],
+"group__platformUIType.html#gaa1e68ac1f25da9c85c937d0360dbc601":[1,0,0,285],
+"group__platformUIType.html#gac945decc5f26f3fdb5419e8de833a0e1":[0,10,0,4],
+"group__platformUIType.html#gac945decc5f26f3fdb5419e8de833a0e1":[0,10,0,10],
+"group__platformUIType.html#gac945decc5f26f3fdb5419e8de833a0e1":[1,0,0,289],
 "group__plugType.html":[0,0],
 "group__plugType.html#ga0017ff4ab459880956723e09c847188a":[0,0,1],
 "group__plugType.html#ga0091b72150adc715454c410d230127e9":[0,0,24],
@@ -138,6 +185,19 @@ var NAVTREEINDEX3 =
 "group__presetAttributes.html#gacbad3647c9f27b2777cb6a3cd24fe49e":[0,2,0],
 "group__presetAttributes.html#gad5fe1f71ae69e7b4daaf0e79130930c3":[0,2,6],
 "group__presetAttributes.html#gaefefe46f30651266cc9ccc8908409552":[0,2,5],
+"group__sdkBase.html#ga4474115d0c145ca7e10e4dfd2f372122":[1,0,0,10,1],
+"group__sdkBase.html#ga573e89b755a4d476e281d5687fc7de84":[1,0,0,132],
+"group__sdkBase.html#ga7c77f85bd1460fe895ef3c29a361462d":[1,0,0,10,0],
+"group__sdkBase.html#ga9161593ad3336650b604b9b7ceb15b81":[1,0,0,133],
+"group__smtgtypedef.html#ga0e747a3b854268949a75a1c8e8fd070c":[1,0,0,282],
+"group__smtgtypedef.html#ga1c13255fbcd5845d44bd45cc27bd3586":[1,0,0,283],
+"group__smtgtypedef.html#ga2ae80314db54c6bda33e1cf922effb47":[1,0,0,280],
+"group__smtgtypedef.html#ga45a730ec762ad31ab0e5c80e15560afc":[1,0,0,284],
+"group__smtgtypedef.html#ga6a838f230987e1a095b0cb75c28d4a65":[1,0,0,89],
+"group__smtgtypedef.html#ga728f0ddc16a12be5fa0f950f4c8a0a8e":[1,0,0,90],
+"group__smtgtypedef.html#ga75ec4b5d086d2af3733ac3775ab008d8":[0,10,8,0],
+"group__smtgtypedef.html#ga81eef9745d0b6653c6a1c78bb89533d8":[1,0,0,91],
+"group__smtgtypedef.html#gad5ffc071fd688ac833b5283777037278":[1,0,0,281],
 "group__speakerArrangements.html":[0,7],
 "group__speakerArrangements.html#ga0049a81a50306a41abd45f0871e13173":[0,7,387],
 "group__speakerArrangements.html#ga006f007337addc5c126777bc9e9b774d":[0,7,343],
@@ -189,65 +249,5 @@ var NAVTREEINDEX3 =
 "group__speakerArrangements.html#ga28381a787f5d2e84e16067329d0efc00":[0,7,271],
 "group__speakerArrangements.html#ga2990e1e187ac62b502407cad4fea5ae7":[0,7,391],
 "group__speakerArrangements.html#ga29b4840204d45e234269f8ca643728af":[0,7,13],
-"group__speakerArrangements.html#ga29b55e791de7fa8d4efdb6948d40db09":[0,7,20],
-"group__speakerArrangements.html#ga2a834a6c97df49e2fa45315ff7045533":[0,7,48],
-"group__speakerArrangements.html#ga2abe9ebdaff5cae2f2581a558cb3eb02":[0,7,255],
-"group__speakerArrangements.html#ga2b7412e5a07fbbce4e641a8fa7b81001":[0,7,285],
-"group__speakerArrangements.html#ga2d6583c536b80d854cbd733eea9877f9":[0,7,68],
-"group__speakerArrangements.html#ga2ebfc79a0e5ef338247e31239967632d":[0,7,113],
-"group__speakerArrangements.html#ga2f2f2eb56bcf2977ad670a752c69d793":[0,7,332],
-"group__speakerArrangements.html#ga2f656b124363f1656327bf5fb9e7dc48":[0,7,297],
-"group__speakerArrangements.html#ga2fb8698f83d75be166b99fdbce9e82f1":[0,7,108],
-"group__speakerArrangements.html#ga300b4574ad12477ff99286519b754dfe":[0,7,140],
-"group__speakerArrangements.html#ga301aef980be40689f6a32d2f2ea5990d":[0,7,250],
-"group__speakerArrangements.html#ga3087980012d3e5dee03f977677790623":[0,7,258],
-"group__speakerArrangements.html#ga30a288eb79dfa6b08afb569234e831d2":[0,7,245],
-"group__speakerArrangements.html#ga3151e2974547b528528e913542dd5292":[0,7,300],
-"group__speakerArrangements.html#ga3160617565b0ad36d34a025fe119bbb6":[0,7,310],
-"group__speakerArrangements.html#ga31865a34aa4e3eca16df14729ff1629f":[0,7,213],
-"group__speakerArrangements.html#ga319dbf573206d0bb1a8b77e7f476548d":[0,7,401],
-"group__speakerArrangements.html#ga31c77ba2ccde7c76357149b9be8d1141":[0,7,169],
-"group__speakerArrangements.html#ga329178a60998946671c5de893797dddf":[0,7,107],
-"group__speakerArrangements.html#ga32b8626cc036129ae6465115e7d33c5a":[0,7,91],
-"group__speakerArrangements.html#ga341a094c1693e21946264eb706155c32":[0,7,353],
-"group__speakerArrangements.html#ga3475b1b161d22aca3939960e461307a5":[0,7,234],
-"group__speakerArrangements.html#ga34a5ea5d19e507a4cc75aaf5ca038e70":[0,7,231],
-"group__speakerArrangements.html#ga34c39373e8684ea0bdd623206d23f92a":[0,7,57],
-"group__speakerArrangements.html#ga34fbc53e44aafa8ca50155a58bd056fe":[0,7,94],
-"group__speakerArrangements.html#ga350fe92a4a9f185ff5a7141e7cbada14":[0,7,86],
-"group__speakerArrangements.html#ga3531cf9980f8fbeb289280f70cb82eb0":[0,7,56],
-"group__speakerArrangements.html#ga35ac01519b72d4f2ebc88a7621467378":[0,7,233],
-"group__speakerArrangements.html#ga35c11fa95eb4ed5340307b725c53180d":[0,7,247],
-"group__speakerArrangements.html#ga3633546c0ee46e3c70c52843faf722e6":[0,7,51],
-"group__speakerArrangements.html#ga36a920fcf904e74af45153417e6bda20":[0,7,393],
-"group__speakerArrangements.html#ga3789962208da8454667b34aa666981db":[0,7,326],
-"group__speakerArrangements.html#ga3818a39d5d27234b78a6dfa41385c749":[0,7,75],
-"group__speakerArrangements.html#ga38bd79e07efa7b1b2825a614e25e597e":[0,7,43],
-"group__speakerArrangements.html#ga38c557da6a4db5884d2d688c30cc5553":[0,7,203],
-"group__speakerArrangements.html#ga39cdd95afef98e1901ebdb99183e91f2":[0,7,211],
-"group__speakerArrangements.html#ga39dd41aa48652def01c2b774f3a46a02":[0,7,187],
-"group__speakerArrangements.html#ga3a48ceea90b000d970319d3c5370855b":[0,7,168],
-"group__speakerArrangements.html#ga3a6e7551ec2aebccdb70236a29eaae2d":[0,7,134],
-"group__speakerArrangements.html#ga3b0b6d1ed6af07daa84a016f9a594d59":[0,7,272],
-"group__speakerArrangements.html#ga3cb0fc4337ff0f43bf119b20c7f5d810":[0,7,312],
-"group__speakerArrangements.html#ga41826ce2877ff6e8fc93c8d4aa85647e":[0,7,61],
-"group__speakerArrangements.html#ga419904483b34cd1d809100f7388d50b7":[0,7,195],
-"group__speakerArrangements.html#ga41db9e2cbe4b39f58fb972feee953d21":[0,7,10],
-"group__speakerArrangements.html#ga42ee84421893fe9759b400d0bd3becaf":[0,7,253],
-"group__speakerArrangements.html#ga44710b9a538279e604b98213e8acdbec":[0,7,83],
-"group__speakerArrangements.html#ga447cbeb4a66d7a12f6c36240b666331a":[0,7,193],
-"group__speakerArrangements.html#ga4496b8a1fc103ed42e399eca71048d12":[0,7,150],
-"group__speakerArrangements.html#ga44ee3dd3579cc26082915d76a28be70f":[0,7,128],
-"group__speakerArrangements.html#ga45b8a48950dee4f9713bda0a5b9ca196":[0,7,261],
-"group__speakerArrangements.html#ga4623d9c5afc0883aa25409a89fc4b01c":[0,7,254],
-"group__speakerArrangements.html#ga47554e8c117d0119288c796708533bd5":[0,7,365],
-"group__speakerArrangements.html#ga48d6693407aff2059d23dbee4e9c4e6c":[0,7,4],
-"group__speakerArrangements.html#ga48d6c553097c808e4d720a20af732555":[0,7,182],
-"group__speakerArrangements.html#ga49ccafdb4653781c17fa20f933a29af2":[0,7,270],
-"group__speakerArrangements.html#ga4a24b9cdab9b5ed5af4ae28cbe8f7205":[0,7,351],
-"group__speakerArrangements.html#ga4a84febf8ecee1a6ba6c0a8786d378c3":[0,7,397],
-"group__speakerArrangements.html#ga4b0a12de443ae669b9dce39400837571":[0,7,40],
-"group__speakerArrangements.html#ga4b10dc09ef678e66e90330f5b6b591d0":[0,7,336],
-"group__speakerArrangements.html#ga4b1241bc660c2cd6fe752e2f3a1d6de7":[0,7,342],
-"group__speakerArrangements.html#ga4c68f76511df6119eca847b005105cd5":[0,7,116]
+"group__speakerArrangements.html#ga29b55e791de7fa8d4efdb6948d40db09":[0,7,20]
 };
