@@ -6,7 +6,7 @@ var searchData=
   ['editordestroyed_3',['editorDestroyed',['../../vstsdk/classSteinberg_1_1Vst_1_1EditController.html#a0d848355600e651408719e8a288426ef',1,'Steinberg::Vst::EditController']]],
   ['editorremoved_4',['editorRemoved',['../../vstsdk/classSteinberg_1_1Vst_1_1EditController.html#a30a5f278c9ad42c540a11823241e59e3',1,'Steinberg::Vst::EditController']]],
   ['editorview_5',['EditorView',['../../vstsdk/classSteinberg_1_1Vst_1_1EditorView.html',1,'EditorView'],['../../vstsdk/classSteinberg_1_1Vst_1_1EditorView.html#a04fe421361ccb6e2127b486a198e7adf',1,'Steinberg::Vst::EditorView::EditorView()']]],
-  ['email_6',['email',['../../base/structSteinberg_1_1PFactoryInfo.html#a371bd4486f2314c56b0dc15665ac2825',1,'Steinberg::PFactoryInfo::email'],['../../vstsdk/classVST3_1_1Hosting_1_1FactoryInfo.html#aab48f577414d7c9d0008bb27dec6eca5',1,'VST3::Hosting::FactoryInfo::email()']]],
+  ['email_6',['email',['../../base/structSteinberg_1_1PFactoryInfo.html#a371bd4486f2314c56b0dc15665ac2825',1,'Steinberg::PFactoryInfo::email'],['../../vstsdk/structSteinberg_1_1ModuleInfo_1_1FactoryInfo.html#a39f10874f551f4c4ad837e516691e4e6',1,'Steinberg::ModuleInfo::FactoryInfo::email'],['../../vstsdk/classVST3_1_1Hosting_1_1FactoryInfo.html#aab48f577414d7c9d0008bb27dec6eca5',1,'VST3::Hosting::FactoryInfo::email()']]],
   ['empty_7',['empty',['../../base/classSteinberg_1_1FVariant.html#a9a4d7b0a805f99ab95362516ee336b3e',1,'Steinberg::FVariant']]],
   ['enable_8',['enable',['../../vstsdk/classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a66d8feb44d790d1c96e76ffd13b54bb0',1,'Steinberg::Vst::DataExchangeHandler']]],
   ['enablempeinputprocessing_9',['enableMPEInputProcessing',['../classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#a322e79e7c76c3e2b5f717e9666870c58',1,'Steinberg::Vst::IVst3WrapperMPESupport']]],
