@@ -3,7 +3,7 @@ var searchData=
   ['scaleevent_0',['ScaleEvent',['../structSteinberg_1_1Vst_1_1ScaleEvent.html',1,'Steinberg::Vst']]],
   ['setup_1',['Setup',['../../vstsdk/structSteinberg_1_1Vst_1_1MPE_1_1Setup.html',1,'Steinberg::Vst::MPE']]],
   ['singlecomponenteffect_2',['SingleComponentEffect',['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html',1,'Steinberg::Vst']]],
-  ['snapshot_3',['Snapshot',['../../vstsdk/structVST3_1_1Hosting_1_1Module_1_1Snapshot.html',1,'VST3::Hosting::Module']]],
+  ['snapshot_3',['Snapshot',['../../vstsdk/structSteinberg_1_1ModuleInfo_1_1Snapshot.html',1,'Snapshot'],['../../vstsdk/structVST3_1_1Hosting_1_1Module_1_1Snapshot.html',1,'Snapshot']]],
   ['speakerarray_4',['SpeakerArray',['../../vstsdk/classSteinberg_1_1Vst_1_1SpeakerArray.html',1,'Steinberg::Vst']]],
   ['stringlistparameter_5',['StringListParameter',['../../vstsdk/classSteinberg_1_1Vst_1_1StringListParameter.html',1,'Steinberg::Vst']]],
   ['stringresult_6',['StringResult',['../../vstsdk/classSteinberg_1_1Vst_1_1StringResult.html',1,'Steinberg::Vst']]],
