@@ -9,6 +9,12 @@ var searchData=
   ['module_5flinux_2ecpp_6',['module_linux.cpp',['../../vstsdk/module__linux_8cpp.html',1,'']]],
   ['module_5fmac_2emm_7',['module_mac.mm',['../../vstsdk/module__mac_8mm.html',1,'']]],
   ['module_5fwin32_2ecpp_8',['module_win32.cpp',['../../vstsdk/module__win32_8cpp.html',1,'']]],
-  ['mpeprocessor_2ecpp_9',['mpeprocessor.cpp',['../../vstsdk/mpeprocessor_8cpp.html',1,'']]],
-  ['mpeprocessor_2eh_10',['mpeprocessor.h',['../../vstsdk/mpeprocessor_8h.html',1,'']]]
+  ['moduleinfo_2eh_9',['moduleinfo.h',['../../vstsdk/moduleinfo_8h.html',1,'']]],
+  ['moduleinfocreator_2ecpp_10',['moduleinfocreator.cpp',['../../vstsdk/moduleinfocreator_8cpp.html',1,'']]],
+  ['moduleinfocreator_2eh_11',['moduleinfocreator.h',['../../vstsdk/moduleinfocreator_8h.html',1,'']]],
+  ['moduleinfoparser_2ecpp_12',['moduleinfoparser.cpp',['../../vstsdk/moduleinfoparser_8cpp.html',1,'']]],
+  ['moduleinfoparser_2eh_13',['moduleinfoparser.h',['../../vstsdk/moduleinfoparser_8h.html',1,'']]],
+  ['moduleinit_2eh_14',['moduleinit.h',['../../vstsdk/moduleinit_8h.html',1,'']]],
+  ['mpeprocessor_2ecpp_15',['mpeprocessor.cpp',['../../vstsdk/mpeprocessor_8cpp.html',1,'']]],
+  ['mpeprocessor_2eh_16',['mpeprocessor.h',['../../vstsdk/mpeprocessor_8h.html',1,'']]]
 ];
