@@ -3,7 +3,7 @@ var searchData=
   ['banklsb_0',['BankLSB',['../../vstsdk/structSteinberg_1_1Vst_1_1UMP_1_1IUniversalMidiPacketHandler.html#afbb0e21dbbe231a4fc86d49064bc8ac1',1,'Steinberg::Vst::UMP::IUniversalMidiPacketHandler']]],
   ['bankmsb_1',['BankMSB',['../../vstsdk/structSteinberg_1_1Vst_1_1UMP_1_1IUniversalMidiPacketHandler.html#a22e7795020c0f4e77e675d92594db478',1,'Steinberg::Vst::UMP::IUniversalMidiPacketHandler']]],
   ['banknumber_2',['BankNumber',['../../vstsdk/structSteinberg_1_1Vst_1_1UMP_1_1IUniversalMidiPacketHandler.html#aa61c467c7213eaf8394b00f5535d9a17',1,'Steinberg::Vst::UMP::IUniversalMidiPacketHandler']]],
-  ['base_3',['Base',['../../base/classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html#a2fcc41284c370068704fcd87160d7099',1,'Steinberg::FUnknownImpl::ImplementsImpl&lt; BaseClass, Directly&lt; I, DirectIFs... &gt;, Indirectly&lt; IndirectIFs... &gt; &gt;']]],
-  ['busdirection_4',['BusDirection',['../namespaceSteinberg_1_1Vst.html#a0dc035dac7916366d61df365731f7b63',1,'Steinberg::Vst']]],
-  ['bustype_5',['BusType',['../namespaceSteinberg_1_1Vst.html#aa6029db01759d30cfcb3504b84d5d04f',1,'Steinberg::Vst']]]
+  ['busdirection_3',['BusDirection',['../group__vst3typedef.html#ga0dc035dac7916366d61df365731f7b63',1,'Steinberg::Vst']]],
+  ['busindex_4',['BusIndex',['../namespaceSteinberg_1_1Vst.html#accb693c3515fc981c452e8683fd8523f',1,'Steinberg::Vst']]],
+  ['bustype_5',['BusType',['../group__vst3typedef.html#gaa6029db01759d30cfcb3504b84d5d04f',1,'Steinberg::Vst']]]
 ];
