@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['email_0',['email',['../../base/structSteinberg_1_1PFactoryInfo.html#a371bd4486f2314c56b0dc15665ac2825',1,'Steinberg::PFactoryInfo']]],
+  ['email_0',['email',['../../base/structSteinberg_1_1PFactoryInfo.html#a371bd4486f2314c56b0dc15665ac2825',1,'Steinberg::PFactoryInfo::email'],['../../vstsdk/structSteinberg_1_1ModuleInfo_1_1FactoryInfo.html#a39f10874f551f4c4ad837e516691e4e6',1,'Steinberg::ModuleInfo::FactoryInfo::email']]],
   ['entries_1',['entries',['../../vstsdk/classSteinberg_1_1Vst_1_1PresetFile.html#a83b23e1334542a860af5f8f6a9b813bf',1,'Steinberg::Vst::PresetFile']]],
   ['entrycount_2',['entryCount',['../../vstsdk/classSteinberg_1_1Vst_1_1PresetFile.html#a4f71f86dadbbb1cf5a477c64587ca491',1,'Steinberg::Vst::PresetFile']]],
   ['eventinputs_3',['eventInputs',['../../vstsdk/classSteinberg_1_1Vst_1_1Component.html#a183bab90c30bb13225535e57cbe982b0',1,'Steinberg::Vst::Component::eventInputs'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a183bab90c30bb13225535e57cbe982b0',1,'Steinberg::Vst::SingleComponentEffect::eventInputs']]],
