@@ -25,9 +25,27 @@ var namespaceSteinberg =
     ] ],
     [ "Linux", "../base/namespaceSteinberg_1_1Linux.html", [
       [ "TimerInterval", "../base/namespaceSteinberg_1_1Linux.html#ad94d4fecedeef98b5d1709b61cfa0e7c", null ],
-      [ "FileDescriptor", "../base/namespaceSteinberg_1_1Linux.html#a9c80aaf6d9c6451b471e97de46595753", null ]
+      [ "FileDescriptor", "../base/namespaceSteinberg_1_1Linux.html#a9c80aaf6d9c6451b471e97de46595753", null ],
+      [ "setupVSTGUIRunloop", "../base/namespaceSteinberg_1_1Linux.html#a1b28e608caed211ed220b3f71a28848b", null ]
+    ] ],
+    [ "ModuleInfoLib", "namespaceSteinberg_1_1ModuleInfoLib.html", [
+      [ "createModuleInfo", "namespaceSteinberg_1_1ModuleInfoLib.html#a4117d027c9b52e6940b247a8ec3b8f39", null ],
+      [ "outputJson", "namespaceSteinberg_1_1ModuleInfoLib.html#a858102d84872d222cb591df6a8629549", null ],
+      [ "parseJson", "namespaceSteinberg_1_1ModuleInfoLib.html#a31a7664a41c79d05d65fe4f0736003b3", null ],
+      [ "parseCompatibilityJson", "namespaceSteinberg_1_1ModuleInfoLib.html#a8456b0a8791d15a9fe626ecd18f54fc5", null ]
     ] ],
     [ "OneReaderOneWriter", "namespaceSteinberg_1_1OneReaderOneWriter.html", "namespaceSteinberg_1_1OneReaderOneWriter" ],
+    [ "PluginFactoryDetail", "namespaceSteinberg_1_1PluginFactoryDetail.html", "namespaceSteinberg_1_1PluginFactoryDetail" ],
+    [ "StringConvert", "namespaceSteinberg_1_1StringConvert.html", [
+      [ "convert", "namespaceSteinberg_1_1StringConvert.html#a7b24e433664bafa3dd3f9357ec3f6c4d", null ],
+      [ "convert", "namespaceSteinberg_1_1StringConvert.html#abff8a368026b5ff872b48945fcf3113f", null ],
+      [ "convert", "namespaceSteinberg_1_1StringConvert.html#ab20bb6b50e97de71fea1897b45dca317", null ],
+      [ "toString", "namespaceSteinberg_1_1StringConvert.html#a450e4b1073502d7b8346a6c0bb856c2d", null ]
+    ] ],
+    [ "SystemClipboard", "namespaceSteinberg_1_1SystemClipboard.html", [
+      [ "copyTextToClipboard", "group__sdkBase.html#ga7c77f85bd1460fe895ef3c29a361462d", null ],
+      [ "getTextFromClipboard", "group__sdkBase.html#ga4474115d0c145ca7e10e4dfd2f372122", null ]
+    ] ],
     [ "U", "../base/namespaceSteinberg_1_1U.html", [
       [ "Unknown", "../base/namespaceSteinberg_1_1U.html#a68f6e121eb237b7f588f0036b056b43b", null ],
       [ "Extends", "../base/namespaceSteinberg_1_1U.html#ad7c3d8fc183de6c65cb7209c4edda8a7", null ],
@@ -39,41 +57,49 @@ var namespaceSteinberg =
     [ "Vst", "../vstinterfaces/namespaceSteinberg_1_1Vst.html", "namespaceSteinberg_1_1Vst" ],
     [ "CPluginFactory", "classSteinberg_1_1CPluginFactory.html", "classSteinberg_1_1CPluginFactory" ],
     [ "CPluginView", "classSteinberg_1_1CPluginView.html", "classSteinberg_1_1CPluginView" ],
+    [ "IPluginFactoryInternal", "classSteinberg_1_1IPluginFactoryInternal.html", "classSteinberg_1_1IPluginFactoryInternal" ],
     [ "MemoryStream", "classSteinberg_1_1MemoryStream.html", "classSteinberg_1_1MemoryStream" ],
+    [ "ModuleInfo", "structSteinberg_1_1ModuleInfo.html", "structSteinberg_1_1ModuleInfo" ],
+    [ "ModuleInitializer", "structSteinberg_1_1ModuleInitializer.html", "structSteinberg_1_1ModuleInitializer" ],
+    [ "ModuleTerminator", "structSteinberg_1_1ModuleTerminator.html", "structSteinberg_1_1ModuleTerminator" ],
     [ "ObjCClassBuilder", "structSteinberg_1_1ObjCClassBuilder.html", "structSteinberg_1_1ObjCClassBuilder" ],
     [ "ObjCInstance", "structSteinberg_1_1ObjCInstance.html", "structSteinberg_1_1ObjCInstance" ],
     [ "ObjCVariable", "structSteinberg_1_1ObjCVariable.html", "structSteinberg_1_1ObjCVariable" ],
+    [ "PluginFactory", "classSteinberg_1_1PluginFactory.html", "classSteinberg_1_1PluginFactory" ],
     [ "ResizableMemoryIBStream", "classSteinberg_1_1ResizableMemoryIBStream.html", "classSteinberg_1_1ResizableMemoryIBStream" ],
-    [ "int8", "../base/namespaceSteinberg.html#ae47c588f3ab8c61121c1c7ab7edc47cd", null ],
-    [ "uint8", "../base/namespaceSteinberg.html#a33a5e996e7a90acefb8b1c0bea47e365", null ],
-    [ "uchar", "../base/namespaceSteinberg.html#a65f85814a8290f9797005d3b28e7e5fc", null ],
-    [ "int16", "../base/namespaceSteinberg.html#aa0d0fdc87fd135ef2bedb030901cdb9c", null ],
-    [ "uint16", "../base/namespaceSteinberg.html#ac2a9e79eb120216f855626495b7bd18a", null ],
-    [ "int32", "../base/namespaceSteinberg.html#ab7903878916593daecbeb95b98115ab0", null ],
-    [ "uint32", "../base/namespaceSteinberg.html#acbd4acd0d29e2d6c43104827f77d9cd2", null ],
-    [ "int64", "../base/namespaceSteinberg.html#a7cde0074dfd288f2d70c0e035dacb28a", null ],
-    [ "uint64", "../base/namespaceSteinberg.html#abc0f5bc07737e498f287334775dff2b6", null ],
-    [ "TSize", "../base/namespaceSteinberg.html#abc5a03f91bd781b5062f4fccaa7851f0", null ],
-    [ "tresult", "../base/namespaceSteinberg.html#a902761e005a6252e538c766de48fc957", null ],
-    [ "TPtrInt", "../base/namespaceSteinberg.html#adbdfa470c35e7bf57d7952f0767bbf57", null ],
-    [ "TBool", "../base/namespaceSteinberg.html#a1ea8addd740f35d207a1569dd38ef895", null ],
-    [ "char8", "../base/namespaceSteinberg.html#ac9e1c0f508ae0f5f8a2b704a91e1ae86", null ],
-    [ "char16", "../base/namespaceSteinberg.html#a667a0a4e0cbcb3f3785984955e1fefd8", null ],
-    [ "char", "../base/namespaceSteinberg.html#aa9eb7d301130a7771343735bef461579", null ],
-    [ "CStringA", "../base/namespaceSteinberg.html#a435992556581fbc31a9bddb3bb2f787a", null ],
-    [ "CStringW", "../base/namespaceSteinberg.html#a81b4df0e8189d2f135f25919a6a90be2", null ],
-    [ "CString", "../base/namespaceSteinberg.html#a6f37e0dbf8faed21d2658800d9db4583", null ],
-    [ "FIDString", "../base/namespaceSteinberg.html#ad4c02134d1ee42389f3d94717935a1d5", null ],
-    [ "UCoord", "../base/namespaceSteinberg.html#abf33a8b245f4634965116e9c25eb702a", null ],
-    [ "LARGE_INT", "../base/namespaceSteinberg.html#a9cd1730908299276af7bc0baa8c5197e", null ],
-    [ "TUID", "../base/namespaceSteinberg.html#a6935af93744bfe4ecc455f274ef1ec36", null ],
-    [ "IAttrID", "../base/namespaceSteinberg.html#ae6eacc17e4382538d4af0d9993bc869a", null ],
-    [ "ColorSpec", "../base/namespaceSteinberg.html#a5b13d028fba1eee386ec9ac208c6238d", null ],
-    [ "ColorComponent", "../base/namespaceSteinberg.html#af1189c83b63820c6ccc3167402601fea", null ],
-    [ "UColorSpec", "../base/namespaceSteinberg.html#a87699df6cd24276f34afea51d903c6e4", null ],
-    [ "UColorComponent", "../base/namespaceSteinberg.html#a3c4f7362f2f494a4120d7c864dd0822d", null ],
-    [ "UString128", "../base/namespaceSteinberg.html#aa92186fdeda699e7a0cc7ac6c45d07e5", null ],
-    [ "UString256", "../base/namespaceSteinberg.html#a71098a25fa252b10d271a11807153385", null ],
+    [ "int8", "../base/group__smtgtypedef.html#gae47c588f3ab8c61121c1c7ab7edc47cd", null ],
+    [ "uint8", "../base/group__smtgtypedef.html#ga33a5e996e7a90acefb8b1c0bea47e365", null ],
+    [ "uchar", "../base/group__smtgtypedef.html#ga65f85814a8290f9797005d3b28e7e5fc", null ],
+    [ "int16", "../base/group__smtgtypedef.html#gaa0d0fdc87fd135ef2bedb030901cdb9c", null ],
+    [ "uint16", "../base/group__smtgtypedef.html#gac2a9e79eb120216f855626495b7bd18a", null ],
+    [ "int32", "../base/group__smtgtypedef.html#gab7903878916593daecbeb95b98115ab0", null ],
+    [ "uint32", "../base/group__smtgtypedef.html#gacbd4acd0d29e2d6c43104827f77d9cd2", null ],
+    [ "int64", "../base/group__smtgtypedef.html#ga7cde0074dfd288f2d70c0e035dacb28a", null ],
+    [ "uint64", "../base/group__smtgtypedef.html#gabc0f5bc07737e498f287334775dff2b6", null ],
+    [ "TSize", "../base/group__smtgtypedef.html#gabc5a03f91bd781b5062f4fccaa7851f0", null ],
+    [ "tresult", "../base/group__smtgtypedef.html#ga902761e005a6252e538c766de48fc957", null ],
+    [ "TPtrInt", "../base/group__smtgtypedef.html#gadbdfa470c35e7bf57d7952f0767bbf57", null ],
+    [ "TBool", "../base/group__smtgtypedef.html#ga1ea8addd740f35d207a1569dd38ef895", null ],
+    [ "char8", "../base/group__smtgtypedef.html#gac9e1c0f508ae0f5f8a2b704a91e1ae86", null ],
+    [ "char16", "../base/group__smtgtypedef.html#ga667a0a4e0cbcb3f3785984955e1fefd8", null ],
+    [ "char", "../base/group__smtgtypedef.html#gaa9eb7d301130a7771343735bef461579", null ],
+    [ "CStringA", "../base/group__smtgtypedef.html#ga435992556581fbc31a9bddb3bb2f787a", null ],
+    [ "CStringW", "../base/group__smtgtypedef.html#ga81b4df0e8189d2f135f25919a6a90be2", null ],
+    [ "CString", "../base/group__smtgtypedef.html#ga6f37e0dbf8faed21d2658800d9db4583", null ],
+    [ "FIDString", "../base/group__smtgtypedef.html#gad4c02134d1ee42389f3d94717935a1d5", null ],
+    [ "UCoord", "../base/group__smtgtypedef.html#gabf33a8b245f4634965116e9c25eb702a", null ],
+    [ "LARGE_INT", "../base/group__smtgtypedef.html#ga9cd1730908299276af7bc0baa8c5197e", null ],
+    [ "TUID", "../base/group__pluginBase.html#ga6935af93744bfe4ecc455f274ef1ec36", null ],
+    [ "IAttrID", "../base/group__smtgtypedef.html#gae6eacc17e4382538d4af0d9993bc869a", null ],
+    [ "ColorSpec", "../base/group__smtgtypedef.html#ga5b13d028fba1eee386ec9ac208c6238d", null ],
+    [ "ColorComponent", "../base/group__smtgtypedef.html#gaf1189c83b63820c6ccc3167402601fea", null ],
+    [ "UColorSpec", "../base/group__smtgtypedef.html#ga87699df6cd24276f34afea51d903c6e4", null ],
+    [ "UColorComponent", "../base/group__smtgtypedef.html#ga3c4f7362f2f494a4120d7c864dd0822d", null ],
+    [ "UString128", "../base/group__smtgtypedef.html#gaa92186fdeda699e7a0cc7ac6c45d07e5", null ],
+    [ "UString256", "../base/group__smtgtypedef.html#ga71098a25fa252b10d271a11807153385", null ],
+    [ "PlatformModuleHandle", "namespaceSteinberg.html#a2b77f25331b6b934ae5be8a502577f3c", null ],
+    [ "ModuleInitFunction", "namespaceSteinberg.html#ac80d5bce3313535f472096c5148f39c6", null ],
+    [ "ModuleInitPriority", "namespaceSteinberg.html#aeaed082fad769d227ba3c79b380eb894", null ],
     [ "Direction", "../base/namespaceSteinberg.html#a224b9163917ac32fc95a60d8c1eec3aa", null ],
     [ "Orientation", "../base/namespaceSteinberg.html#a871118a09520247c78a71ecd7b0abd58", null ],
     [ "VirtualKeyCodes", "../base/namespaceSteinberg.html#a9380117707cebcb5a3cd9fa8b960e22b", null ],
@@ -111,9 +137,9 @@ var namespaceSteinberg =
     [ "strcat16", "../base/namespaceSteinberg.html#a05fbb76593f6044ac8375e1becf16d4d", null ],
     [ "str8ToStr16", "../base/namespaceSteinberg.html#a65d41e28de7b3ce39de0f9e2e6d99926", null ],
     [ "FIDStringsEqual", "../base/namespaceSteinberg.html#afcb1a763178c9806cc827360a02741e2", null ],
-    [ "strEmpty", "../base/namespaceSteinberg.html#a6a838f230987e1a095b0cb75c28d4a65", null ],
-    [ "str8Empty", "../base/namespaceSteinberg.html#a728f0ddc16a12be5fa0f950f4c8a0a8e", null ],
-    [ "str16Empty", "../base/namespaceSteinberg.html#a81eef9745d0b6653c6a1c78bb89533d8", null ],
+    [ "strEmpty", "../base/group__smtgtypedef.html#ga6a838f230987e1a095b0cb75c28d4a65", null ],
+    [ "str8Empty", "../base/group__smtgtypedef.html#ga728f0ddc16a12be5fa0f950f4c8a0a8e", null ],
+    [ "str16Empty", "../base/group__smtgtypedef.html#ga81eef9745d0b6653c6a1c78bb89533d8", null ],
     [ "getTUID", "../base/namespaceSteinberg.html#ab5c714b140d499f304e042e746ca9b1b", null ],
     [ "Min", "../base/namespaceSteinberg.html#a29948ccdc9190054dba415d7ac893768", null ],
     [ "Max", "../base/namespaceSteinberg.html#ae861849d924547696801cead672d8b16", null ],
@@ -122,7 +148,7 @@ var namespaceSteinberg =
     [ "Bound", "../base/namespaceSteinberg.html#ac5974f8c0577e9e37f9ea9d9d5a70a75", null ],
     [ "Swap", "../base/namespaceSteinberg.html#a1bab287b1f45fc8d99493a1d142b7deb", null ],
     [ "IsApproximateEqual", "../base/namespaceSteinberg.html#a004e46ded0d442c0c031094559ad23b6", null ],
-    [ "ToNormalized", "../base/namespaceSteinberg.html#a31a33bd1d2143601be9244b5eb666167", null ],
+    [ "ToNormalized", "../base/namespaceSteinberg.html#a266eafd81fd5078d6b177162227ee49a", null ],
     [ "FromNormalized", "../base/namespaceSteinberg.html#a53b9fdb1691391567d0bd6697ddc503c", null ],
     [ "operator==", "../base/namespaceSteinberg.html#a8a42998c5c8a3a844cdf3b21d1b9be70", null ],
     [ "operator!=", "../base/namespaceSteinberg.html#a443dbd34922bff48d94a4060764ae9e9", null ],
@@ -150,7 +176,13 @@ var namespaceSteinberg =
     [ "BlendColor", "../base/namespaceSteinberg.html#a82f9ae0460c5ad8b348cdfa75fec5c68", null ],
     [ "StringCopy", "../base/namespaceSteinberg.html#a51c63740ab18a5e8a1394fb10e743917", null ],
     [ "StringLength", "../base/namespaceSteinberg.html#ae6cdc2936b352ab9cd2fb6aed350bbaa", null ],
-    [ "DEF_CLASS_IID", "../base/namespaceSteinberg.html#a0a5776df696f816f7fcc81666e242d81", null ],
+    [ "strEmpty", "../base/group__smtgtypedef.html#ga6a838f230987e1a095b0cb75c28d4a65", null ],
+    [ "str8Empty", "../base/group__smtgtypedef.html#ga728f0ddc16a12be5fa0f950f4c8a0a8e", null ],
+    [ "str16Empty", "../base/group__smtgtypedef.html#ga81eef9745d0b6653c6a1c78bb89533d8", null ],
+    [ "DEF_CLASS_IID", "namespaceSteinberg.html#a0a5776df696f816f7fcc81666e242d81", null ],
+    [ "openURLInDefaultApplication", "group__sdkBase.html#ga573e89b755a4d476e281d5687fc7de84", null ],
+    [ "readFile", "group__sdkBase.html#ga9161593ad3336650b604b9b7ceb15b81", null ],
+    [ "getPlatformModuleHandle", "namespaceSteinberg.html#a6f950e10982e85e00537791c44d635e3", null ],
     [ "kNoInterface", "../base/namespaceSteinberg.html#a57098e3418561770792c2f29c4530c53a21f2c8af375a407ff9fb8d10e8e73a17", null ],
     [ "kResultOk", "../base/namespaceSteinberg.html#a57098e3418561770792c2f29c4530c53a941549edbe23d0f21851403ae03ad4df", null ],
     [ "kResultTrue", "../base/namespaceSteinberg.html#a57098e3418561770792c2f29c4530c53a9e60fad4624bee040985edebe1800372", null ],
@@ -294,15 +326,33 @@ var namespaceSteinberg =
     [ "kLtGray", "../base/namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cdac4512c2e2b20209b3fa8364b8be3483d", null ],
     [ "kGray", "../base/namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda1ab75347fd43308dc34268db5a181108", null ],
     [ "kDkGray", "../base/namespaceSteinberg.html#acbbce6877e30abdb4f8fedfbcc3622cda78c5cc590de98a677b2dc3076c904128", null ],
-    [ "kPlatformStringWin", "../base/namespaceSteinberg.html#a2ae80314db54c6bda33e1cf922effb47", null ],
-    [ "kPlatformStringMac", "../base/namespaceSteinberg.html#ad5ffc071fd688ac833b5283777037278", null ],
-    [ "kPlatformStringIOS", "../base/namespaceSteinberg.html#a0e747a3b854268949a75a1c8e8fd070c", null ],
-    [ "kPlatformStringLinux", "../base/namespaceSteinberg.html#a1c13255fbcd5845d44bd45cc27bd3586", null ],
-    [ "kPlatformString", "../base/namespaceSteinberg.html#a45a730ec762ad31ab0e5c80e15560afc", null ],
-    [ "kPlatformTypeHWND", "../base/namespaceSteinberg.html#aa1e68ac1f25da9c85c937d0360dbc601", null ],
-    [ "kPlatformTypeHIView", "../base/namespaceSteinberg.html#a974cabea219cb31ad8218ba15d1f7071", null ],
-    [ "kPlatformTypeNSView", "../base/namespaceSteinberg.html#a8ce69944b5475d65206469b9ebcbf755", null ],
-    [ "kPlatformTypeUIView", "../base/namespaceSteinberg.html#a6362a7ca65b87d30c561dac986b757bd", null ],
-    [ "kPlatformTypeX11EmbedWindowID", "../base/namespaceSteinberg.html#ac945decc5f26f3fdb5419e8de833a0e1", null ],
-    [ "gPluginFactory", "../base/namespaceSteinberg.html#a8424a16f6b47419c0c3bb4b7b1374d81", null ]
+    [ "kPlatformStringWin", "../base/group__smtgtypedef.html#ga2ae80314db54c6bda33e1cf922effb47", null ],
+    [ "kPlatformStringMac", "../base/group__smtgtypedef.html#gad5ffc071fd688ac833b5283777037278", null ],
+    [ "kPlatformStringIOS", "../base/group__smtgtypedef.html#ga0e747a3b854268949a75a1c8e8fd070c", null ],
+    [ "kPlatformStringLinux", "../base/group__smtgtypedef.html#ga1c13255fbcd5845d44bd45cc27bd3586", null ],
+    [ "kPlatformString", "../base/group__smtgtypedef.html#ga45a730ec762ad31ab0e5c80e15560afc", null ],
+    [ "kPlatformTypeHWND", "../base/group__platformUIType.html#gaa1e68ac1f25da9c85c937d0360dbc601", null ],
+    [ "kPlatformTypeHIView", "../base/group__platformUIType.html#ga974cabea219cb31ad8218ba15d1f7071", null ],
+    [ "kPlatformTypeNSView", "../base/group__platformUIType.html#ga8ce69944b5475d65206469b9ebcbf755", null ],
+    [ "kPlatformTypeUIView", "../base/group__platformUIType.html#ga6362a7ca65b87d30c561dac986b757bd", null ],
+    [ "kPlatformTypeX11EmbedWindowID", "../base/group__platformUIType.html#gac945decc5f26f3fdb5419e8de833a0e1", null ],
+    [ "kPlatformTypeWaylandSurfaceID", "../base/group__platformUIType.html#ga111998b5f362f172b2c0edce7bfe3552", null ],
+    [ "kPlatformStringWin", "../base/group__smtgtypedef.html#ga2ae80314db54c6bda33e1cf922effb47", null ],
+    [ "kPlatformStringMac", "../base/group__smtgtypedef.html#gad5ffc071fd688ac833b5283777037278", null ],
+    [ "kPlatformStringIOS", "../base/group__smtgtypedef.html#ga0e747a3b854268949a75a1c8e8fd070c", null ],
+    [ "kPlatformStringLinux", "../base/group__smtgtypedef.html#ga1c13255fbcd5845d44bd45cc27bd3586", null ],
+    [ "kPlatformString", "../base/group__smtgtypedef.html#ga45a730ec762ad31ab0e5c80e15560afc", null ],
+    [ "kPlatformTypeHWND", "../base/group__platformUIType.html#gaa1e68ac1f25da9c85c937d0360dbc601", null ],
+    [ "kPlatformTypeHIView", "../base/group__platformUIType.html#ga974cabea219cb31ad8218ba15d1f7071", null ],
+    [ "kPlatformTypeNSView", "../base/group__platformUIType.html#ga8ce69944b5475d65206469b9ebcbf755", null ],
+    [ "kPlatformTypeUIView", "../base/group__platformUIType.html#ga6362a7ca65b87d30c561dac986b757bd", null ],
+    [ "kPlatformTypeX11EmbedWindowID", "../base/group__platformUIType.html#gac945decc5f26f3fdb5419e8de833a0e1", null ],
+    [ "kPlatformTypeWaylandSurfaceID", "../base/group__platformUIType.html#ga111998b5f362f172b2c0edce7bfe3552", null ],
+    [ "kPlatformTypeHWND", "../vstinterfaces/group__platformUIType.html#gaa1e68ac1f25da9c85c937d0360dbc601", null ],
+    [ "kPlatformTypeHIView", "../vstinterfaces/group__platformUIType.html#ga974cabea219cb31ad8218ba15d1f7071", null ],
+    [ "kPlatformTypeNSView", "../vstinterfaces/group__platformUIType.html#ga8ce69944b5475d65206469b9ebcbf755", null ],
+    [ "kPlatformTypeUIView", "../vstinterfaces/group__platformUIType.html#ga6362a7ca65b87d30c561dac986b757bd", null ],
+    [ "kPlatformTypeX11EmbedWindowID", "../vstinterfaces/group__platformUIType.html#gac945decc5f26f3fdb5419e8de833a0e1", null ],
+    [ "kPlatformTypeWaylandSurfaceID", "../vstinterfaces/group__platformUIType.html#ga111998b5f362f172b2c0edce7bfe3552", null ],
+    [ "gPluginFactory", "namespaceSteinberg.html#a8424a16f6b47419c0c3bb4b7b1374d81", null ]
 ];
\ No newline at end of file
