@@ -1,7 +1,21 @@
 var NAVTREEINDEX1 =
 {
-"classSteinberg_1_1Vst_1_1BypassProcessor.html#af03bc4cf393d19019897417293c55663":[2,0,0,7,30,9],
-"classSteinberg_1_1Vst_1_1BypassProcessor.html#af03bc4cf393d19019897417293c55663":[3,0,0,1,10,9],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#a691325367c431ca1b7de7e4ee9a5c12f":[2,0,0,11,30,11],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#a691325367c431ca1b7de7e4ee9a5c12f":[3,0,0,2,10,11],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#a8deb9859f723a808a42ff15745c62c12":[2,0,0,11,30,6],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#a8deb9859f723a808a42ff15745c62c12":[3,0,0,2,10,6],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#aa22941a36e7c7c61e30f3a54879528a0":[2,0,0,11,30,2],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#aa22941a36e7c7c61e30f3a54879528a0":[3,0,0,2,10,2],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#ab582c8b862d2c49ab3ad21ac7b036500":[2,0,0,11,30,10],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#ab582c8b862d2c49ab3ad21ac7b036500":[3,0,0,2,10,10],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#ad20897c5c8bd47f5d4005989bead0e55":[2,0,0,11,30,4],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#ad20897c5c8bd47f5d4005989bead0e55":[3,0,0,2,10,4],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#add33a3d56ac667b24bdf9a292a5bd36c":[2,0,0,11,30,3],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#add33a3d56ac667b24bdf9a292a5bd36c":[3,0,0,2,10,3],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#ae53e2a9daae0aa62f5797ed0d4dbdcb0":[2,0,0,11,30,8],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#ae53e2a9daae0aa62f5797ed0d4dbdcb0":[3,0,0,2,10,8],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#af03bc4cf393d19019897417293c55663":[2,0,0,11,30,9],
+"classSteinberg_1_1Vst_1_1BypassProcessor.html#af03bc4cf393d19019897417293c55663":[3,0,0,2,10,9],
 "classSteinberg_1_1Vst_1_1Component.html":[1,0,5],
 "classSteinberg_1_1Vst_1_1Component.html#a0171e1571f18dc6a27c8b041de55feec":[1,0,5,0],
 "classSteinberg_1_1Vst_1_1Component.html#a0dc4b3344bc02fac04276d981e23834f":[1,0,5,1],
@@ -42,62 +56,62 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1ComponentBase.html#ad73cdb71520acbddc432f05afc78f319":[1,0,6,4],
 "classSteinberg_1_1Vst_1_1ComponentBase.html#adbcbdfd9061c4f951db444f60d358b12":[1,0,6,12],
 "classSteinberg_1_1Vst_1_1ComponentBase.html#ae38ec4832624d4d7d1eca0edaae60476":[1,0,6,3],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html":[2,0,0,7,33],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html":[3,0,0,1,13],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a12db172f74059f7eceb63714f4589aa0":[2,0,0,7,33,5],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a12db172f74059f7eceb63714f4589aa0":[3,0,0,1,13,5],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a4487b5c458a52ed743064aad105a244d":[2,0,0,7,33,7],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a4487b5c458a52ed743064aad105a244d":[3,0,0,1,13,7],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a6c2e8e8b1fbabb82ea67dcf81fb0c6b6":[2,0,0,7,33,3],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a6c2e8e8b1fbabb82ea67dcf81fb0c6b6":[3,0,0,1,13,3],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a891d1d252d711b7980defaba5112544f":[2,0,0,7,33,1],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a891d1d252d711b7980defaba5112544f":[3,0,0,1,13,1],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a8c57e5b4596d750102fbdc6f195ea05f":[2,0,0,7,33,2],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a8c57e5b4596d750102fbdc6f195ea05f":[3,0,0,1,13,2],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#ad51790a646502c1269d5a4ae48441c7d":[2,0,0,7,33,0],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#ad51790a646502c1269d5a4ae48441c7d":[3,0,0,1,13,0],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#ae03c2fc2709da3bc22c6f765185fd793":[2,0,0,7,33,8],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#ae03c2fc2709da3bc22c6f765185fd793":[3,0,0,1,13,8],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#af7bb4bec2475d18c304cc1263092e2cc":[2,0,0,7,33,6],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#af7bb4bec2475d18c304cc1263092e2cc":[3,0,0,1,13,6],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#afc8b9232e82d8a56bc262978dac5856c":[2,0,0,7,33,4],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#afc8b9232e82d8a56bc262978dac5856c":[3,0,0,1,13,4],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html":[2,0,0,7,34],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html":[3,0,0,1,14],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a0658f09730e3694a67ebed87c6d06138":[2,0,0,7,34,6],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a0658f09730e3694a67ebed87c6d06138":[3,0,0,1,14,6],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a0d0f05deba6d875f545adb38dbff1853":[2,0,0,7,34,5],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a0d0f05deba6d875f545adb38dbff1853":[3,0,0,1,14,5],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a1198f6e88e7ba2ba5965aa4f0a592d72":[2,0,0,7,34,4],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a1198f6e88e7ba2ba5965aa4f0a592d72":[3,0,0,1,14,4],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a11ba504740a2f7c2e89688344141be45":[2,0,0,7,34,1],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a11ba504740a2f7c2e89688344141be45":[3,0,0,1,14,1],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a23592d2f6bfb88d19ae499ddb644b3f6":[2,0,0,7,34,9],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a23592d2f6bfb88d19ae499ddb644b3f6":[3,0,0,1,14,9],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a2c8c2d0a612cd628e955dc6e9676ea85":[2,0,0,7,34,8],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a2c8c2d0a612cd628e955dc6e9676ea85":[3,0,0,1,14,8],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a49505377ab844ba48d3b85fd224f7d63":[2,0,0,7,34,11],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a49505377ab844ba48d3b85fd224f7d63":[3,0,0,1,14,11],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a6530852c0fc0ded04f913c5d6de9bc16":[2,0,0,7,34,7],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a6530852c0fc0ded04f913c5d6de9bc16":[3,0,0,1,14,7],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a66d8feb44d790d1c96e76ffd13b54bb0":[2,0,0,7,34,12],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a66d8feb44d790d1c96e76ffd13b54bb0":[3,0,0,1,14,12],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a82c9767f227ed858413efa54450309ea":[2,0,0,7,34,3],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a82c9767f227ed858413efa54450309ea":[3,0,0,1,14,3],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a97ca1031d43944ec348aab7d5a060b8c":[2,0,0,7,34,10],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a97ca1031d43944ec348aab7d5a060b8c":[3,0,0,1,14,10],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aacb819fb241851fd9fc045271baa4034":[2,0,0,7,34,13],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aacb819fb241851fd9fc045271baa4034":[3,0,0,1,14,13],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aea634a2e1293658a1e343bbc8bf71dd7":[2,0,0,7,34,2],
-"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aea634a2e1293658a1e343bbc8bf71dd7":[3,0,0,1,14,2],
-"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html":[2,0,0,7,35],
-"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html":[3,0,0,1,15],
-"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a04f7bfae5ffb6c3841cad64acfed4747":[2,0,0,7,35,0],
-"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a04f7bfae5ffb6c3841cad64acfed4747":[3,0,0,1,15,0],
-"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a1f2bdf21855cf544c941e22557450a58":[2,0,0,7,35,1],
-"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a1f2bdf21855cf544c941e22557450a58":[3,0,0,1,15,1],
-"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a3b307b566f37e2addb73488ba6c67fe7":[2,0,0,7,35,2],
-"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a3b307b566f37e2addb73488ba6c67fe7":[3,0,0,1,15,2],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html":[2,0,0,11,33],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html":[3,0,0,2,13],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a12db172f74059f7eceb63714f4589aa0":[2,0,0,11,33,5],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a12db172f74059f7eceb63714f4589aa0":[3,0,0,2,13,5],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a4487b5c458a52ed743064aad105a244d":[2,0,0,11,33,7],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a4487b5c458a52ed743064aad105a244d":[3,0,0,2,13,7],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a6c2e8e8b1fbabb82ea67dcf81fb0c6b6":[2,0,0,11,33,3],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a6c2e8e8b1fbabb82ea67dcf81fb0c6b6":[3,0,0,2,13,3],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a891d1d252d711b7980defaba5112544f":[2,0,0,11,33,1],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a891d1d252d711b7980defaba5112544f":[3,0,0,2,13,1],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a8c57e5b4596d750102fbdc6f195ea05f":[2,0,0,11,33,2],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a8c57e5b4596d750102fbdc6f195ea05f":[3,0,0,2,13,2],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#ad51790a646502c1269d5a4ae48441c7d":[2,0,0,11,33,0],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#ad51790a646502c1269d5a4ae48441c7d":[3,0,0,2,13,0],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#ae03c2fc2709da3bc22c6f765185fd793":[2,0,0,11,33,8],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#ae03c2fc2709da3bc22c6f765185fd793":[3,0,0,2,13,8],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#af7bb4bec2475d18c304cc1263092e2cc":[2,0,0,11,33,6],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#af7bb4bec2475d18c304cc1263092e2cc":[3,0,0,2,13,6],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#afc8b9232e82d8a56bc262978dac5856c":[2,0,0,11,33,4],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html#afc8b9232e82d8a56bc262978dac5856c":[3,0,0,2,13,4],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html":[2,0,0,11,34],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html":[3,0,0,2,14],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a0658f09730e3694a67ebed87c6d06138":[2,0,0,11,34,6],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a0658f09730e3694a67ebed87c6d06138":[3,0,0,2,14,6],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a0d0f05deba6d875f545adb38dbff1853":[2,0,0,11,34,5],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a0d0f05deba6d875f545adb38dbff1853":[3,0,0,2,14,5],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a1198f6e88e7ba2ba5965aa4f0a592d72":[2,0,0,11,34,4],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a1198f6e88e7ba2ba5965aa4f0a592d72":[3,0,0,2,14,4],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a11ba504740a2f7c2e89688344141be45":[2,0,0,11,34,1],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a11ba504740a2f7c2e89688344141be45":[3,0,0,2,14,1],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a23592d2f6bfb88d19ae499ddb644b3f6":[2,0,0,11,34,9],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a23592d2f6bfb88d19ae499ddb644b3f6":[3,0,0,2,14,9],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a2c8c2d0a612cd628e955dc6e9676ea85":[2,0,0,11,34,8],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a2c8c2d0a612cd628e955dc6e9676ea85":[3,0,0,2,14,8],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a49505377ab844ba48d3b85fd224f7d63":[2,0,0,11,34,11],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a49505377ab844ba48d3b85fd224f7d63":[3,0,0,2,14,11],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a6530852c0fc0ded04f913c5d6de9bc16":[2,0,0,11,34,7],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a6530852c0fc0ded04f913c5d6de9bc16":[3,0,0,2,14,7],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a66d8feb44d790d1c96e76ffd13b54bb0":[2,0,0,11,34,12],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a66d8feb44d790d1c96e76ffd13b54bb0":[3,0,0,2,14,12],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a82c9767f227ed858413efa54450309ea":[2,0,0,11,34,3],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a82c9767f227ed858413efa54450309ea":[3,0,0,2,14,3],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a97ca1031d43944ec348aab7d5a060b8c":[2,0,0,11,34,10],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a97ca1031d43944ec348aab7d5a060b8c":[3,0,0,2,14,10],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aacb819fb241851fd9fc045271baa4034":[2,0,0,11,34,13],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aacb819fb241851fd9fc045271baa4034":[3,0,0,2,14,13],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aea634a2e1293658a1e343bbc8bf71dd7":[2,0,0,11,34,2],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aea634a2e1293658a1e343bbc8bf71dd7":[3,0,0,2,14,2],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html":[2,0,0,11,35],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html":[3,0,0,2,15],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a04f7bfae5ffb6c3841cad64acfed4747":[2,0,0,11,35,0],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a04f7bfae5ffb6c3841cad64acfed4747":[3,0,0,2,15,0],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a1f2bdf21855cf544c941e22557450a58":[2,0,0,11,35,1],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a1f2bdf21855cf544c941e22557450a58":[3,0,0,2,15,1],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a3b307b566f37e2addb73488ba6c67fe7":[2,0,0,11,35,2],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a3b307b566f37e2addb73488ba6c67fe7":[3,0,0,2,15,2],
 "classSteinberg_1_1Vst_1_1EditController.html":[1,0,7],
 "classSteinberg_1_1Vst_1_1EditController.html#a0d848355600e651408719e8a288426ef":[1,0,7,24],
 "classSteinberg_1_1Vst_1_1EditController.html#a1a882472b7c228eb1f709c7f15b15999":[1,0,7,4],
@@ -174,34 +188,34 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1EventBus.html#a5570b4631f4b2d4660a1b53e65c3d876":[1,0,2,1],
 "classSteinberg_1_1Vst_1_1EventBus.html#ab22e24964d55652336d526a41e5a2309":[1,0,2,3],
 "classSteinberg_1_1Vst_1_1EventBus.html#ad95d0ee442fa262d28e33fc43f8e16c2":[1,0,2,2],
-"classSteinberg_1_1Vst_1_1EventList.html":[1,1,1],
-"classSteinberg_1_1Vst_1_1EventList.html#a1cbe1abefe1aa274c4a68aefe8255eef":[1,1,1,0],
-"classSteinberg_1_1Vst_1_1EventList.html#a368f654ec650602168bd5ddab3a9105a":[1,1,1,4],
-"classSteinberg_1_1Vst_1_1EventList.html#a40abce7e3caeb230845167f0376b67c0":[1,1,1,7],
-"classSteinberg_1_1Vst_1_1EventList.html#a609c4f8034f898f63d031c2d0a50e74c":[1,1,1,9],
-"classSteinberg_1_1Vst_1_1EventList.html#a7e24245d928a44341af3ea9fce899704":[1,1,1,2],
-"classSteinberg_1_1Vst_1_1EventList.html#a7fd201a191321a3648691995aae75b15":[1,1,1,8],
-"classSteinberg_1_1Vst_1_1EventList.html#a8dc46be3158d9c6b9ffe81945a32cb92":[1,1,1,1],
-"classSteinberg_1_1Vst_1_1EventList.html#a9535fa1037b1bb2bfa5f855a02a357b8":[1,1,1,3],
-"classSteinberg_1_1Vst_1_1EventList.html#ac8bb3912a3ce86b15842e79d0b421204":[1,1,1,6],
-"classSteinberg_1_1Vst_1_1EventList.html#ae719cb1fce98d2f22058ae277db25c57":[1,1,1,10],
-"classSteinberg_1_1Vst_1_1EventList.html#ae99140cfaabb706532cbfc38313a54cd":[1,1,1,5],
-"classSteinberg_1_1Vst_1_1FileStream.html":[2,0,0,7,41],
-"classSteinberg_1_1Vst_1_1FileStream.html":[3,0,0,1,21],
-"classSteinberg_1_1Vst_1_1FileStream.html#a07ec419862792d4581e85feef181702c":[2,0,0,7,41,0],
-"classSteinberg_1_1Vst_1_1FileStream.html#a07ec419862792d4581e85feef181702c":[3,0,0,1,21,0],
-"classSteinberg_1_1Vst_1_1FileStream.html#a19e0b2bee0e3bc81ea6e6ba6c6a44134":[2,0,0,7,41,1],
-"classSteinberg_1_1Vst_1_1FileStream.html#a19e0b2bee0e3bc81ea6e6ba6c6a44134":[3,0,0,1,21,1],
-"classSteinberg_1_1Vst_1_1FileStream.html#a2d4abea09c00a14cc7cb73faca434027":[2,0,0,7,41,4],
-"classSteinberg_1_1Vst_1_1FileStream.html#a2d4abea09c00a14cc7cb73faca434027":[3,0,0,1,21,4],
-"classSteinberg_1_1Vst_1_1FileStream.html#a30ac05a99b145cc2d1837cb32aff8678":[2,0,0,7,41,3],
-"classSteinberg_1_1Vst_1_1FileStream.html#a30ac05a99b145cc2d1837cb32aff8678":[3,0,0,1,21,3],
-"classSteinberg_1_1Vst_1_1FileStream.html#a702945180aa732857b380a007a7e2a21":[2,0,0,7,41,6],
-"classSteinberg_1_1Vst_1_1FileStream.html#a702945180aa732857b380a007a7e2a21":[3,0,0,1,21,6],
-"classSteinberg_1_1Vst_1_1FileStream.html#a7a35b7508308b7cb624562821c653c84":[2,0,0,7,41,5],
-"classSteinberg_1_1Vst_1_1FileStream.html#a7a35b7508308b7cb624562821c653c84":[3,0,0,1,21,5],
-"classSteinberg_1_1Vst_1_1FileStream.html#af2a6c55ced9ca4dd804e10f73e26b5df":[2,0,0,7,41,2],
-"classSteinberg_1_1Vst_1_1FileStream.html#af2a6c55ced9ca4dd804e10f73e26b5df":[3,0,0,1,21,2],
+"classSteinberg_1_1Vst_1_1EventList.html":[1,1,2],
+"classSteinberg_1_1Vst_1_1EventList.html#a1cbe1abefe1aa274c4a68aefe8255eef":[1,1,2,0],
+"classSteinberg_1_1Vst_1_1EventList.html#a368f654ec650602168bd5ddab3a9105a":[1,1,2,4],
+"classSteinberg_1_1Vst_1_1EventList.html#a40abce7e3caeb230845167f0376b67c0":[1,1,2,7],
+"classSteinberg_1_1Vst_1_1EventList.html#a609c4f8034f898f63d031c2d0a50e74c":[1,1,2,9],
+"classSteinberg_1_1Vst_1_1EventList.html#a7e24245d928a44341af3ea9fce899704":[1,1,2,2],
+"classSteinberg_1_1Vst_1_1EventList.html#a7fd201a191321a3648691995aae75b15":[1,1,2,8],
+"classSteinberg_1_1Vst_1_1EventList.html#a8dc46be3158d9c6b9ffe81945a32cb92":[1,1,2,1],
+"classSteinberg_1_1Vst_1_1EventList.html#a9535fa1037b1bb2bfa5f855a02a357b8":[1,1,2,3],
+"classSteinberg_1_1Vst_1_1EventList.html#ac8bb3912a3ce86b15842e79d0b421204":[1,1,2,6],
+"classSteinberg_1_1Vst_1_1EventList.html#ae719cb1fce98d2f22058ae277db25c57":[1,1,2,10],
+"classSteinberg_1_1Vst_1_1EventList.html#ae99140cfaabb706532cbfc38313a54cd":[1,1,2,5],
+"classSteinberg_1_1Vst_1_1FileStream.html":[2,0,0,11,41],
+"classSteinberg_1_1Vst_1_1FileStream.html":[3,0,0,2,21],
+"classSteinberg_1_1Vst_1_1FileStream.html#a07ec419862792d4581e85feef181702c":[2,0,0,11,41,0],
+"classSteinberg_1_1Vst_1_1FileStream.html#a07ec419862792d4581e85feef181702c":[3,0,0,2,21,0],
+"classSteinberg_1_1Vst_1_1FileStream.html#a19e0b2bee0e3bc81ea6e6ba6c6a44134":[2,0,0,11,41,1],
+"classSteinberg_1_1Vst_1_1FileStream.html#a19e0b2bee0e3bc81ea6e6ba6c6a44134":[3,0,0,2,21,1],
+"classSteinberg_1_1Vst_1_1FileStream.html#a2d4abea09c00a14cc7cb73faca434027":[2,0,0,11,41,4],
+"classSteinberg_1_1Vst_1_1FileStream.html#a2d4abea09c00a14cc7cb73faca434027":[3,0,0,2,21,4],
+"classSteinberg_1_1Vst_1_1FileStream.html#a30ac05a99b145cc2d1837cb32aff8678":[2,0,0,11,41,3],
+"classSteinberg_1_1Vst_1_1FileStream.html#a30ac05a99b145cc2d1837cb32aff8678":[3,0,0,2,21,3],
+"classSteinberg_1_1Vst_1_1FileStream.html#a702945180aa732857b380a007a7e2a21":[2,0,0,11,41,6],
+"classSteinberg_1_1Vst_1_1FileStream.html#a702945180aa732857b380a007a7e2a21":[3,0,0,2,21,6],
+"classSteinberg_1_1Vst_1_1FileStream.html#a7a35b7508308b7cb624562821c653c84":[2,0,0,11,41,5],
+"classSteinberg_1_1Vst_1_1FileStream.html#a7a35b7508308b7cb624562821c653c84":[3,0,0,2,21,5],
+"classSteinberg_1_1Vst_1_1FileStream.html#af2a6c55ced9ca4dd804e10f73e26b5df":[2,0,0,11,41,2],
+"classSteinberg_1_1Vst_1_1FileStream.html#af2a6c55ced9ca4dd804e10f73e26b5df":[3,0,0,2,21,2],
 "classSteinberg_1_1Vst_1_1HostApplication.html":[1,2,0],
 "classSteinberg_1_1Vst_1_1HostApplication.html#a682147e83d7a2350ed741b45f0e019cf":[1,2,0,1],
 "classSteinberg_1_1Vst_1_1HostApplication.html#a917b260c602e1aa5332bb349ef0f2c20":[1,2,0,0],
@@ -235,19 +249,5 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1HostProcessData.html#a796f58f03d7aaa775291b741b99934ff":[1,2,7,9],
 "classSteinberg_1_1Vst_1_1HostProcessData.html#a93c35fdbe9a7946debe1b9c75a45daef":[1,2,7,5],
 "classSteinberg_1_1Vst_1_1HostProcessData.html#a99c0b5d3887e3704a467073443527e36":[1,2,7,1],
-"classSteinberg_1_1Vst_1_1HostProcessData.html#a9dce8ca94a068851ffa015c766c9d04e":[1,2,7,2],
-"classSteinberg_1_1Vst_1_1HostProcessData.html#aac85e944298eabcb099f9a98e6e97a94":[1,2,7,13],
-"classSteinberg_1_1Vst_1_1HostProcessData.html#ac9368c70233f027934c6414975720e68":[1,2,7,11],
-"classSteinberg_1_1Vst_1_1HostProcessData.html#ad2956018947469c5d5d17d86ee868f2a":[1,2,7,14],
-"classSteinberg_1_1Vst_1_1HostProcessData.html#af09fdb1736e7957252ac630096ef6357":[1,2,7,3],
-"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html":[2,0,0,7,9,0],
-"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html":[3,0,0,1,0,0],
-"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#a35c0a5fa5367c71ed35c53737b88880c":[2,0,0,7,9,0,6],
-"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#a35c0a5fa5367c71ed35c53737b88880c":[3,0,0,1,0,0,6],
-"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#a5f54b6e5cf74285792bb132af98c0308":[2,0,0,7,9,0,3],
-"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#a5f54b6e5cf74285792bb132af98c0308":[3,0,0,1,0,0,3],
-"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#a9bf9df82b8772ce781fb2860e204a8df":[2,0,0,7,9,0,5],
-"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#a9bf9df82b8772ce781fb2860e204a8df":[3,0,0,1,0,0,5],
-"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#aacb819fb241851fd9fc045271baa4034":[2,0,0,7,9,0,1],
-"classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#aacb819fb241851fd9fc045271baa4034":[3,0,0,1,0,0,1]
+"classSteinberg_1_1Vst_1_1HostProcessData.html#a9dce8ca94a068851ffa015c766c9d04e":[1,2,7,2]
 };
