@@ -1,5 +1,6 @@
 var pluginfactory_8h =
 [
+    [ "IPluginFactoryInternal", "classSteinberg_1_1IPluginFactoryInternal.html", "classSteinberg_1_1IPluginFactoryInternal" ],
     [ "BEGIN_FACTORY_CLASS", "group__classFactoryMacros.html#ga24772621f55b42b9cdc3920b7e73f4dd", null ],
     [ "BEGIN_FACTORY", "group__classFactoryMacros.html#ga24a0ad042738fc4de8c584cfb7759669", null ],
     [ "DEF_CLASS", "group__classFactoryMacros.html#gaae295af1798ff7bd4e2eaa31978142b3", null ],
@@ -9,5 +10,5 @@ var pluginfactory_8h =
     [ "DEF_CLASS_W2", "group__classFactoryMacros.html#ga790d425a588499b53552614009b8bbfe", null ],
     [ "END_FACTORY", "group__classFactoryMacros.html#ga962bbf29e9f424c00fd43493fb8f9489", null ],
     [ "DEF_VST3_CLASS", "group__classFactoryMacros.html#ga9fdf83113c2b2dddbb42811957843dd6", null ],
-    [ "gPluginFactory", "../base/namespaceSteinberg.html#a8424a16f6b47419c0c3bb4b7b1374d81", null ]
+    [ "gPluginFactory", "namespaceSteinberg.html#a8424a16f6b47419c0c3bb4b7b1374d81", null ]
 ];
\ No newline at end of file
