@@ -3,7 +3,7 @@ var searchData=
   ['scaleevent_0',['ScaleEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ScaleEvent.html',1,'Steinberg::Vst']]],
   ['setup_1',['Setup',['../structSteinberg_1_1Vst_1_1MPE_1_1Setup.html',1,'Steinberg::Vst::MPE']]],
   ['singlecomponenteffect_2',['SingleComponentEffect',['../classSteinberg_1_1Vst_1_1SingleComponentEffect.html',1,'Steinberg::Vst']]],
-  ['snapshot_3',['Snapshot',['../structVST3_1_1Hosting_1_1Module_1_1Snapshot.html',1,'VST3::Hosting::Module']]],
+  ['snapshot_3',['Snapshot',['../structSteinberg_1_1ModuleInfo_1_1Snapshot.html',1,'ModuleInfo::Snapshot'],['../structVST3_1_1Hosting_1_1Module_1_1Snapshot.html',1,'Module::Snapshot']]],
   ['speakerarray_4',['SpeakerArray',['../classSteinberg_1_1Vst_1_1SpeakerArray.html',1,'Steinberg::Vst']]],
   ['stringlistparameter_5',['StringListParameter',['../classSteinberg_1_1Vst_1_1StringListParameter.html',1,'Steinberg::Vst']]],
   ['stringresult_6',['StringResult',['../classSteinberg_1_1Vst_1_1StringResult.html',1,'Steinberg::Vst']]],
